module FHIR
  class AllergyIntolerance < FHIR::Model
    include FHIR::Hashable
    include FHIR::Json
    include FHIR::Xml

    MULTIPLE_TYPES = {
      'onset' => ['dateTime', 'Age', 'Period', 'Range', 'string']
    }
    SEARCH_PARAMS = ['asserter', 'category', 'clinical-status', 'code', 'criticality', 'date', 'identifier', 'last-date', 'manifestation', 'onset', 'patient', 'recorder', 'route', 'severity', 'type', 'verification-status']
    METADATA = {
      'id' => {'type'=>'id', 'path'=>'AllergyIntolerance.id', 'min'=>0, 'max'=>1},
      'meta' => {'type'=>'Meta', 'path'=>'AllergyIntolerance.meta', 'min'=>0, 'max'=>1},
      'implicitRules' => {'type'=>'uri', 'path'=>'AllergyIntolerance.implicitRules', 'min'=>0, 'max'=>1},
      'language' => {'valid_codes'=>{'urn:ietf:bcp:47'=>['ar', 'bn', 'cs', 'da', 'de', 'de-AT', 'de-CH', 'de-DE', 'el', 'en', 'en-AU', 'en-CA', 'en-GB', 'en-IN', 'en-NZ', 'en-SG', 'en-US', 'es', 'es-AR', 'es-ES', 'es-UY', 'fi', 'fr', 'fr-BE', 'fr-CH', 'fr-FR', 'fy', 'fy-NL', 'hi', 'hr', 'it', 'it-CH', 'it-IT', 'ja', 'ko', 'nl', 'nl-BE', 'nl-NL', 'no', 'no-NO', 'pa', 'pl', 'pt', 'pt-BR', 'ru', 'ru-RU', 'sr', 'sr-RS', 'sv', 'sv-SE', 'te', 'zh', 'zh-CN', 'zh-HK', 'zh-SG', 'zh-TW']}, 'type'=>'code', 'path'=>'AllergyIntolerance.language', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'preferred', 'uri'=>'http://hl7.org/fhir/ValueSet/languages'}},
      'text' => {'type'=>'Narrative', 'path'=>'AllergyIntolerance.text', 'min'=>0, 'max'=>1},
      'contained' => {'type'=>'Resource', 'path'=>'AllergyIntolerance.contained', 'min'=>0, 'max'=>Float::INFINITY},
      'extension' => {'type'=>'Extension', 'path'=>'AllergyIntolerance.extension', 'min'=>0, 'max'=>Float::INFINITY},
      'modifierExtension' => {'type'=>'Extension', 'path'=>'AllergyIntolerance.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
      'identifier' => {'type'=>'Identifier', 'path'=>'AllergyIntolerance.identifier', 'min'=>0, 'max'=>Float::INFINITY},
      'clinicalStatus' => {'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/allergyintolerance-clinical'=>['active', 'inactive', 'resolved']}, 'type'=>'CodeableConcept', 'path'=>'AllergyIntolerance.clinicalStatus', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/allergyintolerance-clinical'}},
      'verificationStatus' => {'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/allergyintolerance-verification'=>['unconfirmed', 'confirmed', 'refuted', 'entered-in-error']}, 'type'=>'CodeableConcept', 'path'=>'AllergyIntolerance.verificationStatus', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/allergyintolerance-verification'}},
      'type' => {'valid_codes'=>{'http://hl7.org/fhir/allergy-intolerance-type'=>['allergy', 'intolerance']}, 'type'=>'code', 'path'=>'AllergyIntolerance.type', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/allergy-intolerance-type'}},
      'category' => {'valid_codes'=>{'http://hl7.org/fhir/allergy-intolerance-category'=>['food', 'medication', 'environment', 'biologic']}, 'type'=>'code', 'path'=>'AllergyIntolerance.category', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/allergy-intolerance-category'}},
      'criticality' => {'valid_codes'=>{'http://hl7.org/fhir/allergy-intolerance-criticality'=>['low', 'high', 'unable-to-assess']}, 'type'=>'code', 'path'=>'AllergyIntolerance.criticality', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/allergy-intolerance-criticality'}},
      'code' => {'valid_codes'=>{'http://snomed.info/sct'=>['102002', '120006', '125001', '126000', '130002', '131003', '159002', '164003', '178002', '186002', '187006', '200001', '217008', '231008', '238002', '261000', '296000', '322006', '327000', '329002', '336001', '340005', '363000', '370000', '371001', '377002', '392001', '395004', '412004', '424006', '425007', '432003', '438004', '462009', '472007', '476005', '498001', '501001', '505005', '506006', '515004', '519005', '521000', '529003', '538001', '566009', '576007', '578008', '584006', '585007', '591009', '593007', '594001', '597008', '604000', '611001', '620005', '648005', '662003', '668004', '683009', '686001', '693002', '698006', '699003', '704006', '732002', '735000', '747006', '773001', '785009', '804003', '819002', '850000', '859004', '860009', '873008', '876000', '877009', '889006', '896008', '905001', '923009', '925002', '963005', '974001', '979006', '993004', '1002007', '1010008', '1018001', '1025008', '1047008', '1050006', '1057009', '1065007', '1080001', '1091008', '1097007', '1105007', '1113008', '1137008', '1149009', '1160000', '1166006', '1169004', '1171004', '1185009', '1189003', '1190007', '1219001', '1223009', '1244009', '1248007', '1269009', '1272002', '1273007', '1313002', '1319003', '1320009', '1325004', '1331001', '1334009', '1336006', '1341003', '1346008', '1355006', '1368003', '1371006', '1373009', '1381005', '1394007', '1396009', '1405004', '1408002', '1416006', '1450002', '1466000', '1471007', '1472000', '1476002', '1477006', '1496005', '1506001', '1517000', '1530004', '1535009', '1536005', '1540001', '1545006', '1557002', '1565004', '1575001', '1603001', '1607000', '1609002', '1634002', '1649005', '1656004', '1660001', '1668008', '1672007', '1673002', '1675009', '1676005', '1681001', '1696002', '1701009', '1710001', '1726000', '1727009', '1740004', '1764003', '1768000', '1786002', '1793003', '1795005', '1798007', '1799004', '1823002', '1827001', '1886008', '1904005', '1914001', '1916004', '1940007', '1944003', '1956002', '1971003', '1975007', '1978009', '1985008', '1991005', '2000001', '2006007', '2008008', '2009000', '2017008', '2027002', '2029004', '2038002', '2039005', '2050008', '2064008', '2082006', '2085008', '2088005', '2096000', '2100004', '2101000', '2125008', '2130007', '2141009', '2147008', '2151005', '2154002', '2159007', '2163000', '2168009', '2179004', '2189000', '2194000', '2195004', '2197007', '2201007', '2208001', '2212007', '2215009', '2240002', '2249001', '2254005', '2260005', '2262002', '2264001', '2309006', '2311002', '2329007', '2331003', '2338009', '2343002', '2346005', '2354007', '2358005', '2369008', '2370009', '2376003', '2384004', '2404002', '2405001', '2414006', '2430003', '2431004', '2441001', '2444009', '2450004', '2462000', '2466002', '2500009', '2509005', '2516006', '2522002', '2529006', '2537003', '2568004', '2573005', '2575003', '2595009', '2597001', '2611008', '2637006', '2648004', '2649007', '2660003', '2671002', '2674005', '2676007', '2678008', '2680002', '2698003', '2705002', '2706001', '2719002', '2721007', '2728001', '2753003', '2754009', '2765004', '2778004', '2796008', '2799001', '2823004', '2832002', '2846002', '2869004', '2878005', '2880004', '2883002', '2913009', '2916001', '2925007', '2927004', '2938004', '2942001', '2950005', '2958003', '2964005', '2974008', '2988007', '2991007', '2995003', '3027009', '3031003', '3040004', '3045009', '3052006', '3066001', '3070009', '3087006', '3107005', '3108000', '3131000', '3136005', '3142009', '3145006', '3150000', '3151001', '3155005', '3161008', '3167007', '3187008', '3193000', '3197004', '3209002', '3212004', '3225007', '3232003', '3271000', '3273002', '3300001', '3318003', '3325005', '3339005', '3340007', '3342004', '3346001', '3378009', '3379001', '3392003', '3405005', '3411008', '3437006', '3440006', '3455002', '3463001', '3465008', '3466009', '3492002', '3493007', '3495000', '3501003', '3523004', '3532002', '3555004', '3579002', '3581000', '3587001', '3588006', '3592004', '3597005', '3601005', '3602003', '3610002', '3617004', '3648007', '3655009', '3672002', '3684000', '3689005', '3692009', '3693004', '3702007', '3710008', '3718001', '3726009', '3727000', '3730007', '3737005', '3742002', '3757009', '3771001', '3775005', '3776006', '3792001', '3793006', '3800009', '3807007', '3811001', '3812008', '3816006', '3823007', '3829006', '3834005', '3836007', '3844007', '3848005', '3849002', '3854006', '3874004', '3892007', '3896005', '3897001', '3906002', '3920009', '3930000', '3932008', '3941003', '3945007', '3958008', '3961009', '3976001', '3982003', '3983008', '3990003', '3994007', '4014000', '4024008', '4025009', '4043008', '4047009', '4048004', '4067000', '4076007', '4077003', '4080002', '4091009', '4097008', '4104007', '4105008', '4115002', '4137009', '4153007', '4167003', '4169000', '4177001', '4182008', '4188007', '4200007', '4201006', '4203009', '4207005', '4217000', '4218005', '4231000', '4239003', '4255005', '4289006', '4290002', '4314009', '4334005', '4342006', '4353000', '4355007', '4362003', '4370008', '4393002', '4401009', '4413004', '4422003', '4423008', '4425001', '4435007', '4437004', '4471008', '4479005', '4480008', '4509009', '4518006', '4534009', '4540002', '4546008', '4555006', '4560005', '4561009', '4564001', '4567008', '4582003', '4591004', '4610008', '4616002', '4629002', '4635002', '4643007', '4656000', '4674009', '4681002', '4693006', '4700006', '4706000', '4714006', '4728000', '4731004', '4732006', '4746006', '4761007', '4762000', '4777008', '4780009', '4786003', '4789005', '4793004', '4814001', '4824009', '4825005', '4831008', '4832001', '4833006', '4844003', '4864008', '4872005', '4878009', '4882006', '4889002', '4901003', '4925006', '4933007', '4940008', '4955004', '4962008', '4963003', '4965005', '4968007', '4986005', '5003005', '5004004', '5007006', '5024000', '5031001', '5040002', '5043000', '5045007', '5059000', '5060005', '5061009', '5064001', '5081005', '5086000', '5094007', '5098005', '5109006', '5142007', '5160007', '5163009', '5167005', '5172001', '5179005', '5200001', '5206007', '5220000', '5226006', '5250008', '5252000', '5253005', '5259009', '5289002', '5303002', '5305009', '5307001', '5312000', '5323001', '5330007', '5339008', '5340005', '5392001', '5395004', '5404007', '5405008', '5406009', '5420002', '5439007', '5442001', '5453007', '5471000', '5474008', '5477001', '5483003', '5504009', '5511008', '5513006', '5515004', '5533005', '5537006', '5540006', '5547009', '5548004', '5568005', '5573004', '5589001', '5590005', '5628003', '5629006', '5637003', '5641004', '5647000', '5656008', '5657004', '5659001', '5670008', '5681006', '5691000', '5692007', '5699003', '5700002', '5702005', '5704006', '5705007', '5739006', '5746002', '5757007', '5762008', '5764009', '5767002', '5774007', '5800007', '5813001', '5826002', '5827006', '5829009', '5830004', '5840001', '5858007', '5863006', '5896008', '5899001', '5907009', '5910002', '5915007', '5927005', '5931004', '5932006', '5950004', '5955009', '5977008', '5989005', '5991002', '6021003', '6038004', '6043006', '6044000', '6054001', '6056004', '6068008', '6083003', '6085005', '6088007', '6089004', '6091007', '6107003', '6109000', '6115000', '6135004', '6138002', '6162007', '6170002', '6172005', '6178009', '6179001', '6182006', '6197009', '6237004', '6249003', '6256009', '6257000', '6260007', '6261006', '6263009', '6264003', '6287006', '6291001', '6301006', '6310003', '6314007', '6333002', '6338006', '6356006', '6360009', '6367007', '6386004', '6394006', '6401007', '6409009', '6411000', '6422001', '6451002', '6455006', '6469006', '6478000', '6495008', '6507009', '6513000', '6516008', '6524003', '6529008', '6532006', '6590001', '6592009', '6602005', '6611005', '6612003', '6619007', '6642000', '6644004', '6671004', '6672006', '6699008', '6701008', '6702001', '6709005', '6710000', '6713003', '6717002', '6725000', '6730001', '6741004', '6755007', '6786001', '6790004', '6792007', '6808006', '6809003', '6814004', '6817006', '6826009', '6837005', '6854002', '6865007', '6873003', '6879004', '6881002', '6884005', '6890009', '6896003', '6910009', '6911008', '6916003', '6924008', '6925009', '6927001', '6937006', '6945001', '6952004', '6958000', '6961004', '6970001', '6973004', '6983000', '6992002', '6993007', '6999006', '7008002', '7018007', '7029006', '7030001', '7034005', '7045008', '7047000', '7049002', '7054006', '7056008', '7059001', '7061005', '7070008', '7084003', '7110002', '7120007', '7132006', '7139002', '7146006', '7152007', '7156005', '7158006', '7161007', '7179006', '7191002', '7208009', '7211005', '7237008', '7243005', '7269004', '7271004', '7280004', '7281000', '7284008', '7294003', '7302008', '7318002', '7321000', '7325009', '7327001', '7328006', '7330008', '7337006', '7348004', '7382005', '7401000', '7411007', '7427000', '7434003', '7446004', '7451005', '7460002', '7470000', '7489000', '7503004', '7509000', '7515000', '7537007', '7547005', '7549008', '7588005', '7608003', '7616007', '7648006', '7661006', '7670009', '7675004', '7679005', '7685003', '7696006', '7716001', '7737009', '7738004', '7761002', '7770004', '7774008', '7779003', '7785005', '7790008', '7791007', '7795003', '7801007', '7816005', '7834009', '7846008', '7848009', '7868003', '7879008', '7900007', '7904003', '7909008', '7924004', '7938006', '7945006', '7948008', '7953003', '7957002', '7961008', '7970006', '7974002', '7975001', '7979007', '7983007', '7985000', '7997004', '8000007', '8002004', '8025003', '8029009', '8030004', '8035009', '8048008', '8054009', '8055005', '8105004', '8108002', '8123007', '8132009', '8143001', '8153000', '8156008', '8164002', '8168004', '8179009', '8184003', '8190004', '8202008', '8203003', '8204009', '8222007', '8227001', '8230008', '8237006', '8252004', '8257005', '8261004', '8268005', '8270001', '8275006', '8295000', '8300003', '8310007', '8313009', '8340009', '8342001', '8343006', '8354001', '8355000', '8362009', '8365006', '8368008', '8376005', '8385005', '8397006', '8406008', '8429000', '8450009', '8452001', '8456003', '8460000', '8473001', '8474007', '8484008', '8485009', '8486005', '8487001', '8491006', '8492004', '8498000', '8507001', '8514004', '8520003', '8525008', '8529002', '8534003', '8537005', '8578007', '8591008', '8612007', '8620009', '8631001', '8653004', '8660005', '8687009', '8689007', '8701002', '8705006', '8731008', '8740007', '8761000', '8767001', '8785008', '8786009', '8795001', '8817004', '8818009', '8822004', '8830003', '8836009', '8844009', '8858006', '8865003', '8878003', '8882001', '8886003', '8908003', '8914005', '8919000', '8926000', '8945009', '8953001', '8963009', '8969008', '8977007', '8982000', '8987006', '8991001', '9010006', '9013008', '9021002', '9024005', '9045003', '9052001', '9054000', '9103003', '9110009', '9125009', '9159008', '9172009', '9174005', '9183000', '9189001', '9195000', '9197008', '9205004', '9220005', '9223007', '9234005', '9246009', '9253000', '9270008', '9271007', '169008', '211009', '302007', '439007', '449005', '544002', '669007', '716000', '796001', '847003', '902003', '922004', '1039008', '1148001', '1182007', '1206000', '1222004', '1389007', '1434005', '1528001', '1552008', '1594006', '1613009', '1756009', '1758005', '1842003', '1878008', '1887004', '1982006', '2016004', '2037007', '2183004', '2190009', '2497003', '2571007', '2596005', '2679000', '2944000', '2949005', '3037004', '3046005', '3127006', '3221003', '3334000', '3361000', '3526007', '3593009', '3814009', '3822002', '4126008', '4194004', '4219002', '4220008', '4382004', '4704002', '4741001', '4753002', '4865009', '4937008', '5067008', '5465006', '5478006', '5487002', '5606003', '5720001', '5737008', '5776009', '5786005', '5797005', '5924003', '5975000', '6028009', '6067003', '6071000', '6102009', '6116004', '6122008', '6232005', '6247001', '6259002', '6369005', '6425004', '6517004', '6526001', '6625006', '6652001', '6716006', '6960003', '6985007', '7092007', '7140000', '7168001', '7230005', '7235000', '7292004', '7336002', '7561000', '7577004', '7624002', '7836006', '7947003', '7959004', '7982002', '8028001', '8109005', '8163008', '8348002', '8372007', '8416000', '8571001', '8658008', '8661009', '8692006', '8696009', '9190005', '9268004', '9307009', '9500005', '9542007', '9690006', '9745007', '9778000', '9944001', '10099000', '10135005', '10243007', '10312003', '10332002', '10355004', '10356003', '10368007', '10422008', '10504007', '10515002', '10555000', '10632007', '10668002', '10712001', '10756001', '10784006', '11185009', '11260008', '11402001', '11430001', '11563006', '11719000', '11777007', '11783005', '11796006', '11841005', '11847009', '11866009', '11959009', '12096000', '12236006', '12289007', '12335007', '12369008', '12425002', '12436009', '12495006', '12512008', '12559001', '12657005', '12839006', '12968008', '13132007', '13154009', '13178004', '13252002', '13414000', '13432000', '13512003', '13525006', '13565005', '13592004', '13664004', '13790009', '13800009', '13813003', '13929005', '13936006', '13965000', '14054003', '14103001', '14170004', '14542005', '14601000', '14706000', '14728000', '14745005', '14814001', '14816004', '15117003', '15222008', '15375005', '15383004', '15389000', '15432003', '15772006', '15857002', '16031005', '16037009', '16047007', '16131008', '16403005', '16602005', '16787005', '16791000', '16832004', '16858004', '16867004', '16970001', '16977003', '17016006', '17055007', '17308007', '17386008', '17502009', '17554004', '17558001', '17600005', '17805003', '17859000', '17893001', '18002004', '18125000', '18335001', '18340009', '18381001', '18511007', '18548003', '18679008', '18811003', '18914005', '18952006', '19194001', '19225000', '19232009', '19261005', '19315007', '19403009', '19405002', '19581007', '19583005', '19630009', '19768003', '19841008', '20091003', '20201001', '20237006', '20249007', '20303001', '20320002', '20577002', '20865003', '20969008', '21069002', '21159006', '21451004', '21691008', '21701005', '21767006', '21788002', '21986005', '22091006', '22168005', '22198003', '22274004', '22474002', '22587006', '22657006', '22672005', '22696000', '22801004', '22826008', '22969001', '23079006', '23222006', '23343005', '23532003', '23822003', '23827009', '23838009', '23888001', '24036003', '24450004', '24504000', '24866006', '24891006', '25014009', '25057004', '25076002', '25085002', '25142008', '25246002', '25398003', '25419009', '25465007', '25673006', '25716001', '25849001', '25860005', '25912006', '25995007', '26122009', '26124005', '26244009', '26303005', '26370007', '26456008', '26458009', '26462003', '26503009', '26523005', '26548008', '26574002', '26580005', '26736008', '26800000', '26842003', '27035007', '27085003', '27196008', '27242001', '27479000', '27518004', '27548001', '27566006', '27638005', '27658006', '27707001', '27754002', '27867009', '28028002', '28149003', '28235004', '28240007', '28410007', '28415002', '28426008', '28506006', '28748001', '28841002', '28906000', '29051009', '29058003', '29089004', '29121001', '29129004', '29156002', '29175007', '29237004', '29439004', '29620001', '29840005', '29877002', '29883004', '29896003', '29987004', '30010009', '30125007', '30306003', '30317002', '30427009', '30466001', '30492008', '30666008', '30729008', '30761007', '30964009', '30988006', '31025003', '31087008', '31181006', '31231007', '31305008', '31306009', '31352002', '31587003', '31684002', '31690003', '31692006', '31716004', '31865003', '31872002', '31970009', '32249005', '32313007', '32460003', '32462006', '32473004', '32474005', '32583002', '32647002', '32653002', '32792001', '32823007', '32841004', '32955006', '32960005', '33124007', '33133009', '33219003', '33231001', '33234009', '33236006', '33252009', '33378002', '33484000', '33588000', '33589008', '33664007', '33675006', '33682005', '33815001', '34012005', '34217006', '34364009', '34393009', '34462007', '34598001', '34599009', '34689006', '34693000', '34696008', '34731007', '34816007', '34833000', '34929006', '35035001', '35063004', '35097006', '35282000', '35300007', '35324004', '35392005', '35476001', '35531004', '35736007', '35768004', '35792007', '35967000', '35983000', '36068003', '36113004', '36168000', '36218003', '36236003', '36391008', '36537006', '36594001', '36621009', '36642006', '36763003', '36795002', '36893000', '36909007', '36940000', '36944009', '37084008', '37146000', '37306000', '37400007', '37628007', '37643009', '37773009', '37803001', '38076006', '38131009', '38166006', '38181000', '38231004', '38268001', '38314008', '38413003', '38578004', '38828006', '38900001', '39064002', '39124003', '39128000', '39142008', '39252001', '39359008', '39432004', '39487003', '39516004', '39598004', '39608003', '39707000', '39741008', '39860005', '39939003', '40162007', '40232005', '40339003', '40429005', '40430000', '40556005', '40562000', '40589005', '40606008', '40648001', '40652001', '40820003', '40877002', '40901001', '40905005', '40974005', '40999006', '41001009', '41015006', '41147003', '41193000', '41324009', '41365009', '41367001', '41399007', '41470001', '41493007', '41549009', '41985001', '42082003', '42098005', '42271003', '42348003', '42374009', '42444000', '42514000', '42638008', '42714002', '42720001', '42863006', '43343000', '43499003', '43533002', '43594006', '43684009', '43747001', '43753001', '43879000', '43927002', '44175000', '44418001', '44658005', '44731005', '44790008', '44798001', '44938006', '44990002', '45218006', '45311002', '45313004', '45355008', '45518007', '45680002', '45844004', '45888006', '45923000', '46009007', '46063005', '46123006', '46233009', '46436003', '46479001', '46532003', '46547007', '46576005', '46709004', '46741005', '46913003', '47065008', '47120002', '47124006', '47140009', '47331002', '47527007', '47602007', '47755009', '47772002', '47898004', '48028008', '48174005', '48256008', '48279009', '48351000', '48546005', '48603004', '48614001', '48647005', '48698004', '48836000', '48875009', '48899009', '49019002', '49157004', '49192007', '49267000', '49299006', '49485009', '49577002', '49590009', '49600008', '49617001', '49663007', '49669006', '49688004', '49694007', '49705006', '49802003', '49860008', '49953001', '49992008', '50094009', '50137001', '50182002', '50244000', '50256004', '50318003', '50335004', '50520001', '50841004', '50868004', '51013009', '51073002', '51103004', '51126006', '51132001', '51326002', '51334008', '51361008', '51425004', '51555009', '51752005', '51758009', '51779009', '51908007', '51992002', '52017007', '52108005', '52215008', '52388000', '52412009', '52423008', '52451004', '52489009', '52628005', '52761007', '52883001', '52896000', '53009005', '53480001', '53584007', '53640004', '53641000', '53691001', '53793005', '53800008', '53848009', '53855006', '54142000', '54344006', '54391004', '54406003', '54541002', '54544005', '54577009', '54659006', '54705000', '54765002', '54824008', '54882005', '54887004', '54972005', '54982006', '55015008', '55217007', '55432002', '55556000', '55673009', '55745002', '55782006', '55784007', '55830003', '55867006', '55889005', '56011005', '56014002', '56032002', '56059005', '56123002', '56230001', '56234005', '56240003', '56281006', '56480005', '56549003', '56602009', '56615000', '56656002', '56844000', '56928005', '56934003', '57002000', '57066004', '57123008', '57191001', '57263002', '57376006', '57538001', '57616006', '57670008', '57752001', '57811004', '57819002', '57845006', '57853003', '57893000', '57952007', '58050004', '58098008', '58360000', '58467001', '58502006', '58760003', '58805000', '58883005', '58892008', '58905004', '58944007', '59057006', '59187003', '59240002', '59245007', '59255006', '59261009', '59270007', '59456005', '59589008', '59594008', '59751001', '59799001', '59941008', '59953007', '59999009', '60090003', '60093001', '60149003', '60169008', '60468008', '60520004', '60533005', '60541005', '60682004', '60731009', '60767002', '60881009', '60972002', '60978003', '61020000', '61093008', '61123001', '61132004', '61153008', '61181002', '61408004', '61457001', '61602008', '61621000', '61623002', '61650007', '61651006', '61862008', '61939007', '61946003', '62051009', '62063004', '62191005', '62288001', '62294009', '62353003', '62354009', '62529008', '62560008', '62782004', '63094006', '63136007', '63318000', '63338004', '63470003', '63639004', '63682003', '63758001', '63822004', '64083002', '64115004', '64127001', '64240003', '64296005', '64349004', '64462001', '64558005', '64851009', '64878006', '65020006', '65026000', '65041000', '65092008', '65265006', '65461004', '65484006', '65502005', '65505007', '65627005', '65628000', '65638005', '65695006', '65823007', '65884003', '65965000', '66065008', '66094001', '66125007', '66243004', '66261008', '66349002', '66441000', '66492008', '66493003', '66602007', '66672008', '66742008', '66854004', '66859009', '66860004', '66919007', '66971004', '67213005', '67423003', '67440007', '67477004', '67507000', '67585005', '67735003', '67891001', '67939000', '68088000', '68113000', '68206008', '68208009', '68395000', '68398003', '68402007', '68407001', '68422006', '68424007', '68444001', '68461003', '68490009', '68622003', '68702006', '68774008', '68864001', '68887009', '68892006', '69107004', '69204002', '69227005', '69236009', '69242008', '69331001', '69431002', '69509008', '69576000', '69708003', '69801001', '69879000', '69918003', '69967001', '70047000', '70216000', '70254000', '70343008', '70379000', '70447008', '70460002', '70702006', '70776005', '70841003', '70864001', '70934008', '71181003', '71289008', '71338005', '71451001', '71453003', '71455005', '71462001', '71516007', '71584004', '71634000', '71699007', '71724000', '71731001', '71759000', '71770007', '71798005', '71837009', '72312007', '72398005', '72416006', '72623000', '72824008', '72870001', '72924009', '72968006', '72996000', '73074003', '73093001', '73133000', '73170009', '73212002', '73228007', '73274006', '73277004', '73454001', '73572009', '73585007', '73627008', '73639000', '73647000', '73756003', '73763003', '73805002', '73949004', '73986003', '74022005', '74065006', '74074008', '74147005', '74213004', '74226000', '74470007', '74480006', '74575000', '74583006', '74626007', '74632002', '74674007', '74771007', '74780007', '74782004', '74798006', '74819009', '75029008', '75201000', '75203002', '75292001', '75366006', '75429004', '75501004', '75661008', '75748004', '75770001', '75927008', '75959001', '75969007', '76058001', '76155001', '76286000', '76289007', '76385003', '76390000', '76591000', '76696004', '76759004', '76962009', '77035009', '77048008', '77237006', '77331005', '77390008', '77398001', '77549006', '77657003', '77731008', '77750008', '77856005', '77885004', '77898008', '78025001', '78057000', '78174002', '78379001', '78411008', '78439009', '78449007', '78507004', '78542000', '15911003', '25868003', '59037007', '61712006', '72354005', '91929009', '91930004', '91931000', '91932007', '91933002', '91934008', '91935009', '91936005', '91937001', '91938006', '91939003', '91940001', '188336009', '197493001', '197494007', '200848004', '213020009', '232346004', '232347008', '232348003', '232349006', '232350006', '235719002', '235720008', '292545003', '293580007', '293582004', '293583009', '293584003', '293585002', '293586001', '293587005', '293588000', '293589008', '293590004', '293591000', '293592007', '293593002', '293594008', '293595009', '293596005', '293597001', '293598006', '293599003', '293600000', '293601001', '293602008', '293603003', '293604009', '293605005', '293606006', '293607002', '293608007', '293609004', '293610009', '293611008', '293612001', '293613006', '293614000', '293615004', '293616003', '293617007', '293618002', '293619005', '293620004', '293621000', '293622007', '293623002', '293624008', '293625009', '293626005', '293627001', '293628006', '293629003', '293630008', '293631007', '293632000', '293633005', '293634004', '293635003', '293636002', '293637006', '293638001', '293639009', '293640006', '293641005', '293643008', '293644002', '293645001', '293646000', '293647009', '293648004', '293649007', '293650007', '293651006', '293652004', '293653009', '293654003', '293655002', '293656001', '293657005', '293658000', '293659008', '293660003', '293662006', '293663001', '293664007', '293665008', '293666009', '293667000', '293668005', '293669002', '293670001', '293671002', '293672009', '293673004', '293674005', '293675006', '293676007', '293677003', '293678008', '293679000', '293680002', '293681003', '293682005', '293683000', '293684006', '293685007', '293686008', '293687004', '293688009', '293689001', '293690005', '293691009', '293692002', '293693007', '293694001', '293695000', '293696004', '293697008', '293698003', '293699006', '293700007', '293701006', '293702004', '293703009', '293704003', '293705002', '293706001', '293707005', '293708000', '293709008', '293710003', '293711004', '293712006', '293713001', '293714007', '293715008', '293716009', '293717000', '293718005', '293719002', '293720008', '293721007', '293722000', '293723005', '293724004', '293725003', '293726002', '293727006', '293728001', '293730004', '293732007', '293733002', '293734008', '293735009', '293736005', '293737001', '293738006', '293739003', '293740001', '293741002', '293742009', '293743004', '293745006', '293746007', '293747003', '293748008', '293749000', '293750000', '293751001', '293752008', '293753003', '293754009', '293755005', '293756006', '293757002', '293758007', '293759004', '293760009', '293761008', '293762001', '293763006', '293764000', '293765004', '293766003', '293767007', '293768002', '293769005', '293770006', '293771005', '293772003', '293773008', '293774002', '293775001', '293776000', '293777009', '293778004', '293779007', '293780005', '293781009', '293782002', '293783007', '293784001', '293785000', '293786004', '293787008', '293788003', '293789006', '293790002', '293791003', '293792005', '293793000', '293794006', '293795007', '293796008', '293797004', '293798009', '293799001', '293800002', '293801003', '293802005', '293803000', '293804006', '293805007', '293806008', '293807004', '293808009', '293809001', '293810006', '293811005', '293812003', '293813008', '293814002', '293815001', '293816000', '293817009', '293818004', '293819007', '293821002', '293822009', '293823004', '293824005', '293825006', '293826007', '293827003', '293828008', '293829000', '293830005', '293831009', '293832002', '293833007', '293834001', '293835000', '293836004', '293837008', '293838003', '293839006', '293840008', '293841007', '293842000', '293843005', '293844004', '293845003', '293847006', '293848001', '293849009', '293850009', '293851008', '293852001', '293853006', '293854000', '293855004', '293856003', '293857007', '293858002', '293859005', '293860000', '293861001', '293862008', '293863003', '293864009', '293865005', '293866006', '293867002', '293868007', '293869004', '293870003', '293871004', '293873001', '293874007', '293875008', '293876009', '293877000', '293878005', '293879002', '293880004', '293881000', '293882007', '293883002', '293884008', '293885009', '293886005', '293887001', '293888006', '293889003', '293890007', '293891006', '293892004', '293893009', '293894003', '293895002', '293896001', '293897005', '293898000', '293899008', '293900003', '293901004', '293902006', '293903001', '293904007', '293905008', '293906009', '293907000', '293908005', '293909002', '293910007', '293911006', '293912004', '293913009', '293914003', '293915002', '293916001', '293917005', '293918000', '293919008', '293920002', '293921003', '293922005', '293923000', '293924006', '293925007', '293926008', '293927004', '293928009', '293929001', '293930006', '293931005', '293932003', '293933008', '293934002', '293935001', '293936000', '293937009', '293938004', '293939007', '293940009', '293941008', '293942001', '293943006', '293944000', '293945004', '293946003', '293948002', '293949005', '293950005', '293951009', '293952002', '293953007', '293954001', '293955000', '293956004', '293957008', '293958003', '293959006', '293960001', '293961002', '293962009', '293963004', '293964005', '293965006', '293966007', '293967003', '293968008', '293969000', '293970004', '293971000', '293972007', '293973002', '293974008', '293975009', '293976005', '293977001', '293978006', '293979003', '293980000', '293981001', '293982008', '293983003', '293984009', '293985005', '293986006', '293987002', '293988007', '293989004', '293990008', '293991007', '293992000', '293993005', '293994004', '293995003', '293996002', '293997006', '293998001', '293999009', '294000006', '294001005', '294002003', '294003008', '294004002', '294005001', '294006000', '294007009', '294008004', '294009007', '294010002', '294011003', '294012005', '294013000', '294014006', '294015007', '294016008', '294017004', '294018009', '294019001', '294020007', '294021006', '294022004', '294023009', '294024003', '294025002', '294026001', '294027005', '294028000', '294029008', '294030003', '294031004', '294032006', '294033001', '294035008', '294036009', '294037000', '294038005', '294039002', '294040000', '294041001', '294042008', '294043003', '294044009', '294045005', '294046006', '294047002', '294048007', '294050004', '294051000', '294052007', '294053002', '294054008', '294055009', '294056005', '294057001', '294058006', '294059003', '294060008', '294061007', '294062000', '294063005', '294064004', '294065003', '294066002', '294067006', '294068001', '294069009', '294070005', '294071009', '294072002', '294073007', '294074001', '294075000', '294076004', '294077008', '294078003', '294079006', '294080009', '294081008', '294082001', '294083006', '294084000', '294085004', '294086003', '294087007', '294088002', '294089005', '294090001', '294091002', '294092009', '294093004', '294094005', '294095006', '294096007', '294097003', '294098008', '294099000', '294100008', '294101007', '294102000', '294103005', '294104004', '294105003', '294106002', '294107006', '294108001', '294109009', '294110004', '294111000', '294112007', '294113002', '294114008', '294115009', '294116005', '294117001', '294118006', '294119003', '294120009', '294121008', '294122001', '294123006', '294124000', '294125004', '294126003', '294127007', '294128002', '294129005', '294130000', '294131001', '294132008', '294133003', '294134009', '294135005', '294136006', '294137002', '294138007', '294139004', '294140002', '294141003', '294142005', '294143000', '294144006', '294145007', '294146008', '294147004', '294148009', '294149001', '294151002', '294152009', '294153004', '294154005', '294155006', '294156007', '294157003', '294158008', '294159000', '294160005', '294161009', '294162002', '294163007', '294164001', '294165000', '294166004', '294167008', '294168003', '294169006', '294170007', '294171006', '294172004', '294173009', '294174003', '294175002', '294176001', '294177005', '294178000', '294179008', '294180006', '294181005', '294182003', '294183008', '294184002', '294185001', '294187009', '294188004', '294189007', '294190003', '294191004', '294192006', '294193001', '294194007', '294195008', '294196009', '294197000', '294198005', '294199002', '294200004', '294201000', '294202007', '294203002', '294204008', '294206005', '294207001', '294208006', '294209003', '294210008', '294211007', '294212000', '294213005', '294214004', '294215003', '294216002', '294217006', '294218001', '294219009', '294220003', '294221004', '294222006', '294223001', '294224007', '294225008', '294226009', '294227000', '294228005', '294229002', '294230007', '294231006', '294232004', '294233009', '294234003', '294235002', '294236001', '294237005', '294238000', '294239008', '294240005', '294241009', '294242002', '294243007', '294244001', '294245000', '294246004', '294247008', '294248003', '294249006', '294250006', '294252003', '294253008', '294254002', '294255001', '294256000', '294257009', '294258004', '294259007', '294260002', '294261003', '294262005', '294263000', '294264006', '294265007', '294266008', '294268009', '294269001', '294270000', '294271001', '294272008', '294273003', '294274009', '294275005', '294276006', '294277002', '294278007', '294279004', '294280001', '294281002', '294282009', '294283004', '294284005', '294285006', '294286007', '294287003', '294288008', '294289000', '294290009', '294291008', '294293006', '294295004', '294297007', '294298002', '294299005', '294300002', '294301003', '294302005', '294304006', '294306008', '294307004', '294308009', '294309001', '294310006', '294311005', '294312003', '294313008', '294315001', '294316000', '294317009', '294318004', '294319007', '294320001', '294321002', '294322009', '294324005', '294325006', '294326007', '294327003', '294328008', '294329000', '294330005', '294331009', '294332002', '294333007', '294334001', '294335000', '294336004', '294337008', '294339006', '294340008', '294341007', '294342000', '294343005', '294344004', '294346002', '294348001', '294349009', '294350009', '294351008', '294352001', '294354000', '294355004', '294356003', '294357007', '294358002', '294359005', '294360000', '294361001', '294362008', '294363003', '294364009', '294365005', '294366006', '294367002', '294368007', '294369004', '294370003', '294371004', '294372006', '294373001', '294374007', '294375008', '294376009', '294377000', '294378005', '294379002', '294380004', '294381000', '294382007', '294383002', '294384008', '294385009', '294386005', '294387001', '294388006', '294389003', '294390007', '294391006', '294392004', '294393009', '294394003', '294395002', '294396001', '294397005', '294398000', '294399008', '294400001', '294401002', '294402009', '294403004', '294404005', '294405006', '294406007', '294407003', '294408008', '294409000', '294410005', '294411009', '294412002', '294413007', '294414001', '294415000', '294416004', '294417008', '294418003', '294419006', '294420000', '294421001', '294422008', '294423003', '294425005', '294426006', '294427002', '294428007', '294429004', '294430009', '294431008', '294432001', '294433006', '294434000', '294435004', '294436003', '294437007', '294438002', '294439005', '294440007', '294441006', '294442004', '294443009', '294444003', '294445002', '294446001', '294447005', '294448000', '294449008', '294450008', '294451007', '294452000', '294453005', '294455003', '294456002', '294457006', '294458001', '294459009', '294460004', '294461000', '294462007', '294463002', '294464008', '294465009', '294466005', '294467001', '294468006', '294469003', '294470002', '294471003', '294472005', '294473000', '294474006', '294475007', '294476008', '294477004', '294478009', '294479001', '294480003', '294481004', '294482006', '294483001', '294484007', '294485008', '294486009', '294487000', '294488005', '294489002', '294490006', '294491005', '294492003', '294494002', '294495001', '294496000', '294497009', '294498004', '294499007', '294500003', '294501004', '294502006', '294503001', '294504007', '294505008', '294506009', '294507000', '294508005', '294509002', '294510007', '294511006', '294512004', '294513009', '294514003', '294515002', '294516001', '294517005', '294518000', '294519008', '294520002', '294521003', '294522005', '294523000', '294524006', '294525007', '294526008', '294527004', '294528009', '294529001', '294530006', '294531005', '294532003', '294533008', '294534002', '294535001', '294536000', '294537009', '294538004', '294539007', '294540009', '294541008', '294542001', '294543006', '294544000', '294545004', '294546003', '294547007', '294548002', '294549005', '294550005', '294551009', '294552002', '294554001', '294555000', '294556004', '294557008', '294558003', '294559006', '294560001', '294561002', '294562009', '294563004', '294564005', '294565006', '294566007', '294567003', '294568008', '294569000', '294570004', '294571000', '294572007', '294573002', '294574008', '294575009', '294576005', '294577001', '294578006', '294579003', '294580000', '294581001', '5388008', '25744000', '29512005', '38032004', '54250004', '60414003', '190751001', '52070001', '237978005', '700094005', '409137002', '428197003', '428607008', '429625007', '716184000', '716220001']}, 'type'=>'CodeableConcept', 'path'=>'AllergyIntolerance.code', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/allergyintolerance-code'}},
      'patient' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Patient'], 'type'=>'Reference', 'path'=>'AllergyIntolerance.patient', 'min'=>1, 'max'=>1},
      'encounter' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Encounter'], 'type'=>'Reference', 'path'=>'AllergyIntolerance.encounter', 'min'=>0, 'max'=>1},
      'onsetDateTime' => {'type'=>'dateTime', 'path'=>'AllergyIntolerance.onset[x]', 'min'=>0, 'max'=>1},
      'onsetAge' => {'type'=>'Age', 'path'=>'AllergyIntolerance.onset[x]', 'min'=>0, 'max'=>1},
      'onsetPeriod' => {'type'=>'Period', 'path'=>'AllergyIntolerance.onset[x]', 'min'=>0, 'max'=>1},
      'onsetRange' => {'type'=>'Range', 'path'=>'AllergyIntolerance.onset[x]', 'min'=>0, 'max'=>1},
      'onsetString' => {'type'=>'string', 'path'=>'AllergyIntolerance.onset[x]', 'min'=>0, 'max'=>1},
      'recordedDate' => {'type'=>'dateTime', 'path'=>'AllergyIntolerance.recordedDate', 'min'=>0, 'max'=>1},
      'recorder' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Practitioner', 'http://hl7.org/fhir/StructureDefinition/PractitionerRole', 'http://hl7.org/fhir/StructureDefinition/Patient', 'http://hl7.org/fhir/StructureDefinition/RelatedPerson'], 'type'=>'Reference', 'path'=>'AllergyIntolerance.recorder', 'min'=>0, 'max'=>1},
      'asserter' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Patient', 'http://hl7.org/fhir/StructureDefinition/RelatedPerson', 'http://hl7.org/fhir/StructureDefinition/Practitioner', 'http://hl7.org/fhir/StructureDefinition/PractitionerRole'], 'type'=>'Reference', 'path'=>'AllergyIntolerance.asserter', 'min'=>0, 'max'=>1},
      'lastOccurrence' => {'type'=>'dateTime', 'path'=>'AllergyIntolerance.lastOccurrence', 'min'=>0, 'max'=>1},
      'note' => {'type'=>'Annotation', 'path'=>'AllergyIntolerance.note', 'min'=>0, 'max'=>Float::INFINITY},
      'reaction' => {'type'=>'AllergyIntolerance::Reaction', 'path'=>'AllergyIntolerance.reaction', 'min'=>0, 'max'=>Float::INFINITY}
    }

    class Reaction < FHIR::Model
      include FHIR::Hashable
      include FHIR::Json
      include FHIR::Xml

      METADATA = {
        'id' => {'type'=>'string', 'path'=>'Reaction.id', 'min'=>0, 'max'=>1},
        'extension' => {'type'=>'Extension', 'path'=>'Reaction.extension', 'min'=>0, 'max'=>Float::INFINITY},
        'modifierExtension' => {'type'=>'Extension', 'path'=>'Reaction.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
        'substance' => {'valid_codes'=>{'http://snomed.info/sct'=>['102002', '120006', '125001', '126000', '130002', '131003', '159002', '164003', '178002', '186002', '187006', '200001', '217008', '231008', '238002', '261000', '296000', '322006', '327000', '329002', '336001', '340005', '363000', '370000', '371001', '377002', '392001', '395004', '412004', '424006', '425007', '432003', '438004', '462009', '472007', '476005', '498001', '501001', '505005', '506006', '515004', '519005', '521000', '529003', '538001', '566009', '576007', '578008', '584006', '585007', '591009', '593007', '594001', '597008', '604000', '611001', '620005', '648005', '662003', '668004', '683009', '686001', '693002', '698006', '699003', '704006', '732002', '735000', '747006', '773001', '785009', '804003', '819002', '850000', '859004', '860009', '873008', '876000', '877009', '889006', '896008', '905001', '923009', '925002', '963005', '974001', '979006', '993004', '1002007', '1010008', '1018001', '1025008', '1047008', '1050006', '1057009', '1065007', '1080001', '1091008', '1097007', '1105007', '1113008', '1137008', '1149009', '1160000', '1166006', '1169004', '1171004', '1185009', '1189003', '1190007', '1219001', '1223009', '1244009', '1248007', '1269009', '1272002', '1273007', '1313002', '1319003', '1320009', '1325004', '1331001', '1334009', '1336006', '1341003', '1346008', '1355006', '1368003', '1371006', '1373009', '1381005', '1394007', '1396009', '1405004', '1408002', '1416006', '1450002', '1466000', '1471007', '1472000', '1476002', '1477006', '1496005', '1506001', '1517000', '1530004', '1535009', '1536005', '1540001', '1545006', '1557002', '1565004', '1575001', '1603001', '1607000', '1609002', '1634002', '1649005', '1656004', '1660001', '1668008', '1672007', '1673002', '1675009', '1676005', '1681001', '1696002', '1701009', '1710001', '1726000', '1727009', '1740004', '1764003', '1768000', '1786002', '1793003', '1795005', '1798007', '1799004', '1823002', '1827001', '1886008', '1904005', '1914001', '1916004', '1940007', '1944003', '1956002', '1971003', '1975007', '1978009', '1985008', '1991005', '2000001', '2006007', '2008008', '2009000', '2017008', '2027002', '2029004', '2038002', '2039005', '2050008', '2064008', '2082006', '2085008', '2088005', '2096000', '2100004', '2101000', '2125008', '2130007', '2141009', '2147008', '2151005', '2154002', '2159007', '2163000', '2168009', '2179004', '2189000', '2194000', '2195004', '2197007', '2201007', '2208001', '2212007', '2215009', '2240002', '2249001', '2254005', '2260005', '2262002', '2264001', '2309006', '2311002', '2329007', '2331003', '2338009', '2343002', '2346005', '2354007', '2358005', '2369008', '2370009', '2376003', '2384004', '2404002', '2405001', '2414006', '2430003', '2431004', '2441001', '2444009', '2450004', '2462000', '2466002', '2500009', '2509005', '2516006', '2522002', '2529006', '2537003', '2568004', '2573005', '2575003', '2595009', '2597001', '2611008', '2637006', '2648004', '2649007', '2660003', '2671002', '2674005', '2676007', '2678008', '2680002', '2698003', '2705002', '2706001', '2719002', '2721007', '2728001', '2753003', '2754009', '2765004', '2778004', '2796008', '2799001', '2823004', '2832002', '2846002', '2869004', '2878005', '2880004', '2883002', '2913009', '2916001', '2925007', '2927004', '2938004', '2942001', '2950005', '2958003', '2964005', '2974008', '2988007', '2991007', '2995003', '3027009', '3031003', '3040004', '3045009', '3052006', '3066001', '3070009', '3087006', '3107005', '3108000', '3131000', '3136005', '3142009', '3145006', '3150000', '3151001', '3155005', '3161008', '3167007', '3187008', '3193000', '3197004', '3209002', '3212004', '3225007', '3232003', '3271000', '3273002', '3300001', '3318003', '3325005', '3339005', '3340007', '3342004', '3346001', '3378009', '3379001', '3392003', '3405005', '3411008', '3437006', '3440006', '3455002', '3463001', '3465008', '3466009', '3492002', '3493007', '3495000', '3501003', '3523004', '3532002', '3555004', '3579002', '3581000', '3587001', '3588006', '3592004', '3597005', '3601005', '3602003', '3610002', '3617004', '3648007', '3655009', '3672002', '3684000', '3689005', '3692009', '3693004', '3702007', '3710008', '3718001', '3726009', '3727000', '3730007', '3737005', '3742002', '3757009', '3771001', '3775005', '3776006', '3792001', '3793006', '3800009', '3807007', '3811001', '3812008', '3816006', '3823007', '3829006', '3834005', '3836007', '3844007', '3848005', '3849002', '3854006', '3874004', '3892007', '3896005', '3897001', '3906002', '3920009', '3930000', '3932008', '3941003', '3945007', '3958008', '3961009', '3976001', '3982003', '3983008', '3990003', '3994007', '4014000', '4024008', '4025009', '4043008', '4047009', '4048004', '4067000', '4076007', '4077003', '4080002', '4091009', '4097008', '4104007', '4105008', '4115002', '4137009', '4153007', '4167003', '4169000', '4177001', '4182008', '4188007', '4200007', '4201006', '4203009', '4207005', '4217000', '4218005', '4231000', '4239003', '4255005', '4289006', '4290002', '4314009', '4334005', '4342006', '4353000', '4355007', '4362003', '4370008', '4393002', '4401009', '4413004', '4422003', '4423008', '4425001', '4435007', '4437004', '4471008', '4479005', '4480008', '4509009', '4518006', '4534009', '4540002', '4546008', '4555006', '4560005', '4561009', '4564001', '4567008', '4582003', '4591004', '4610008', '4616002', '4629002', '4635002', '4643007', '4656000', '4674009', '4681002', '4693006', '4700006', '4706000', '4714006', '4728000', '4731004', '4732006', '4746006', '4761007', '4762000', '4777008', '4780009', '4786003', '4789005', '4793004', '4814001', '4824009', '4825005', '4831008', '4832001', '4833006', '4844003', '4864008', '4872005', '4878009', '4882006', '4889002', '4901003', '4925006', '4933007', '4940008', '4955004', '4962008', '4963003', '4965005', '4968007', '4986005', '5003005', '5004004', '5007006', '5024000', '5031001', '5040002', '5043000', '5045007', '5059000', '5060005', '5061009', '5064001', '5081005', '5086000', '5094007', '5098005', '5109006', '5142007', '5160007', '5163009', '5167005', '5172001', '5179005', '5200001', '5206007', '5220000', '5226006', '5250008', '5252000', '5253005', '5259009', '5289002', '5303002', '5305009', '5307001', '5312000', '5323001', '5330007', '5339008', '5340005', '5392001', '5395004', '5404007', '5405008', '5406009', '5420002', '5439007', '5442001', '5453007', '5471000', '5474008', '5477001', '5483003', '5504009', '5511008', '5513006', '5515004', '5533005', '5537006', '5540006', '5547009', '5548004', '5568005', '5573004', '5589001', '5590005', '5628003', '5629006', '5637003', '5641004', '5647000', '5656008', '5657004', '5659001', '5670008', '5681006', '5691000', '5692007', '5699003', '5700002', '5702005', '5704006', '5705007', '5739006', '5746002', '5757007', '5762008', '5764009', '5767002', '5774007', '5800007', '5813001', '5826002', '5827006', '5829009', '5830004', '5840001', '5858007', '5863006', '5896008', '5899001', '5907009', '5910002', '5915007', '5927005', '5931004', '5932006', '5950004', '5955009', '5977008', '5989005', '5991002', '6021003', '6038004', '6043006', '6044000', '6054001', '6056004', '6068008', '6083003', '6085005', '6088007', '6089004', '6091007', '6107003', '6109000', '6115000', '6135004', '6138002', '6162007', '6170002', '6172005', '6178009', '6179001', '6182006', '6197009', '6237004', '6249003', '6256009', '6257000', '6260007', '6261006', '6263009', '6264003', '6287006', '6291001', '6301006', '6310003', '6314007', '6333002', '6338006', '6356006', '6360009', '6367007', '6386004', '6394006', '6401007', '6409009', '6411000', '6422001', '6451002', '6455006', '6469006', '6478000', '6495008', '6507009', '6513000', '6516008', '6524003', '6529008', '6532006', '6590001', '6592009', '6602005', '6611005', '6612003', '6619007', '6642000', '6644004', '6671004', '6672006', '6699008', '6701008', '6702001', '6709005', '6710000', '6713003', '6717002', '6725000', '6730001', '6741004', '6755007', '6786001', '6790004', '6792007', '6808006', '6809003', '6814004', '6817006', '6826009', '6837005', '6854002', '6865007', '6873003', '6879004', '6881002', '6884005', '6890009', '6896003', '6910009', '6911008', '6916003', '6924008', '6925009', '6927001', '6937006', '6945001', '6952004', '6958000', '6961004', '6970001', '6973004', '6983000', '6992002', '6993007', '6999006', '7008002', '7018007', '7029006', '7030001', '7034005', '7045008', '7047000', '7049002', '7054006', '7056008', '7059001', '7061005', '7070008', '7084003', '7110002', '7120007', '7132006', '7139002', '7146006', '7152007', '7156005', '7158006', '7161007', '7179006', '7191002', '7208009', '7211005', '7237008', '7243005', '7269004', '7271004', '7280004', '7281000', '7284008', '7294003', '7302008', '7318002', '7321000', '7325009', '7327001', '7328006', '7330008', '7337006', '7348004', '7382005', '7401000', '7411007', '7427000', '7434003', '7446004', '7451005', '7460002', '7470000', '7489000', '7503004', '7509000', '7515000', '7537007', '7547005', '7549008', '7588005', '7608003', '7616007', '7648006', '7661006', '7670009', '7675004', '7679005', '7685003', '7696006', '7716001', '7737009', '7738004', '7761002', '7770004', '7774008', '7779003', '7785005', '7790008', '7791007', '7795003', '7801007', '7816005', '7834009', '7846008', '7848009', '7868003', '7879008', '7900007', '7904003', '7909008', '7924004', '7938006', '7945006', '7948008', '7953003', '7957002', '7961008', '7970006', '7974002', '7975001', '7979007', '7983007', '7985000', '7997004', '8000007', '8002004', '8025003', '8029009', '8030004', '8035009', '8048008', '8054009', '8055005', '8105004', '8108002', '8123007', '8132009', '8143001', '8153000', '8156008', '8164002', '8168004', '8179009', '8184003', '8190004', '8202008', '8203003', '8204009', '8222007', '8227001', '8230008', '8237006', '8252004', '8257005', '8261004', '8268005', '8270001', '8275006', '8295000', '8300003', '8310007', '8313009', '8340009', '8342001', '8343006', '8354001', '8355000', '8362009', '8365006', '8368008', '8376005', '8385005', '8397006', '8406008', '8429000', '8450009', '8452001', '8456003', '8460000', '8473001', '8474007', '8484008', '8485009', '8486005', '8487001', '8491006', '8492004', '8498000', '8507001', '8514004', '8520003', '8525008', '8529002', '8534003', '8537005', '8578007', '8591008', '8612007', '8620009', '8631001', '8653004', '8660005', '8687009', '8689007', '8701002', '8705006', '8731008', '8740007', '8761000', '8767001', '8785008', '8786009', '8795001', '8817004', '8818009', '8822004', '8830003', '8836009', '8844009', '8858006', '8865003', '8878003', '8882001', '8886003', '8908003', '8914005', '8919000', '8926000', '8945009', '8953001', '8963009', '8969008', '8977007', '8982000', '8987006', '8991001', '9010006', '9013008', '9021002', '9024005', '9045003', '9052001', '9054000', '9103003', '9110009', '9125009', '9159008', '9172009', '9174005', '9183000', '9189001', '9195000', '9197008', '9205004', '9220005', '9223007', '9234005', '9246009', '9253000', '9270008', '9271007', '169008', '211009', '302007', '439007', '449005', '544002', '669007', '716000', '796001', '847003', '902003', '922004', '1039008', '1148001', '1182007', '1206000', '1222004', '1389007', '1434005', '1528001', '1552008', '1594006', '1613009', '1756009', '1758005', '1842003', '1878008', '1887004', '1982006', '2016004', '2037007', '2183004', '2190009', '2497003', '2571007', '2596005', '2679000', '2944000', '2949005', '3037004', '3046005', '3127006', '3221003', '3334000', '3361000', '3526007', '3593009', '3814009', '3822002', '4126008', '4194004', '4219002', '4220008', '4382004', '4704002', '4741001', '4753002', '4865009', '4937008', '5067008', '5465006', '5478006', '5487002', '5606003', '5720001', '5737008', '5776009', '5786005', '5797005', '5924003', '5975000', '6028009', '6067003', '6071000', '6102009', '6116004', '6122008', '6232005', '6247001', '6259002', '6369005', '6425004', '6517004', '6526001', '6625006', '6652001', '6716006', '6960003', '6985007', '7092007', '7140000', '7168001', '7230005', '7235000', '7292004', '7336002', '7561000', '7577004', '7624002', '7836006', '7947003', '7959004', '7982002', '8028001', '8109005', '8163008', '8348002', '8372007', '8416000', '8571001', '8658008', '8661009', '8692006', '8696009', '9190005', '9268004', '9307009', '9500005', '9542007', '9690006', '9745007', '9778000', '9944001', '10099000', '10135005', '10243007', '10312003', '10332002', '10355004', '10356003', '10368007', '10422008', '10504007', '10515002', '10555000', '10632007', '10668002', '10712001', '10756001', '10784006', '11185009', '11260008', '11402001', '11430001', '11563006', '11719000', '11777007', '11783005', '11796006', '11841005', '11847009', '11866009', '11959009', '12096000', '12236006', '12289007', '12335007', '12369008', '12425002', '12436009', '12495006', '12512008', '12559001', '12657005', '12839006', '12968008', '13132007', '13154009', '13178004', '13252002', '13414000', '13432000', '13512003', '13525006', '13565005', '13592004', '13664004', '13790009', '13800009', '13813003', '13929005', '13936006', '13965000', '14054003', '14103001', '14170004', '14542005', '14601000', '14706000', '14728000', '14745005', '14814001', '14816004', '15117003', '15222008', '15375005', '15383004', '15389000', '15432003', '15772006', '15857002', '16031005', '16037009', '16047007', '16131008', '16403005', '16602005', '16787005', '16791000', '16832004', '16858004', '16867004', '16970001', '16977003', '17016006', '17055007', '17308007', '17386008', '17502009', '17554004', '17558001', '17600005', '17805003', '17859000', '17893001', '18002004', '18125000', '18335001', '18340009', '18381001', '18511007', '18548003', '18679008', '18811003', '18914005', '18952006', '19194001', '19225000', '19232009', '19261005', '19315007', '19403009', '19405002', '19581007', '19583005', '19630009', '19768003', '19841008', '20091003', '20201001', '20237006', '20249007', '20303001', '20320002', '20577002', '20865003', '20969008', '21069002', '21159006', '21451004', '21691008', '21701005', '21767006', '21788002', '21986005', '22091006', '22168005', '22198003', '22274004', '22474002', '22587006', '22657006', '22672005', '22696000', '22801004', '22826008', '22969001', '23079006', '23222006', '23343005', '23532003', '23822003', '23827009', '23838009', '23888001', '24036003', '24450004', '24504000', '24866006', '24891006', '25014009', '25057004', '25076002', '25085002', '25142008', '25246002', '25398003', '25419009', '25465007', '25673006', '25716001', '25849001', '25860005', '25912006', '25995007', '26122009', '26124005', '26244009', '26303005', '26370007', '26456008', '26458009', '26462003', '26503009', '26523005', '26548008', '26574002', '26580005', '26736008', '26800000', '26842003', '27035007', '27085003', '27196008', '27242001', '27479000', '27518004', '27548001', '27566006', '27638005', '27658006', '27707001', '27754002', '27867009', '28028002', '28149003', '28235004', '28240007', '28410007', '28415002', '28426008', '28506006', '28748001', '28841002', '28906000', '29051009', '29058003', '29089004', '29121001', '29129004', '29156002', '29175007', '29237004', '29439004', '29620001', '29840005', '29877002', '29883004', '29896003', '29987004', '30010009', '30125007', '30306003', '30317002', '30427009', '30466001', '30492008', '30666008', '30729008', '30761007', '30964009', '30988006', '31025003', '31087008', '31181006', '31231007', '31305008', '31306009', '31352002', '31587003', '31684002', '31690003', '31692006', '31716004', '31865003', '31872002', '31970009', '32249005', '32313007', '32460003', '32462006', '32473004', '32474005', '32583002', '32647002', '32653002', '32792001', '32823007', '32841004', '32955006', '32960005', '33124007', '33133009', '33219003', '33231001', '33234009', '33236006', '33252009', '33378002', '33484000', '33588000', '33589008', '33664007', '33675006', '33682005', '33815001', '34012005', '34217006', '34364009', '34393009', '34462007', '34598001', '34599009', '34689006', '34693000', '34696008', '34731007', '34816007', '34833000', '34929006', '35035001', '35063004', '35097006', '35282000', '35300007', '35324004', '35392005', '35476001', '35531004', '35736007', '35768004', '35792007', '35967000', '35983000', '36068003', '36113004', '36168000', '36218003', '36236003', '36391008', '36537006', '36594001', '36621009', '36642006', '36763003', '36795002', '36893000', '36909007', '36940000', '36944009', '37084008', '37146000', '37306000', '37400007', '37628007', '37643009', '37773009', '37803001', '38076006', '38131009', '38166006', '38181000', '38231004', '38268001', '38314008', '38413003', '38578004', '38828006', '38900001', '39064002', '39124003', '39128000', '39142008', '39252001', '39359008', '39432004', '39487003', '39516004', '39598004', '39608003', '39707000', '39741008', '39860005', '39939003', '40162007', '40232005', '40339003', '40429005', '40430000', '40556005', '40562000', '40589005', '40606008', '40648001', '40652001', '40820003', '40877002', '40901001', '40905005', '40974005', '40999006', '41001009', '41015006', '41147003', '41193000', '41324009', '41365009', '41367001', '41399007', '41470001', '41493007', '41549009', '41985001', '42082003', '42098005', '42271003', '42348003', '42374009', '42444000', '42514000', '42638008', '42714002', '42720001', '42863006', '43343000', '43499003', '43533002', '43594006', '43684009', '43747001', '43753001', '43879000', '43927002', '44175000', '44418001', '44658005', '44731005', '44790008', '44798001', '44938006', '44990002', '45218006', '45311002', '45313004', '45355008', '45518007', '45680002', '45844004', '45888006', '45923000', '46009007', '46063005', '46123006', '46233009', '46436003', '46479001', '46532003', '46547007', '46576005', '46709004', '46741005', '46913003', '47065008', '47120002', '47124006', '47140009', '47331002', '47527007', '47602007', '47755009', '47772002', '47898004', '48028008', '48174005', '48256008', '48279009', '48351000', '48546005', '48603004', '48614001', '48647005', '48698004', '48836000', '48875009', '48899009', '49019002', '49157004', '49192007', '49267000', '49299006', '49485009', '49577002', '49590009', '49600008', '49617001', '49663007', '49669006', '49688004', '49694007', '49705006', '49802003', '49860008', '49953001', '49992008', '50094009', '50137001', '50182002', '50244000', '50256004', '50318003', '50335004', '50520001', '50841004', '50868004', '51013009', '51073002', '51103004', '51126006', '51132001', '51326002', '51334008', '51361008', '51425004', '51555009', '51752005', '51758009', '51779009', '51908007', '51992002', '52017007', '52108005', '52215008', '52388000', '52412009', '52423008', '52451004', '52489009', '52628005', '52761007', '52883001', '52896000', '53009005', '53480001', '53584007', '53640004', '53641000', '53691001', '53793005', '53800008', '53848009', '53855006', '54142000', '54344006', '54391004', '54406003', '54541002', '54544005', '54577009', '54659006', '54705000', '54765002', '54824008', '54882005', '54887004', '54972005', '54982006', '55015008', '55217007', '55432002', '55556000', '55673009', '55745002', '55782006', '55784007', '55830003', '55867006', '55889005', '56011005', '56014002', '56032002', '56059005', '56123002', '56230001', '56234005', '56240003', '56281006', '56480005', '56549003', '56602009', '56615000', '56656002', '56844000', '56928005', '56934003', '57002000', '57066004', '57123008', '57191001', '57263002', '57376006', '57538001', '57616006', '57670008', '57752001', '57811004', '57819002', '57845006', '57853003', '57893000', '57952007', '58050004', '58098008', '58360000', '58467001', '58502006', '58760003', '58805000', '58883005', '58892008', '58905004', '58944007', '59057006', '59187003', '59240002', '59245007', '59255006', '59261009', '59270007', '59456005', '59589008', '59594008', '59751001', '59799001', '59941008', '59953007', '59999009', '60090003', '60093001', '60149003', '60169008', '60468008', '60520004', '60533005', '60541005', '60682004', '60731009', '60767002', '60881009', '60972002', '60978003', '61020000', '61093008', '61123001', '61132004', '61153008', '61181002', '61408004', '61457001', '61602008', '61621000', '61623002', '61650007', '61651006', '61862008', '61939007', '61946003', '62051009', '62063004', '62191005', '62288001', '62294009', '62353003', '62354009', '62529008', '62560008', '62782004', '63094006', '63136007', '63318000', '63338004', '63470003', '63639004', '63682003', '63758001', '63822004', '64083002', '64115004', '64127001', '64240003', '64296005', '64349004', '64462001', '64558005', '64851009', '64878006', '65020006', '65026000', '65041000', '65092008', '65265006', '65461004', '65484006', '65502005', '65505007', '65627005', '65628000', '65638005', '65695006', '65823007', '65884003', '65965000', '66065008', '66094001', '66125007', '66243004', '66261008', '66349002', '66441000', '66492008', '66493003', '66602007', '66672008', '66742008', '66854004', '66859009', '66860004', '66919007', '66971004', '67213005', '67423003', '67440007', '67477004', '67507000', '67585005', '67735003', '67891001', '67939000', '68088000', '68113000', '68206008', '68208009', '68395000', '68398003', '68402007', '68407001', '68422006', '68424007', '68444001', '68461003', '68490009', '68622003', '68702006', '68774008', '68864001', '68887009', '68892006', '69107004', '69204002', '69227005', '69236009', '69242008', '69331001', '69431002', '69509008', '69576000', '69708003', '69801001', '69879000', '69918003', '69967001', '70047000', '70216000', '70254000', '70343008', '70379000', '70447008', '70460002', '70702006', '70776005', '70841003', '70864001', '70934008', '71181003', '71289008', '71338005', '71451001', '71453003', '71455005', '71462001', '71516007', '71584004', '71634000', '71699007', '71724000', '71731001', '71759000', '71770007', '71798005', '71837009', '72312007', '72398005', '72416006', '72623000', '72824008', '72870001', '72924009', '72968006', '72996000', '73074003', '73093001', '73133000', '73170009', '73212002', '73228007', '73274006', '73277004', '73454001', '73572009', '73585007', '73627008', '73639000', '73647000', '73756003', '73763003', '73805002', '73949004', '73986003', '74022005', '74065006', '74074008', '74147005', '74213004', '74226000', '74470007', '74480006', '74575000', '74583006', '74626007', '74632002', '74674007', '74771007', '74780007', '74782004', '74798006', '74819009', '75029008', '75201000', '75203002', '75292001', '75366006', '75429004', '75501004', '75661008', '75748004', '75770001', '75927008', '75959001', '75969007', '76058001', '76155001', '76286000', '76289007', '76385003', '76390000', '76591000', '76696004', '76759004', '76962009', '77035009', '77048008', '77237006', '77331005', '77390008', '77398001', '77549006', '77657003', '77731008', '77750008', '77856005', '77885004', '77898008', '78025001', '78057000', '78174002', '78379001', '78411008', '78439009', '78449007', '78507004', '78542000']}, 'type'=>'CodeableConcept', 'path'=>'Reaction.substance', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/substance-code'}},
        'manifestation' => {'valid_codes'=>{'http://snomed.info/sct'=>['109006', '122003', '127009', '129007', '134006', '140004', '144008', '147001', '150003', '151004', '162004', '165002', '168000', '171008', '172001', '175004', '177007', '179005', '181007', '183005', '184004', '188001', '192008', '193003', '195005', '198007', '199004', '208008', '216004', '219006', '222008', '223003', '228007', '241006', '242004', '253005', '257006', '258001', '264008', '276008', '279001', '281004', '282006', '290006', '292003', '297009', '299007', '303002', '308006', '310008', '313005', '317006', '320003', '324007', '330007', '335002', '341009', '349006', '355001', '357009', '358004', '359007', '360002', '364006', '366008', '368009', '369001', '378007', '382009', '383004', '385006', '387003', '398002', '407000', '408005', '409002', '426008', '431005', '437009', '440009', '442001', '443006', '447007', '450005', '452002', '460001', '467003', '470004', '479003', '486006', '488007', '490008', '496002', '504009', '517007', '518002', '520004', '527001', '536002', '539009', '547009', '548004', '554003', '555002', '563001', '568005', '586008', '590005', '596004', '599006', '600009', '602001', '607007', '610000', '613003', '615005', '616006', '626004', '631002', '634005', '640003', '643001', '646009', '649002', '651003', '652005', '655007', '658009', '663008', '664002', '666000', '675003', '682004', '685002', '701003', '703000', '714002', '715001', '718004', '733007', '734001', '736004', '750009', '755004', '756003', '758002', '775008', '776009', '781000', '786005', '787001', '788006', '792004', '799008', '801006', '805002', '811004', '813001', '815008', '816009', '818005', '825003', '827006', '832007', '834008', '841002', '842009', '843004', '844005', '845006', '849000', '857002', '862001', '865004', '871005', '874002', '875001', '888003', '890002', '899001', '903008', '904002', '908004', '919001', '928000', '931004', '932006', '934007', '943003', '954008', '961007', '962000', '964004', '965003', '975000', '978003', '981008', '984000', '987007', '991002', '998008', '1003002', '1020003', '1023001', '1027000', '1031006', '1033009', '1034003', '1038000', '1045000', '1046004', '1051005', '1055001', '1059007', '1070000', '1073003', '1074009', '1077002', '1079004', '1085006', '1089000', '1102005', '1107004', '1108009', '1111005', '1112003', '1116000', '1124005', '1125006', '1126007', '1131009', '1134001', '1135000', '1139006', '1140008', '1141007', '1145003', '1150009', '1151008', '1152001', '1155004', '1156003', '1168007', '1184008', '1192004', '1194003', '1196001', '1197005', '1201005', '1203008', '1207009', '1208004', '1212005', '1214006', '1230003', '1232006', '1239002', '1240000', '1259003', '1261007', '1264004', '1271009', '1280009', '1282001', '1283006', '1284000', '1286003', '1287007', '1297003', '1308001', '1310004', '1317001', '1318006', '1323006', '1332008', '1335005', '1343000', '1345007', '1351002', '1356007', '1361009', '1363007', '1367008', '1370007', '1372004', '1376001', '1378000', '1380006', '1383008', '1384002', '1386000', '1387009', '1388004', '1393001', '1395008', '1402001', '1412008', '1415005', '1418007', '1419004', '1426004', '1427008', '1430001', '1447000', '1469007', '1474004', '1475003', '1478001', '1479009', '1482004', '1486001', '1488000', '1489008', '1492007', '1493002', '1499003', '1512006', '1515008', '1518005', '1519002', '1521007', '1523005', '1525003', '1531000', '1532007', '1534008', '1538006', '1539003', '1542009', '1544005', '1551001', '1556006', '1563006', '1567007', '1588003', '1592005', '1593000', '1606009', '1608005', '1639007', '1647007', '1648002', '1654001', '1657008', '1658003', '1663004', '1667003', '1670004', '1671000', '1674008', '1679003', '1682008', '1685005', '1686006', '1694004', '1698001', '1703007', '1705000', '1708003', '1714005', '1717003', '1723008', '1724002', '1734006', '1735007', '1739001', '1742007', '1744008', '1748006', '1755008', '1761006', '1763009', '1767005', '1769008', '1771008', '1776003', '1777007', '1778002', '1779005', '1794009', '1816003', '1821000', '1822007', '1824008', '1826005', '1828006', '1829003', '1833005', '1835003', '1837006', '1845001', '1847009', '1848004', '1852004', '1855002', '1856001', '1857005', '1858000', '1860003', '1865008', '1869002', '1881003', '1892002', '1896004', '1897008', '1899006', '1903004', '1908008', '1909000', '1922008', '1926006', '1938002', '1939005', '1943009', '1953005', '1954004', '1955003', '1959009', '1961000', '1963002', '1965009', '1967001', '1973000', '1977004', '1979001', '1980003', '1981004', '1988005', '1989002', '2004005', '2012002', '2024009', '2028007', '2032001', '2036003', '2040007', '2041006', '2043009', '2053005', '2055003', '2058001', '2061000', '2065009', '2066005', '2070002', '2073000', '2087000', '2089002', '2091005', '2094002', '2102007', '2103002', '2107001', '2109003', '2114004', '2116002', '2120003', '2121004', '2128005', '2129002', '2132004', '2134003', '2136001', '2138000', '2145000', '2149006', '2158004', '2167004', '2169001', '2170000', '2176006', '2177002', '2186007', '2198002', '2202000', '2204004', '2213002', '2216005', '2217001', '2219003', '2224000', '2228002', '2229005', '2231001', '2237002', '2239004', '2241003', '2243000', '2245007', '2251002', '2256007', '2261009', '2268003', '2284002', '2295008', '2296009', '2298005', '2301009', '2303007', '2304001', '2307008', '2308003', '2312009', '2314005', '2326000', '2339001', '2341000', '2351004', '2355008', '2359002', '2365002', '2366001', '2367005', '2374000', '2385003', '2388001', '2390000', '2391001', '2396006', '2398007', '2403008', '2415007', '2418009', '2419001', '2420007', '2432006', '2435008', '2437000', '2438005', '2439002', '2443003', '2452007', '2463005', '2469009', '2470005', '2471009', '2472002', '2473007', '2477008', '2492009', '2495006', '2496007', '2506003', '2513003', '2518007', '2521009', '2523007', '2526004', '2528003', '2532009', '2534005', '2538008', '2541004', '2554006', '2556008', '2560006', '2562003', '2576002', '2581006', '2582004', '2583009', '2584003', '2585002', '2589008', '2591000', '2593002', '2602008', '2606006', '2615004', '2618002', '2622007', '2624008', '2625009', '2630008', '2634004', '2638001', '2640006', '2651006', '2655002', '2657005', '2663001', '2665008', '2683000', '2689001', '2694001', '2704003', '2707005', '2713001', '2724004', '2725003', '2733002', '2736005', '2740001', '2749000', '2751001', '2761008', '2764000', '2770006', '2772003', '2775001', '2776000', '2781009', '2782002', '2783007', '2786004', '2790002', '2805007', '2806008', '2807004', '2808009', '2815001', '2816000', '2818004', '2819007', '2825006', '2828008', '2829000', '2831009', '2835000', '2836004', '2838003', '2840008', '2850009', '2853006', '2856003', '2858002', '2884008', '2893009', '2897005', '2899008', '2900003', '2901004', '2902006', '2904007', '2910007', '2912004', '2917005', '2918000', '2919008', '2929001', '2935001', '2940009', '2946003', '2951009', '2955000', '2965006', '2967003', '2972007', '2973002', '2978006', '2981001', '2989004', '2990008', '2992000', '2994004', '2999009', '3002002', '3004001', '3006004', '3009006', '3013004', '3014005', '3018008', '3019000', '3021005', '3023008', '3032005', '3033000', '3038009', '3044008', '3053001', '3059002', '3067005', '3071008', '3072001', '3073006', '3084004', '3089009', '3094009', '3095005', '3097002', '3098007', '3105002', '3109008', '3110003', '3119002', '3129009', '3135009', '3140001', '3144005', '3158007', '3160009', '3163006', '3168002', '3185000', '3199001', '3200003', '3208005', '3214003', '3217005', '3218000', '3219008', '3228009', '3229001', '3230006', '3238004', '3239007', '3253007', '3254001', '3259006', '3261002', '3263004', '3272007', '3274008', '3275009', '3276005', '3277001', '3282008', '3283003', '3286006', '3289004', '3291007', '3298001', '3303004', '3304005', '3305006', '3308008', '3310005', '3321001', '3323003', '3327002', '3331008', '3344003', '3345002', '3355003', '3358001', '3368006', '3376008', '3381004', '3387000', '3391005', '3393008', '3398004', '3401001', '3415004', '3419005', '3421000', '3424008', '3426005', '3427001', '3434004', '3439009', '3441005', '3446000', '3449007', '3456001', '3458000', '3461004', '3464007', '3468005', '3469002', '3472009', '3474005', '3480002', '3482005', '3483000', '3487004', '3500002', '3502005', '3503000', '3505007', '3506008', '3507004', '3511005', '3514002', '3519007', '3528008', '3529000', '3530005', '3531009', '3533007', '3539006', '3542000', '3544004', '3545003', '3548001', '3549009', '3558002', '3560000', '3570003', '3571004', '3577000', '3585009', '3586005', '3589003', '3590007', '3591006', '3598000', '3611003', '3633001', '3634007', '3639002', '3640000', '3641001', '3642008', '3644009', '3649004', '3650004', '3652007', '3657001', '3660008', '3662000', '3677008', '3680009', '3681008', '3696007', '3699000', '3703002', '3704008', '3705009', '3712000', '3716002', '3720003', '3723001', '3733009', '3736001', '3738000', '3744001', '3745000', '3747008', '3750006', '3751005', '3752003', '3754002', '3755001', '3756000', '3759007', '3760002', '3762005', '3763000', '3783004', '3797007', '3798002', '3815005', '3820005', '3827008', '3830001', '3841004', '3845008', '3855007', '3859001', '3873005', '3885002', '3886001', '3899003', '3900008', '3902000', '3903005', '3908001', '3909009', '3913002', '3914008', '3928002', '3939004', '3944006', '3947004', '3950001', '3951002', '3972004', '3975002', '3978000', '3987009', '3993001', '3999002', '4003003', '4004009', '4006006', '4009004', '4016003', '4017007', '4022007', '4026005', '4030008', '4038001', '4039009', '4040006', '4041005', '4046000', '4062006', '4063001', '4069002', '4070001', '4075006', '4082005', '4088009', '4089001', '4092002', '4103001', '4106009', '4107000', '4113009', '4120002', '4124006', '4127004', '4129001', '4135001', '4136000', '4142001', '4152002', '4160001', '4168008', '4170004', '4174008', '4175009', '4178006', '4181001', '4183003', '4184009', '4191007', '4195003', '4197006', '4199009', '4208000', '4210003', '4223005', '4224004', '4225003', '4229009', '4232007', '4237001', '4240001', '4241002', '4242009', '4244005', '4248008', '4249000', '4251001', '4260009', '4262001', '4264000', '4269005', '4273008', '4275001', '4278004', '4283007', '4287008', '4294006', '4300009', '4301008', '4306003', '4307007', '4308002', '4310000', '4313003', '4316006', '4320005', '4324001', '4325000', '4332009', '4338008', '4340003', '4349002', '4354006', '4356008', '4359001', '4364002', '4367009', '4373005', '4374004', '4381006', '4386001', '4390004', '4397001', '4399003', '4403007', '4406004', '4409006', '4410001', '4412009', '4414005', '4416007', '4418008', '4426000', '4434006', '4439001', '4441000', '4445009', '4448006', '4451004', '4461006', '4463009', '4464003', '4465002', '4468000', '4470009', '4473006', '4477007', '4478002', '4481007', '4483005']}, 'type'=>'CodeableConcept', 'path'=>'Reaction.manifestation', 'min'=>1, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/clinical-findings'}},
        'description' => {'type'=>'string', 'path'=>'Reaction.description', 'min'=>0, 'max'=>1},
        'onset' => {'type'=>'dateTime', 'path'=>'Reaction.onset', 'min'=>0, 'max'=>1},
        'severity' => {'valid_codes'=>{'http://hl7.org/fhir/reaction-event-severity'=>['mild', 'moderate', 'severe']}, 'type'=>'code', 'path'=>'Reaction.severity', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/reaction-event-severity'}},
        'exposureRoute' => {'valid_codes'=>{'http://snomed.info/sct'=>['6064005', '10547007', '12130007', '16857009', '26643006', '34206005', '37161004', '37737002', '37839007', '38239002', '45890007', '46713006', '47625008', '54471007', '54485002', '58100008', '60213007', '62226000', '72607000', '78421000', '90028008', '127490009', '127491008', '127492001', '372449004', '372450004', '372451000', '372452007', '372453002', '372454008', '372457001', '372458006', '372459003', '372460008', '372461007', '372463005', '372464004', '372465003', '372466002', '372467006', '372468001', '372469009', '372470005', '372471009', '372473007', '372474001', '372475000', '372476004', '404815008', '404818005', '404819002', '404820008', '416174007', '417070009', '417255000', '417950001', '417985001', '417989007', '418091004', '418114005', '418133000', '418136008', '418162004', '418204005', '418287000', '418321004', '418331006', '418401004', '418418000', '418441008', '418511008', '418586008', '418608002', '418664002', '418722009', '418730005', '418743005', '418813001', '418821007', '418851001', '418877009', '418887008', '418892005', '418947002', '418987007', '419021003', '419165009', '419231003', '419243002', '419320008', '419396008', '419601003', '419631009', '419684008', '419762003', '419778001', '419810008', '419874009', '419894000', '419954003', '419993007', '420047004', '420163009', '420168000', '420185003', '420201002', '420204005', '420218003', '420254004', '420287000', '420719007', '428191002', '429817007', '445752009', '445754005', '445755006', '445756007', '445767008', '445768003', '445769006', '445771006', '445913005', '445941009', '446105004', '446407004', '446435000', '446442000', '446540005', '447026006', '447052000', '447080003', '447081004', '447121004', '447122006', '447227007', '447229005', '447694001', '447964005', '448077001', '448491004', '448492006', '448598008', '697971008', '711360002', '711378007', '714743009', '718329006', '1611000175109', '180677251000087104', '461657851000087101']}, 'type'=>'CodeableConcept', 'path'=>'Reaction.exposureRoute', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/route-codes'}},
        'note' => {'type'=>'Annotation', 'path'=>'Reaction.note', 'min'=>0, 'max'=>Float::INFINITY}
      }

      attr_accessor :id                # 0-1 string
      attr_accessor :extension         # 0-* [ Extension ]
      attr_accessor :modifierExtension # 0-* [ Extension ]
      attr_accessor :substance         # 0-1 CodeableConcept
      attr_accessor :manifestation     # 1-* [ CodeableConcept ]
      attr_accessor :description       # 0-1 string
      attr_accessor :onset             # 0-1 dateTime
      attr_accessor :severity          # 0-1 code
      attr_accessor :exposureRoute     # 0-1 CodeableConcept
      attr_accessor :note              # 0-* [ Annotation ]
    end

    attr_accessor :id                 # 0-1 id
    attr_accessor :meta               # 0-1 Meta
    attr_accessor :implicitRules      # 0-1 uri
    attr_accessor :language           # 0-1 code
    attr_accessor :text               # 0-1 Narrative
    attr_accessor :contained          # 0-* [ Resource ]
    attr_accessor :extension          # 0-* [ Extension ]
    attr_accessor :modifierExtension  # 0-* [ Extension ]
    attr_accessor :identifier         # 0-* [ Identifier ]
    attr_accessor :clinicalStatus     # 0-1 CodeableConcept
    attr_accessor :verificationStatus # 0-1 CodeableConcept
    attr_accessor :type               # 0-1 code
    attr_accessor :category           # 0-* [ code ]
    attr_accessor :criticality        # 0-1 code
    attr_accessor :code               # 0-1 CodeableConcept
    attr_accessor :patient            # 1-1 Reference(Patient)
    attr_accessor :encounter          # 0-1 Reference(Encounter)
    attr_accessor :onsetDateTime      # 0-1 dateTime
    attr_accessor :onsetAge           # 0-1 Age
    attr_accessor :onsetPeriod        # 0-1 Period
    attr_accessor :onsetRange         # 0-1 Range
    attr_accessor :onsetString        # 0-1 string
    attr_accessor :recordedDate       # 0-1 dateTime
    attr_accessor :recorder           # 0-1 Reference(Practitioner|PractitionerRole|Patient|RelatedPerson)
    attr_accessor :asserter           # 0-1 Reference(Patient|RelatedPerson|Practitioner|PractitionerRole)
    attr_accessor :lastOccurrence     # 0-1 dateTime
    attr_accessor :note               # 0-* [ Annotation ]
    attr_accessor :reaction           # 0-* [ AllergyIntolerance::Reaction ]

    def resourceType
      'AllergyIntolerance'
    end
  end
end