module FHIR
  class CarePlan < FHIR::Model
    include FHIR::Hashable
    include FHIR::Json
    include FHIR::Xml

    SEARCH_PARAMS = ['date', 'identifier', 'patient', 'activity-code', 'activity-date', 'activity-reference', 'based-on', 'care-team', 'category', 'condition', 'encounter', 'goal', 'instantiates-canonical', 'instantiates-uri', 'intent', 'part-of', 'performer', 'replaces', 'status', 'subject']
    METADATA = {
      'id' => {'type'=>'id', 'path'=>'CarePlan.id', 'min'=>0, 'max'=>1},
      'meta' => {'type'=>'Meta', 'path'=>'CarePlan.meta', 'min'=>0, 'max'=>1},
      'implicitRules' => {'type'=>'uri', 'path'=>'CarePlan.implicitRules', 'min'=>0, 'max'=>1},
      'language' => {'valid_codes'=>{'urn:ietf:bcp:47'=>['ar', 'bn', 'cs', 'da', 'de', 'de-AT', 'de-CH', 'de-DE', 'el', 'en', 'en-AU', 'en-CA', 'en-GB', 'en-IN', 'en-NZ', 'en-SG', 'en-US', 'es', 'es-AR', 'es-ES', 'es-UY', 'fi', 'fr', 'fr-BE', 'fr-CH', 'fr-FR', 'fy', 'fy-NL', 'hi', 'hr', 'it', 'it-CH', 'it-IT', 'ja', 'ko', 'nl', 'nl-BE', 'nl-NL', 'no', 'no-NO', 'pa', 'pl', 'pt', 'pt-BR', 'ru', 'ru-RU', 'sr', 'sr-RS', 'sv', 'sv-SE', 'te', 'zh', 'zh-CN', 'zh-HK', 'zh-SG', 'zh-TW']}, 'type'=>'code', 'path'=>'CarePlan.language', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'preferred', 'uri'=>'http://hl7.org/fhir/ValueSet/languages'}},
      'text' => {'type'=>'Narrative', 'path'=>'CarePlan.text', 'min'=>0, 'max'=>1},
      'contained' => {'type'=>'Resource', 'path'=>'CarePlan.contained', 'min'=>0, 'max'=>Float::INFINITY},
      'extension' => {'type'=>'Extension', 'path'=>'CarePlan.extension', 'min'=>0, 'max'=>Float::INFINITY},
      'modifierExtension' => {'type'=>'Extension', 'path'=>'CarePlan.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
      'identifier' => {'type'=>'Identifier', 'path'=>'CarePlan.identifier', 'min'=>0, 'max'=>Float::INFINITY},
      'instantiatesCanonical' => {'type'=>'canonical', 'path'=>'CarePlan.instantiatesCanonical', 'min'=>0, 'max'=>Float::INFINITY},
      'instantiatesUri' => {'type'=>'uri', 'path'=>'CarePlan.instantiatesUri', 'min'=>0, 'max'=>Float::INFINITY},
      'basedOn' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/CarePlan'], 'type'=>'Reference', 'path'=>'CarePlan.basedOn', 'min'=>0, 'max'=>Float::INFINITY},
      'replaces' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/CarePlan'], 'type'=>'Reference', 'path'=>'CarePlan.replaces', 'min'=>0, 'max'=>Float::INFINITY},
      'partOf' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/CarePlan'], 'type'=>'Reference', 'path'=>'CarePlan.partOf', 'min'=>0, 'max'=>Float::INFINITY},
      'status' => {'valid_codes'=>{'http://hl7.org/fhir/request-status'=>['draft', 'active', 'on-hold', 'revoked', 'completed', 'entered-in-error', 'unknown']}, 'type'=>'code', 'path'=>'CarePlan.status', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/request-status'}},
      'intent' => {'valid_codes'=>{'http://hl7.org/fhir/request-intent'=>['proposal', 'plan', 'order', 'option']}, 'type'=>'code', 'path'=>'CarePlan.intent', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/care-plan-intent'}},
      'category' => {'type'=>'CodeableConcept', 'path'=>'CarePlan.category', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/care-plan-category'}},
      'title' => {'type'=>'string', 'path'=>'CarePlan.title', 'min'=>0, 'max'=>1},
      'description' => {'type'=>'string', 'path'=>'CarePlan.description', 'min'=>0, 'max'=>1},
      'subject' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Patient', 'http://hl7.org/fhir/StructureDefinition/Group'], 'type'=>'Reference', 'path'=>'CarePlan.subject', 'min'=>1, 'max'=>1},
      'encounter' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Encounter'], 'type'=>'Reference', 'path'=>'CarePlan.encounter', 'min'=>0, 'max'=>1},
      'period' => {'type'=>'Period', 'path'=>'CarePlan.period', 'min'=>0, 'max'=>1},
      'created' => {'type'=>'dateTime', 'path'=>'CarePlan.created', 'min'=>0, 'max'=>1},
      'author' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Patient', 'http://hl7.org/fhir/StructureDefinition/Practitioner', 'http://hl7.org/fhir/StructureDefinition/PractitionerRole', 'http://hl7.org/fhir/StructureDefinition/Device', 'http://hl7.org/fhir/StructureDefinition/RelatedPerson', 'http://hl7.org/fhir/StructureDefinition/Organization', 'http://hl7.org/fhir/StructureDefinition/CareTeam'], 'type'=>'Reference', 'path'=>'CarePlan.author', 'min'=>0, 'max'=>1},
      'contributor' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Patient', 'http://hl7.org/fhir/StructureDefinition/Practitioner', 'http://hl7.org/fhir/StructureDefinition/PractitionerRole', 'http://hl7.org/fhir/StructureDefinition/Device', 'http://hl7.org/fhir/StructureDefinition/RelatedPerson', 'http://hl7.org/fhir/StructureDefinition/Organization', 'http://hl7.org/fhir/StructureDefinition/CareTeam'], 'type'=>'Reference', 'path'=>'CarePlan.contributor', 'min'=>0, 'max'=>Float::INFINITY},
      'careTeam' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/CareTeam'], 'type'=>'Reference', 'path'=>'CarePlan.careTeam', 'min'=>0, 'max'=>Float::INFINITY},
      'addresses' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Condition'], 'type'=>'Reference', 'path'=>'CarePlan.addresses', 'min'=>0, 'max'=>Float::INFINITY},
      'supportingInfo' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Resource'], 'type'=>'Reference', 'path'=>'CarePlan.supportingInfo', 'min'=>0, 'max'=>Float::INFINITY},
      'goal' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Goal'], 'type'=>'Reference', 'path'=>'CarePlan.goal', 'min'=>0, 'max'=>Float::INFINITY},
      'activity' => {'type'=>'CarePlan::Activity', 'path'=>'CarePlan.activity', 'min'=>0, 'max'=>Float::INFINITY},
      'note' => {'type'=>'Annotation', 'path'=>'CarePlan.note', 'min'=>0, 'max'=>Float::INFINITY}
    }

    class Activity < FHIR::Model
      include FHIR::Hashable
      include FHIR::Json
      include FHIR::Xml

      METADATA = {
        'id' => {'type'=>'string', 'path'=>'Activity.id', 'min'=>0, 'max'=>1},
        'extension' => {'type'=>'Extension', 'path'=>'Activity.extension', 'min'=>0, 'max'=>Float::INFINITY},
        'modifierExtension' => {'type'=>'Extension', 'path'=>'Activity.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
        'outcomeCodeableConcept' => {'valid_codes'=>{'http://snomed.info/sct'=>['54777007', '129862009', '129863004', '129864005', '129865006', '129866007', '129867003', '129868008', '182891003', '397588000', '397598006', '397675006', '397699006', '397724004', '408364003', '423875000', '424537004', '704375003', '704377006', '704379009', '704381006', '704383009', '704400005', '704402002', '704403007', '704404001', '704406004', '704446005', '704491001', '704680001', '705086000', '706869001', '708571001', '713398008', '713447003', '713448008', '713449000', '713451001', '713452008', '714670007', '716391009', '716438000']}, 'type'=>'CodeableConcept', 'path'=>'Activity.outcomeCodeableConcept', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/care-plan-activity-outcome'}},
        'outcomeReference' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Resource'], 'type'=>'Reference', 'path'=>'Activity.outcomeReference', 'min'=>0, 'max'=>Float::INFINITY},
        'progress' => {'type'=>'Annotation', 'path'=>'Activity.progress', 'min'=>0, 'max'=>Float::INFINITY},
        'reference' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Appointment', 'http://hl7.org/fhir/StructureDefinition/CommunicationRequest', 'http://hl7.org/fhir/StructureDefinition/DeviceRequest', 'http://hl7.org/fhir/StructureDefinition/MedicationRequest', 'http://hl7.org/fhir/StructureDefinition/NutritionOrder', 'http://hl7.org/fhir/StructureDefinition/Task', 'http://hl7.org/fhir/StructureDefinition/ServiceRequest', 'http://hl7.org/fhir/StructureDefinition/VisionPrescription', 'http://hl7.org/fhir/StructureDefinition/RequestGroup'], 'type'=>'Reference', 'path'=>'Activity.reference', 'min'=>0, 'max'=>1},
        'detail' => {'type'=>'CarePlan::Activity::Detail', 'path'=>'Activity.detail', 'min'=>0, 'max'=>1}
      }

      class Detail < FHIR::Model
        include FHIR::Hashable
        include FHIR::Json
        include FHIR::Xml

        MULTIPLE_TYPES = {
          'scheduled' => ['Timing', 'Period', 'string'],
          'product' => ['CodeableConcept', 'Reference']
        }
        METADATA = {
          'id' => {'type'=>'string', 'path'=>'Detail.id', 'min'=>0, 'max'=>1},
          'extension' => {'type'=>'Extension', 'path'=>'Detail.extension', 'min'=>0, 'max'=>Float::INFINITY},
          'modifierExtension' => {'type'=>'Extension', 'path'=>'Detail.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
          'kind' => {'valid_codes'=>{'http://hl7.org/fhir/resource-types'=>['Appointment', 'CommunicationRequest', 'DeviceRequest', 'MedicationRequest', 'NutritionOrder', 'Task', 'ServiceRequest', 'VisionPrescription']}, 'type'=>'code', 'path'=>'Detail.kind', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/care-plan-activity-kind'}},
          'instantiatesCanonical' => {'type'=>'canonical', 'path'=>'Detail.instantiatesCanonical', 'min'=>0, 'max'=>Float::INFINITY},
          'instantiatesUri' => {'type'=>'uri', 'path'=>'Detail.instantiatesUri', 'min'=>0, 'max'=>Float::INFINITY},
          'code' => {'valid_codes'=>{'http://snomed.info/sct'=>['104001', '115006', '119000', '121005', '128004', '133000', '135007', '142007', '146005', '153001', '160007', '166001', '170009', '174000', '176003', '189009', '197002', '230009', '243009', '245002', '262007', '267001', '285008', '294002', '295001', '306005', '316002', '334003', '342002', '346004', '348003', '351005', '352003', '353008', '374009', '388008', '389000', '401004', '406009', '417005', '435001', '445004', '456004', '459006', '463004', '468008', '474008', '489004', '493005', '494004', '497006', '503003', '531007', '533005', '535003', '540006', '543008', '545001', '549007', '550007', '559008', '570001', '574005', '603006', '617002', '618007', '625000', '628003', '629006', '633004', '637003', '642006', '645008', '647000', '657004', '665001', '670008', '671007', '673005', '674004', '676002', '680007', '687005', '695009', '697001', '710006', '712003', '721002', '722009', '726007', '730005', '741007', '746002', '753006', '754000', '759005', '762008', '764009', '767002', '789003', '791006', '807005', '814007', '817000', '831000', '851001', '853003', '867007', '870006', '879007', '881009', '893000', '897004', '910002', '911003', '913000', '926001', '935008', '941001', '945005', '948007', '951000', '956005', '967006', '969009', '971009', '1001000', '1008006', '1019009', '1021004', '1029002', '1032004', '1035002', '1036001', '1041009', '1042002', '1043007', '1044001', '1048003', '1054002', '1071001', '1084005', '1093006', '1103000', '1104006', '1115001', '1119007', '1121002', '1127003', '1133007', '1163003', '1176009', '1181000', '1186005', '1198000', '1209007', '1225002', '1227005', '1235008', '1237000', '1238005', '1251000', '1253002', '1258006', '1266002', '1267006', '1278003', '1279006', '1292009', '1299000', '1315009', '1316005', '1324000', '1327007', '1328002', '1329005', '1337002', '1339004', '1347004', '1352009', '1358008', '1366004', '1385001', '1390003', '1398005', '1399002', '1407007', '1410000', '1411001', '1413003', '1414009', '1417002', '1431002', '1440003', '1449002', '1453000', '1455007', '1457004', '1494008', '1500007', '1501006', '1505002', '1529009', '1533002', '1550000', '1555005', '1559004', '1576000', '1577009', '1578004', '1583007', '1585000', '1596008', '1597004', '1602006', '1614003', '1615002', '1616001', '1636000', '1638004', '1640009', '1645004', '1651009', '1653007', '1669000', '1677001', '1678006', '1680000', '1683003', '1689004', '1691007', '1699009', '1702002', '1704001', '1709006', '1712009', '1713004', '1730002', '1746005', '1747001', '1753001', '1757000', '1759002', '1770009', '1774000', '1775004', '1784004', '1787006', '1788001', '1801001', '1805005', '1811008', '1813006', '1820004', '1830008', '1836002', '1844002', '1854003', '1859008', '1861004', '1862006', '1866009', '1868005', '1870001', '1871002', '1872009', '1876007', '1879000', '1889001', '1906007', '1907003', '1917008', '1924009', '1950008', '1958001', '1966005', '1983001', '1995001', '1999007', '2002009', '2021001', '2051007', '2054004', '2067001', '2069003', '2078009', '2079001', '2080003', '2098004', '2115003', '2119009', '2127000', '2137005', '2153008', '2161003', '2164006', '2166008', '2171001', '2178007', '2181002', '2188008', '2193006', '2196003', '2199005', '2214008', '2220009', '2225004', '2234009', '2238007', '2242005', '2244006', '2250001', '2252009', '2266004', '2267008', '2270007', '2276001', '2278000', '2279008', '2290003', '2315006', '2318008', '2321005', '2322003', '2337004', '2344008', '2347001', '2364003', '2371008', '2373006', '2382000', '2386002', '2393003', '2406000', '2407009', '2408004', '2409007', '2425002', '2442008', '2448007', '2455009', '2457001', '2458006', '2459003', '2461007', '2474001', '2475000', '2480009', '2486003', '2488002', '2494005', '2498008', '2507007', '2508002', '2514009', '2517002', '2530001', '2531002', '2535006', '2536007', '2547000', '2552005', '2564002', '2566000', '2567009', '2580007', '2598006', '2601001', '2607002', '2613006', '2614000', '2616003', '2619005', '2629003', '2632000', '2642003', '2643008', '2644002', '2645001', '2646000', '2658000', '2659008', '2668005', '2670001', '2673004', '2677003', '2690005', '2693007', '2696004', '2697008', '2716009', '2722000', '2731000', '2732007', '2737001', '2742009', '2743004', '2745006', '2752008', '2780005', '2794006', '2802005', '2811005', '2813008', '2837008', '2842000', '2843005', '2847006', '2851008', '2854000', '2857007', '2866006', '2875008', '2876009', '2885009', '2891006', '2898000', '2903001', '2908005', '2914003', '2915002', '2933008', '2945004', '2947007', '2960001', '2968008', '2970004', '2971000', '2977001', '3001009', '3010001', '3016007', '3025001', '3026000', '3029007', '3041000', '3047001', '3060007', '3061006', '3063009', '3075004', '3078002', '3083005', '3088001', '3090000', '3112006', '3116009', '3130004', '3133002', '3137001', '3143004', '3162001', '3164000', '3165004', '3166003', '3177009', '3183007', '3186004', '3190002', '3204007', '3241008', '3249005', '3251009', '3256004', '3257008', '3258003', '3268008', '3270004', '3278006', '3287002', '3320000', '3324009', '3326006', '3328007', '3333006', '3338002', '3352000', '3357006', '3360004', '3390006', '3399007', '3407002', '3413006', '3418002', '3432000', '3443008', '3448004', '3450007', '3457005', '3479000', '3498003', '3499006', '3509001', '3512003', '3515001', '3517009', '3518004', '3527003', '3546002', '3559005', '3562008', '3564009', '3575008', '3580004', '3605001', '3607009', '3620007', '3625002', '3651000', '3654008', '3659003', '3664004', '3666002', '3669009', '3673007', '3683006', '3686003', '3688002', '3690001', '3691002', '3697003', '3700004', '3701000', '3713005', '3717006', '3734003', '3735002', '3740005', '3748003', '3749006', '3758004', '3770000', '3778007', '3780001', '3784005', '3786007', '3787003', '3794000', '3796003', '3799005', '3802001', '3819004', '3826004', '3828003', '3831002', '3843001', '3858009', '3861005', '3862003', '3864002', '3880007', '3881006', '3887005', '3889008', '3891000', '3895009', '3907006', '3911000', '3915009', '3917001', '3918006', '3926003', '3929005', '3936006', '3938007', '3942005', '3955006', '3957003', '3963007', '3967008', '3968003', '3969006', '3971006', '3980006', '3981005', '3985001', '3991004', '3998005', '4007002', '4008007', '4010009', '4027001', '4034004', '4035003', '4036002', '4037006', '4044002', '4045001', '4052004', '4064007', '4068005', '4083000', '4084006', '4090005', '4094001', '4101004', '4102006', '4114003', '4116001', '4119008', '4131005', '4134002', '4139007', '4143006', '4149005', '4154001', '4165006', '4176005', '4192000', '4213001', '4214007', '4226002', '4252008', '4263006', '4266003', '4285000', '4293000', '4304000', '4319004', '4321009', '4323007', '4331002', '4333004', '4336007', '4337003', '4339000', '4341004', '4344007', '4348005', '4350002', '4363008', '4365001', '4380007', '4387005', '4388000', '4407008', '4411002', '4420006', '4424002', '4436008', '4438009', '4443002', '4447001', '4449003', '4450003', '4455008', '4457000', '4466001', '4467005', '4475004', '4487006', '4489009', '4496006', '4503005', '4504004', '4505003', '4507006', '4511000', '4516005', '4520009', '4525004', '4533003', '4535005', '4539004', '4542005', '4544006', '4558008', '4563007', '4570007', '4579008', '4581005', '4585001', '4587009', '4589007', '4593001', '4594007', '4613005', '4625008', '4626009', '4636001', '4640005', '4642002', '4660002', '4670000', '4671001', '4672008', '4691008', '4692001', '4694000', '4699005', '4701005', '4707009', '4712005', '4713000', '4719001', '4727005', '4734007', '4737000', '4756005', '4758006', '4764004', '4765003', '4770005', '4772002', '4784000', '4804005', '4811009', '4815000', '4820000', '4827002', '4829004', '4847005', '4849008', '4862007', '4877004', '4891005', '4895001', '4902005', '4903000', '4904006', '4914002', '4929000', '4930005', '4934001', '4957007', '4966006', '4970003', '4974007', '4976009', '4987001', '4992004', '4993009', '5016005', '5019003', '5021008', '5022001', '5025004', '5032008', '5034009', '5048009', '5055006', '5057003', '5065000', '5091004', '5105000', '5110001', '5113004', '5119000', '5121005', '5123008', '5130002', '5131003', '5135007', '5147001', '5151004', '5154007', '5161006', '5162004', '5165002', '5176003', '5182000', '5184004', '5186002', '5190000', '5191001', '5212002', '5216004', '5233006', '5243009', '5245002', '5246001', '5264008', '5267001', '5270002', '5273000', '5282006', '5290006', '5298004', '5304008', '5316002', '5317006', '5326009', '5328005', '5337005', '5338000', '5342002', '5348003', '5357009', '5373003', '5384005', '5391008', '5393006', '5402006', '5407000', '5415002', '5419008', '5422005', '5429001', '5431005', '5433008', '5446003', '5447007', '5452002', '5456004', '5457008', '5460001', '5479003', '5482008', '5486006', '5489004', '5506006', '5517007', '5521000', '5536002', '5545001', '5551006', '5556001', '5570001', '5571002', '5572009', '5586008', '5608002', '5616006', '5621009', '5632009', '5636007', '5638008', '5648005', '5651003', '5663008', '5669007', '5671007', '5687005', '5690004', '5694008', '5721002', '5722009', '5726007', '5728008', '5731009', '5733007', '5738003', '5745003', '5760000', '5771004', '5777000', '5781000', '5785009', '5787001', '5789003', '5796001', '5806001', '5807005', '5809008', '5812006', '5818005', '5821007', '5823005', '5832007', '5845006', '5846007', '5857002', '5865004', '5870006', '5880005', '5892005', '5894006', '5897004', '5902003', '5925002', '5930003', '5947002', '5961007', '5966002', '5971009', '5983006', '5986003', '5992009', '5995006', '5997003', '5998008', '6005008', '6007000', '6019008', '6025007', '6026008', '6029001', '6035001', '6063004', '6069000', '6082008', '6092000', '6100001', '6108008', '6119006', '6125005', '6126006', '6127002', '6130009', '6133006', '6143009', '6146001', '6148000', '6157006', '6159009', '6161000', '6164008', '6166005', '6177004', '6187000', '6188005', '6189002', '6190006', '6195001', '6198004', '6200005', '6205000', '6213004', '6221005', '6225001', '6226000', '6227009', '6231003', '6238009', '6240004', '6255008', '6271008', '6274000', '6286002', '6289009', '6295005', '6307005', '6309008', '6319002', '6337001', '6339003', '6343004', '6353003', '6354009', '6355005', '6358007', '6361008', '6363006', '6370006', '6384001', '6385000', '6388003', '6396008', '6397004', '6399001', '6402000', '6403005', '6419003', '6429005', '6433003', '6434009', '6438007', '6439004', '6443000', '6444006', '6465000', '6466004', '6470007', '6473009', '6480006', '6486000', '6487009', '6491004', '6499002', '6502003', '6506000', '6519001', '6521006', '6527005', '6535008', '6536009', '6543003', '6547002', '6555009', '6556005', '6562000', '6563005', '6567006', '6568001', '6585004', '6589005', '6601003', '6614002', '6615001', '6622009', '6634001', '6639006', '6650009', '6656003', '6657007', '6658002', '6661001', '6665005', '6668007', '6670003']}, 'type'=>'CodeableConcept', 'path'=>'Detail.code', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/procedure-code'}},
          'reasonCode' => {'valid_codes'=>{'http://snomed.info/sct'=>['109006', '122003', '127009', '129007', '134006', '140004', '144008', '147001', '150003', '151004', '162004', '165002', '168000', '171008', '172001', '175004', '177007', '179005', '181007', '183005', '184004', '188001', '192008', '193003', '195005', '198007', '199004', '208008', '216004', '219006', '222008', '223003', '228007', '241006', '242004', '253005', '257006', '258001', '264008', '276008', '279001', '281004', '282006', '290006', '292003', '297009', '299007', '303002', '308006', '310008', '313005', '317006', '320003', '324007', '330007', '335002', '341009', '349006', '355001', '357009', '358004', '359007', '360002', '364006', '366008', '368009', '369001', '378007', '382009', '383004', '385006', '387003', '398002', '407000', '408005', '409002', '426008', '431005', '437009', '440009', '442001', '443006', '447007', '450005', '452002', '460001', '467003', '470004', '479003', '486006', '488007', '490008', '496002', '504009', '517007', '518002', '520004', '527001', '536002', '539009', '547009', '548004', '554003', '555002', '563001', '568005', '586008', '590005', '596004', '599006', '600009', '602001', '607007', '610000', '613003', '615005', '616006', '626004', '631002', '634005', '640003', '643001', '646009', '649002', '651003', '652005', '655007', '658009', '663008', '664002', '666000', '675003', '682004', '685002', '701003', '703000', '714002', '715001', '718004', '733007', '734001', '736004', '750009', '755004', '756003', '758002', '775008', '776009', '781000', '786005', '787001', '788006', '792004', '799008', '801006', '805002', '811004', '813001', '815008', '816009', '818005', '825003', '827006', '832007', '834008', '841002', '842009', '843004', '844005', '845006', '849000', '857002', '862001', '865004', '871005', '874002', '875001', '888003', '890002', '899001', '903008', '904002', '908004', '919001', '928000', '931004', '932006', '934007', '943003', '954008', '961007', '962000', '964004', '965003', '975000', '978003', '981008', '984000', '987007', '991002', '998008', '1003002', '1020003', '1023001', '1027000', '1031006', '1033009', '1034003', '1038000', '1045000', '1046004', '1051005', '1055001', '1059007', '1070000', '1073003', '1074009', '1077002', '1079004', '1085006', '1089000', '1102005', '1107004', '1108009', '1111005', '1112003', '1116000', '1124005', '1125006', '1126007', '1131009', '1134001', '1135000', '1139006', '1140008', '1141007', '1145003', '1150009', '1151008', '1152001', '1155004', '1156003', '1168007', '1184008', '1192004', '1194003', '1196001', '1197005', '1201005', '1203008', '1207009', '1208004', '1212005', '1214006', '1230003', '1232006', '1239002', '1240000', '1259003', '1261007', '1264004', '1271009', '1280009', '1282001', '1283006', '1284000', '1286003', '1287007', '1297003', '1308001', '1310004', '1317001', '1318006', '1323006', '1332008', '1335005', '1343000', '1345007', '1351002', '1356007', '1361009', '1363007', '1367008', '1370007', '1372004', '1376001', '1378000', '1380006', '1383008', '1384002', '1386000', '1387009', '1388004', '1393001', '1395008', '1402001', '1412008', '1415005', '1418007', '1419004', '1426004', '1427008', '1430001', '1447000', '1469007', '1474004', '1475003', '1478001', '1479009', '1482004', '1486001', '1488000', '1489008', '1492007', '1493002', '1499003', '1512006', '1515008', '1518005', '1519002', '1521007', '1523005', '1525003', '1531000', '1532007', '1534008', '1538006', '1539003', '1542009', '1544005', '1551001', '1556006', '1563006', '1567007', '1588003', '1592005', '1593000', '1606009', '1608005', '1639007', '1647007', '1648002', '1654001', '1657008', '1658003', '1663004', '1667003', '1670004', '1671000', '1674008', '1679003', '1682008', '1685005', '1686006', '1694004', '1698001', '1703007', '1705000', '1708003', '1714005', '1717003', '1723008', '1724002', '1734006', '1735007', '1739001', '1742007', '1744008', '1748006', '1755008', '1761006', '1763009', '1767005', '1769008', '1771008', '1776003', '1777007', '1778002', '1779005', '1794009', '1816003', '1821000', '1822007', '1824008', '1826005', '1828006', '1829003', '1833005', '1835003', '1837006', '1845001', '1847009', '1848004', '1852004', '1855002', '1856001', '1857005', '1858000', '1860003', '1865008', '1869002', '1881003', '1892002', '1896004', '1897008', '1899006', '1903004', '1908008', '1909000', '1922008', '1926006', '1938002', '1939005', '1943009', '1953005', '1954004', '1955003', '1959009', '1961000', '1963002', '1965009', '1967001', '1973000', '1977004', '1979001', '1980003', '1981004', '1988005', '1989002', '2004005', '2012002', '2024009', '2028007', '2032001', '2036003', '2040007', '2041006', '2043009', '2053005', '2055003', '2058001', '2061000', '2065009', '2066005', '2070002', '2073000', '2087000', '2089002', '2091005', '2094002', '2102007', '2103002', '2107001', '2109003', '2114004', '2116002', '2120003', '2121004', '2128005', '2129002', '2132004', '2134003', '2136001', '2138000', '2145000', '2149006', '2158004', '2167004', '2169001', '2170000', '2176006', '2177002', '2186007', '2198002', '2202000', '2204004', '2213002', '2216005', '2217001', '2219003', '2224000', '2228002', '2229005', '2231001', '2237002', '2239004', '2241003', '2243000', '2245007', '2251002', '2256007', '2261009', '2268003', '2284002', '2295008', '2296009', '2298005', '2301009', '2303007', '2304001', '2307008', '2308003', '2312009', '2314005', '2326000', '2339001', '2341000', '2351004', '2355008', '2359002', '2365002', '2366001', '2367005', '2374000', '2385003', '2388001', '2390000', '2391001', '2396006', '2398007', '2403008', '2415007', '2418009', '2419001', '2420007', '2432006', '2435008', '2437000', '2438005', '2439002', '2443003', '2452007', '2463005', '2469009', '2470005', '2471009', '2472002', '2473007', '2477008', '2492009', '2495006', '2496007', '2506003', '2513003', '2518007', '2521009', '2523007', '2526004', '2528003', '2532009', '2534005', '2538008', '2541004', '2554006', '2556008', '2560006', '2562003', '2576002', '2581006', '2582004', '2583009', '2584003', '2585002', '2589008', '2591000', '2593002', '2602008', '2606006', '2615004', '2618002', '2622007', '2624008', '2625009', '2630008', '2634004', '2638001', '2640006', '2651006', '2655002', '2657005', '2663001', '2665008', '2683000', '2689001', '2694001', '2704003', '2707005', '2713001', '2724004', '2725003', '2733002', '2736005', '2740001', '2749000', '2751001', '2761008', '2764000', '2770006', '2772003', '2775001', '2776000', '2781009', '2782002', '2783007', '2786004', '2790002', '2805007', '2806008', '2807004', '2808009', '2815001', '2816000', '2818004', '2819007', '2825006', '2828008', '2829000', '2831009', '2835000', '2836004', '2838003', '2840008', '2850009', '2853006', '2856003', '2858002', '2884008', '2893009', '2897005', '2899008', '2900003', '2901004', '2902006', '2904007', '2910007', '2912004', '2917005', '2918000', '2919008', '2929001', '2935001', '2940009', '2946003', '2951009', '2955000', '2965006', '2967003', '2972007', '2973002', '2978006', '2981001', '2989004', '2990008', '2992000', '2994004', '2999009', '3002002', '3004001', '3006004', '3009006', '3013004', '3014005', '3018008', '3019000', '3021005', '3023008', '3032005', '3033000', '3038009', '3044008', '3053001', '3059002', '3067005', '3071008', '3072001', '3073006', '3084004', '3089009', '3094009', '3095005', '3097002', '3098007', '3105002', '3109008', '3110003', '3119002', '3129009', '3135009', '3140001', '3144005', '3158007', '3160009', '3163006', '3168002', '3185000', '3199001', '3200003', '3208005', '3214003', '3217005', '3218000', '3219008', '3228009', '3229001', '3230006', '3238004', '3239007', '3253007', '3254001', '3259006', '3261002', '3263004', '3272007', '3274008', '3275009', '3276005', '3277001', '3282008', '3283003', '3286006', '3289004', '3291007', '3298001', '3303004', '3304005', '3305006', '3308008', '3310005', '3321001', '3323003', '3327002', '3331008', '3344003', '3345002', '3355003', '3358001', '3368006', '3376008', '3381004', '3387000', '3391005', '3393008', '3398004', '3401001', '3415004', '3419005', '3421000', '3424008', '3426005', '3427001', '3434004', '3439009', '3441005', '3446000', '3449007', '3456001', '3458000', '3461004', '3464007', '3468005', '3469002', '3472009', '3474005', '3480002', '3482005', '3483000', '3487004', '3500002', '3502005', '3503000', '3505007', '3506008', '3507004', '3511005', '3514002', '3519007', '3528008', '3529000', '3530005', '3531009', '3533007', '3539006', '3542000', '3544004', '3545003', '3548001', '3549009', '3558002', '3560000', '3570003', '3571004', '3577000', '3585009', '3586005', '3589003', '3590007', '3591006', '3598000', '3611003', '3633001', '3634007', '3639002', '3640000', '3641001', '3642008', '3644009', '3649004', '3650004', '3652007', '3657001', '3660008', '3662000', '3677008', '3680009', '3681008', '3696007', '3699000', '3703002', '3704008', '3705009', '3712000', '3716002', '3720003', '3723001', '3733009', '3736001', '3738000', '3744001', '3745000', '3747008', '3750006', '3751005', '3752003', '3754002', '3755001', '3756000', '3759007', '3760002', '3762005', '3763000', '3783004', '3797007', '3798002', '3815005', '3820005', '3827008', '3830001', '3841004', '3845008', '3855007', '3859001', '3873005', '3885002', '3886001', '3899003', '3900008', '3902000', '3903005', '3908001', '3909009', '3913002', '3914008', '3928002', '3939004', '3944006', '3947004', '3950001', '3951002', '3972004', '3975002', '3978000', '3987009', '3993001', '3999002', '4003003', '4004009', '4006006', '4009004', '4016003', '4017007', '4022007', '4026005', '4030008', '4038001', '4039009', '4040006', '4041005', '4046000', '4062006', '4063001', '4069002', '4070001', '4075006', '4082005', '4088009', '4089001', '4092002', '4103001', '4106009', '4107000', '4113009', '4120002', '4124006', '4127004', '4129001', '4135001', '4136000', '4142001', '4152002', '4160001', '4168008', '4170004', '4174008', '4175009', '4178006', '4181001', '4183003', '4184009', '4191007', '4195003', '4197006', '4199009', '4208000', '4210003', '4223005', '4224004', '4225003', '4229009', '4232007', '4237001', '4240001', '4241002', '4242009', '4244005', '4248008', '4249000', '4251001', '4260009', '4262001', '4264000', '4269005', '4273008', '4275001', '4278004', '4283007', '4287008', '4294006', '4300009', '4301008', '4306003', '4307007', '4308002', '4310000', '4313003', '4316006', '4320005', '4324001', '4325000', '4332009', '4338008', '4340003', '4349002', '4354006', '4356008', '4359001', '4364002', '4367009', '4373005', '4374004', '4381006', '4386001', '4390004', '4397001', '4399003', '4403007', '4406004', '4409006', '4410001', '4412009', '4414005', '4416007', '4418008', '4426000', '4434006', '4439001', '4441000', '4445009', '4448006', '4451004', '4461006', '4463009', '4464003', '4465002', '4468000', '4470009', '4473006', '4477007', '4478002', '4481007', '4483005']}, 'type'=>'CodeableConcept', 'path'=>'Detail.reasonCode', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/clinical-findings'}},
          'reasonReference' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Condition', 'http://hl7.org/fhir/StructureDefinition/Observation', 'http://hl7.org/fhir/StructureDefinition/DiagnosticReport', 'http://hl7.org/fhir/StructureDefinition/DocumentReference'], 'type'=>'Reference', 'path'=>'Detail.reasonReference', 'min'=>0, 'max'=>Float::INFINITY},
          'goal' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Goal'], 'type'=>'Reference', 'path'=>'Detail.goal', 'min'=>0, 'max'=>Float::INFINITY},
          'status' => {'valid_codes'=>{'http://hl7.org/fhir/care-plan-activity-status'=>['not-started', 'scheduled', 'in-progress', 'on-hold', 'completed', 'cancelled', 'stopped', 'unknown', 'entered-in-error']}, 'type'=>'code', 'path'=>'Detail.status', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/care-plan-activity-status'}},
          'statusReason' => {'type'=>'CodeableConcept', 'path'=>'Detail.statusReason', 'min'=>0, 'max'=>1},
          'doNotPerform' => {'type'=>'boolean', 'path'=>'Detail.doNotPerform', 'min'=>0, 'max'=>1},
          'scheduledTiming' => {'type'=>'Timing', 'path'=>'Detail.scheduled[x]', 'min'=>0, 'max'=>1},
          'scheduledPeriod' => {'type'=>'Period', 'path'=>'Detail.scheduled[x]', 'min'=>0, 'max'=>1},
          'scheduledString' => {'type'=>'string', 'path'=>'Detail.scheduled[x]', 'min'=>0, 'max'=>1},
          'location' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Location'], 'type'=>'Reference', 'path'=>'Detail.location', 'min'=>0, 'max'=>1},
          'performer' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Practitioner', 'http://hl7.org/fhir/StructureDefinition/PractitionerRole', 'http://hl7.org/fhir/StructureDefinition/Organization', 'http://hl7.org/fhir/StructureDefinition/RelatedPerson', 'http://hl7.org/fhir/StructureDefinition/Patient', 'http://hl7.org/fhir/StructureDefinition/CareTeam', 'http://hl7.org/fhir/StructureDefinition/HealthcareService', 'http://hl7.org/fhir/StructureDefinition/Device'], 'type'=>'Reference', 'path'=>'Detail.performer', 'min'=>0, 'max'=>Float::INFINITY},
          'productCodeableConcept' => {'valid_codes'=>{'http://snomed.info/sct'=>['261000', '336001', '363000', '519005', '585007', '693002', '698006', '699003', '747006', '873008', '925002', '1018001', '1025008', '1057009', '1091008', '1171004', '1190007', '1244009', '1269009', '1325004', '1336006', '1355006', '1368003', '1381005', '1450002', '1476002', '1536005', '1575001', '1603001', '1668008', '1914001', '1944003', '1956002', '1971003', '2029004', '2125008', '2195004', '2197007', '2201007', '2212007', '2215009', '2249001', '2264001', '2346005', '2537003', '2660003', '2680002', '2796008', '2799001', '2869004', '2878005', '2927004', '2958003', '2964005', '2991007', '2995003', '3031003', '3066001', '3087006', '3136005', '3142009', '3145006', '3209002', '3212004', '3225007', '3342004', '3378009', '3379001', '3501003', '3592004', '3597005', '3617004', '3672002', '3693004', '3793006', '3823007', '3829006', '3874004', '3906002', '3932008', '3941003', '3945007', '3983008', '4014000', '4025009', '4043008', '4076007', '4188007', '4203009', '4334005', '4353000', '4355007', '4413004', '4423008', '4480008', '4518006', '4616002', '4681002', '4700006', '4780009', '4814001', '4844003', '5007006', '5142007', '5167005', '5172001', '5220000', '5312000', '5405008', '5477001', '5641004', '5647000', '5657004', '5681006', '5691000', '5699003', '5739006', '5767002', '5774007', '5907009', '5955009', '6054001', '6088007', '6162007', '6237004', '6260007', '6333002', '6394006', '6495008', '6513000', '6524003', '6602005', '6612003', '6710000', '6717002', '6790004', '6809003', '6826009', '6837005', '6865007', '6873003', '6881002', '6910009', '6927001', '6952004', '6992002', '7034005', '7084003', '7156005', '7179006', '7302008', '7318002', '7328006', '7348004', '7451005', '7509000', '7515000', '7549008', '7608003', '7737009', '7770004', '7774008', '7816005', '7834009', '7904003', '7975001', '8030004', '8143001', '8202008', '8203003', '8222007', '8252004', '8397006', '8450009', '8534003', '8631001', '8689007', '8701002', '8767001', '8886003', '8919000', '8987006', '9174005', '9234005', '9271007', '9396007', '9457002', '9471005', '9530002', '9532005', '9539001', '9643009', '9663002', '9676008', '9680003', '9721008', '9765000', '9797000', '9817005', '9910008', '9974009', '9992001', '10016008', '10020007', '10109009', '10133003', '10174003', '10192006', '10202007', '10240005', '10270000', '10282009', '10324005', '10329000', '10333007', '10342000', '10354000', '10377000', '10424009', '10466005', '10471003', '10500003', '10534002', '10595003', '10644005', '10660009', '10682002', '10730008', '10750007', '10751006', '10767000', '10782005', '10790005', '10843002', '10955007', '11036001', '11038000', '11115001', '11121002', '11137008', '11170003', '11202003', '11331001', '11345007', '11420005', '11473005', '11496005', '11504003', '11633008', '11644000', '11652002', '11714005', '11943009', '11984007', '11986009', '12009000', '12034000', '12177002', '12208001', '12218006', '12290003', '12315006', '12391001', '12525000', '12568004', '12578001', '12597001', '12689001', '12716009', '12801003', '12821002', '12870003', '12930006', '12970004', '13030002', '13150000', '13188003', '13235001', '13342004', '13502005', '13585009', '13668001', '13708006', '13787003', '13789000', '14013006', '14071002', '14146003', '14172007', '14193005', '14285000', '14312008', '14321009', '14340003', '14349002', '14399003', '14409006', '14438009', '14443002', '14461006', '14507006', '14638000', '14645000', '14715007', '14743003', '14767006', '14796007', '14819006', '14903000', '14905007', '15009009', '15017001', '15098005', '15129007', '15322006', '15331006', '15352003', '15505005', '15571002', '15660006', '15698006', '15730005', '15785009', '15810003', '15895007', '15901005', '16106007', '16125005', '16130009', '16214005', '16257000', '16276003', '16318005', '16355005', '16359004', '16392005', '16395007', '16462002', '16477005', '16492006', '16613008', '16624005', '16628008', '16670003', '16683002', '16717002', '16744007', '16745008', '16748005', '16808006', '16826009', '16915004', '16923002', '16946000', '17008002', '17062003', '17072000', '17117004', '17147002', '17212003', '17240008', '17243005', '17244004', '17356001', '17614005', '17731005', '17777001', '17798001', '17836006', '17916009', '17932007', '17942009', '17990002', '17991003', '18017000', '18039003', '18143001', '18220004', '18288009', '18321003', '18394004', '18414002', '18449009', '18462008', '18535002', '18550006', '18600008', '18616005', '18712002', '18815007', '18832006', '18852007', '18959002', '18970009', '19012003', '19041007', '19046002', '19114000', '19126005', '19163001', '19205004', '19421007', '19427006', '19462001', '19499001', '19510001', '19524002', '19595005', '19622008', '19839007', '19893005', '19918001', '19967004', '19978007', '20056006', '20170008', '20217007', '20229003', '20231007', '20238001', '20327004', '20340009', '20368008', '20378006', '20379003', '20413008', '20450009', '20468007', '20495002', '20686000', '20752000', '20771003', '20844009', '20847002', '20887007', '21028006', '21066009', '21075006', '21094001', '21168008', '21175009', '21235009', '21246007', '21289006', '21303006', '21373005', '21394008', '21518006', '21556007', '21559000', '21566004', '21568003', '21572004', '21611007', '21614004', '21706000', '21891005', '21903000', '21919007', '22038003', '22086005', '22165008', '22236007', '22242006', '22250002', '22362000', '22424004', '22453003', '22496008', '22606007', '22635004', '22654004', '22769006', '22779008', '22790003', '22792006', '22827004', '22840009', '22882008', '22941009', '22976006', '23053002', '23068001', '23077008', '23176001', '23295004', '23375008', '23433006', '23459009', '23564005', '23692005', '23701001', '23814005', '23816007', '23861006', '23862004', '23866001', '23883005', '23959001', '23969007', '24022008', '24202000', '24237002', '24261009', '24336008', '24357000', '24434007', '24435008', '24556008', '24570008', '24583009', '24650007', '24686008', '24721007', '24751001', '24809001', '24823004', '24838003', '24869004', '25002001', '25013003', '25027008', '25128000', '25141001', '25183006', '25204006', '25205007', '25213008', '25217009', '25254000', '25305005', '25307002', '25401000', '25500001', '25525005', '25538002', '25571003', '25607008', '25620006', '25710007', '25747007', '25796002', '25886000', '25911004', '26120001', '26191006', '26277008', '26288002', '26327007', '26346008', '26351002', '26371006', '26379008', '26437003', '26469007', '26518005', '26656004', '26817007', '26945002', '26992003', '27054007', '27079005', '27081007', '27082000', '27122000', '27184001', '27192005', '27244000', '27248002', '27345002', '27361000', '27499006', '27586005', '27594003', '27656005', '27730007', '27736001', '27766008', '27822002', '27928002', '27931001', '27989007', '28021008', '28029005', '28069006', '28121005', '28223003', '28268006', '28344001', '28421003', '28464005', '28521000', '28580002', '28588009', '28662003', '28702005', '28825003', '28829009', '28927005', '28942008', '28983006', '28999000', '29011006', '29184007', '29190006', '29301006', '29327006', '29406002', '29522004', '29527005', '29531004', '29584000', '29588002', '29666006', '29671004', '29725000', '29765001', '29783009', '29876006', '30034004', '30053009', '30094001', '30145004', '30178006', '30179003', '30203009', '30205002', '30236005', '30324001', '30325000', '30326004', '30329006', '30333004', '30424002', '30589007', '30658004', '30676006', '30745005', '30804005', '30820000', '30827002', '30848000', '30863002', '30990007', '31011004', '31055005', '31147000', '31178001', '31422009', '31522006', '31617001', '31622001', '31662002', '31706007', '31707003', '31731008', '31780003', '31787000', '31799007', '31801005', '31815007', '31818009', '31827005', '31895006', '31936008', '31990000', '32050003', '32083005', '32120008', '32133002', '32154009', '32157002', '32281001', '32370002', '32436002', '32437006', '32498003', '32505007', '32519007', '32707001', '32714004', '32757009', '32789000', '32800009', '32824001', '32836007', '32852005', '32898006', '32901007', '33280006', '33307008', '33396006', '33435008', '33440000', '33447002', '33535006', '33619005', '33635003', '33642003', '33667000', '33752008', '33837008', '33922005', '33963004', '34007009', '34070005', '34074001', '34086003', '34113002', '34120009', '34198005', '34211007', '34239008', '34274009', '34332002', '34425005', '34471003', '34654009', '34657002', '34658007', '34737006', '34915005', '34919004', '34953000', '34983009', '35060001', '35135004', '35150008', '35236008', '35257000', '35281007', '35318005', '35321007', '35343004', '35431001', '35466004', '35473009', '35605007', '35733004', '35748005', '35765001', '35864006', '35883004', '35903003', '35946000', '35954003', '35966009', '35976007', '36020009', '36021008', '36022001', '36136008', '36167005', '36173006', '36176003', '36235004', '36378007', '36380001', '36516003', '36541005', '36651003', '36661005', '36712003', '36872003', '36887008', '36953002', '37006008', '37013008', '37077000', '37078005', '37123002', '37225000', '37237003', '37262003', '37276002', '37352007', '37365003', '37411004', '37433002', '37451001', '37527009', '37648000', '37656002', '37691005', '37716005', '37751002', '37756007', '37758008', '37765000', '37951005', '37957009', '37978007', '37986007', '37994000', '38044001', '38122009', '38218009', '38245005', '38344006', '38399002', '38408002', '38543004', '38595007', '38622005', '38623000', '38648002', '38686006', '38714005', '38794009', '38909000', '38914001', '38937007', '39012008', '39044007', '39123009', '39152007', '39263003', '39292004', '39294003', '39428005', '39514001', '39546001', '39552000', '39808001', '39815009', '39933002', '39962001', '39972003', '39973008', '39979007', '40036000', '40115000', '40342009', '40404004', '40438007', '40534007', '40545005', '40601003', '40699008', '40710000', '40789008', '40924008', '40937006', '40940006', '41062004', '41067005', '41091001', '41143004', '41153003', '41199001', '41261002', '41332001', '41395001', '41410009', '41433005', '41464007', '41485007', '41492002', '41503000', '41509001', '41573001', '41592004', '41598000', '41722006', '41793006', '41834005', '41903005', '41945007', '41989007', '42033003', '42056007', '42145009', '42146005', '42159002', '42163009', '42180008', '42193003', '42212002', '42230009', '42319009', '42382009', '42464005', '42520004', '42549007', '42605004', '42671007', '42692007', '42710006', '42730005', '42761001', '42841002', '42877009', '43004008', '43032004', '43048003', '43136004', '43171004', '43239002', '43289005', '43332008', '43356007', '43440003', '43462003', '43538006', '43541002', '43585000', '43592005', '43597004', '43613009', '43621003', '43688007', '43698001', '43706004', '43784004', '43835003', '43848004', '43880002', '43897008', '43909000', '43989002', '44044007', '44068004', '44159003', '44234001', '44262008', '44293009', '44330008', '44347009', '44469001', '44508008', '44520000', '44555003', '44588005', '44603007', '44609006', '44624002', '44644008', '44681007', '44711006', '44776005', '44908000', '45084007', '45119009', '45158004', '45159007', '45207006', '45266004', '45483006', '45524001', '45555007', '45604009', '45754009', '45807004', '45940009', '45946003', '45960001', '46015007', '46021006', '46058006', '46097003', '46122001', '46134009', '46146008', '46191004', '46201000', '46225008', '46250006', '46257009', '46293006', '46492003', '46514003', '46558003', '46572007', '46654009', '46668002', '46711008', '46749007', '46861006', '46887006', '46921009', '46943001', '46950002', '47026005', '47176005', '47180000', '47192000', '47218005', '47247003', '47280005', '47336007', '47349002', '47350002', '47355007', '47383009', '47389008', '47408003', '47413004', '47414005', '47500008', '47663000', '169008', '211009', '302007', '439007', '449005', '544002', '669007', '716000', '796001', '847003', '902003', '922004', '1039008', '1148001', '1182007', '1206000', '1222004', '1389007', '1434005', '1528001', '1552008', '1594006', '1613009', '1756009', '1758005', '1842003', '1878008', '1887004', '1982006', '2016004', '2037007', '2183004', '2190009', '2497003', '2571007', '2596005', '2679000', '2944000', '2949005', '3037004', '3046005', '3127006', '3221003', '3334000', '3361000', '3526007', '3593009', '3814009', '3822002', '4126008', '4194004', '4219002', '4220008', '4382004', '4704002', '4741001', '4753002', '4865009', '4937008', '5067008', '5465006', '5478006', '5487002', '5606003', '5720001', '5737008', '5776009', '5786005', '5797005', '5924003', '5975000', '6028009', '6067003', '6071000', '6102009', '6116004', '6122008', '6232005', '6247001', '6259002', '6369005', '6425004', '6517004', '6526001', '6625006', '6652001', '6716006', '6960003', '6985007', '7092007', '7140000', '7168001', '7230005', '7235000', '7292004', '7336002', '7561000', '7577004', '7624002', '7836006', '7947003', '7959004', '7982002', '8028001', '8109005', '8163008', '8348002', '8372007', '8416000', '8571001', '8658008', '8661009', '8692006', '8696009', '9190005', '9268004', '9307009', '9500005', '9542007', '9690006', '9745007', '9778000', '9944001', '10099000', '10135005', '10243007', '10312003', '10332002', '10355004', '10356003', '10368007', '10422008', '10504007', '10515002', '10555000', '10632007', '10668002', '10712001', '10756001', '10784006', '11185009', '11260008', '11402001', '11430001', '11563006', '11719000', '11777007', '11783005', '11796006', '11841005', '11847009', '11866009', '11959009', '12096000', '12236006', '12289007', '12335007', '12369008', '12425002', '12436009', '12495006', '12512008', '12559001', '12657005', '12839006', '12968008', '13132007', '13154009', '13178004', '13252002', '13414000', '13432000', '13512003', '13525006', '13565005', '13592004', '13664004', '13790009', '13800009', '13813003', '13929005', '13936006', '13965000', '14054003', '14103001', '14170004', '14542005', '14601000', '14706000', '14728000', '14745005', '14814001', '14816004', '15117003', '15222008', '15375005', '15383004', '15389000', '15432003', '15772006', '15857002', '16031005', '16037009', '16047007', '16131008', '16403005', '16602005', '16787005', '16791000', '16832004', '16858004', '16867004', '16970001', '16977003', '17016006', '17055007', '17308007', '17386008', '17502009', '17554004', '17558001', '17600005', '17805003', '17859000', '17893001', '18002004', '18125000', '18335001', '18340009', '18381001', '18511007', '18548003', '18679008', '18811003', '18914005', '18952006', '19194001', '19225000', '19232009', '19261005', '19315007', '19403009', '19405002', '19581007', '19583005', '19630009', '19768003', '19841008', '20091003', '20201001', '20237006', '20249007', '20303001', '20320002', '20577002', '20865003', '20969008', '21069002', '21159006', '21451004', '21691008', '21701005', '21767006', '21788002', '21986005', '22091006', '22168005', '22198003', '22274004', '22474002', '22587006', '22657006', '22672005', '22696000', '22801004', '22826008', '22969001', '23079006', '23222006', '23343005', '23532003', '23822003', '23827009', '23838009', '23888001', '24036003', '24450004', '24504000', '24866006', '24891006', '25014009', '25057004', '25076002', '25085002', '25142008', '25246002', '25398003', '25419009', '25465007', '25673006', '25716001', '25849001', '25860005', '25912006', '25995007', '26122009', '26124005', '26244009', '26303005', '26370007', '26456008', '26458009', '26462003', '26503009', '26523005', '26548008', '26574002', '26580005', '26736008', '26800000', '26842003', '27035007', '27085003', '27196008', '27242001', '27479000', '27518004', '27548001', '27566006', '27638005', '27658006', '27707001', '27754002', '27867009', '28028002', '28149003', '28235004', '28240007', '28410007', '28415002', '28426008', '28506006', '28748001', '28841002', '28906000', '29051009', '29058003', '29089004', '29121001', '29129004', '29156002', '29175007', '29237004', '29439004', '29620001', '29840005', '29877002', '29883004', '29896003', '29987004', '30010009', '30125007', '30306003', '30317002', '30427009', '30466001', '30492008', '30666008', '30729008', '30761007', '30964009', '30988006', '31025003', '31087008', '31181006', '31231007', '31305008', '31306009', '31352002', '31587003', '31684002', '31690003', '31692006', '31716004', '31865003', '31872002', '31970009', '32249005', '32313007', '32460003', '32462006', '32473004', '32474005', '32583002', '32647002', '32653002', '32792001', '32823007', '32841004', '32955006', '32960005', '33124007', '33133009', '33219003', '33231001', '33234009', '33236006', '33252009', '33378002', '33484000', '33588000', '33589008', '33664007', '33675006', '33682005', '33815001', '34012005', '34217006', '34364009', '34393009', '34462007', '34598001', '34599009', '34689006', '34693000', '34696008', '34731007', '34816007', '34833000', '34929006', '35035001', '35063004', '35097006', '35282000', '35300007', '35324004', '35392005', '35476001', '35531004', '35736007', '35768004', '35792007', '35967000', '35983000', '36068003', '36113004', '36168000', '36218003', '36236003', '36391008', '36537006', '36594001', '36621009', '36642006', '36763003', '36795002', '36893000', '36909007', '36940000', '36944009', '37084008', '37146000', '37306000', '37400007', '37628007', '37643009', '37773009', '37803001', '38076006', '38131009', '38166006', '38181000', '38231004', '38268001', '38314008', '38413003', '38578004', '38828006', '38900001', '39064002', '39124003', '39128000', '39142008', '39252001', '39359008', '39432004', '39487003', '39516004', '39598004', '39608003', '39707000', '39741008', '39860005', '39939003', '40162007', '40232005', '40339003', '40429005', '40430000', '40556005', '40562000', '40589005', '40606008', '40648001', '40652001', '40820003', '40877002', '40901001', '40905005', '40974005', '40999006', '41001009', '41015006', '41147003', '41193000', '41324009', '41365009', '41367001', '41399007', '41470001', '41493007', '41549009', '41985001', '42082003', '42098005', '42271003', '42348003', '42374009', '42444000', '42514000', '42638008', '42714002', '42720001', '42863006', '43343000', '43499003', '43533002', '43594006', '43684009', '43747001', '43753001', '43879000', '43927002', '44175000', '44418001', '44658005', '44731005', '44790008', '44798001', '44938006', '44990002', '45218006', '45311002', '45313004', '45355008', '45518007', '45680002', '45844004', '45888006', '45923000', '46009007', '46063005', '46123006', '46233009', '46436003', '46479001', '46532003', '46547007', '46576005', '46709004', '46741005', '46913003', '47065008', '47120002', '47124006', '47140009', '47331002', '47527007', '47602007', '47755009', '47772002', '47898004', '48028008', '48174005', '48256008', '48279009', '48351000', '48546005', '48603004', '48614001', '48647005', '48698004', '48836000', '48875009', '48899009', '49019002', '49157004', '49192007', '49267000', '49299006', '49485009', '49577002', '49590009', '49600008', '49617001', '49663007', '49669006', '49688004', '49694007', '49705006', '49802003', '49860008', '49953001', '49992008', '50094009', '50137001', '50182002', '50244000', '50256004', '50318003', '50335004', '50520001', '50841004', '50868004', '51013009', '51073002', '51103004', '51126006', '51132001', '51326002', '51334008', '51361008', '51425004', '51555009', '51752005', '51758009', '51779009', '51908007', '51992002', '52017007', '52108005', '52215008', '52388000', '52412009', '52423008', '52451004', '52489009', '52628005', '52761007', '52883001', '52896000', '53009005', '53480001', '53584007', '53640004', '53641000', '53691001', '53793005', '53800008', '53848009', '53855006', '54142000', '54344006', '54391004', '54406003', '54541002', '54544005', '54577009', '54659006', '54705000', '54765002', '54824008', '54882005', '54887004', '54972005', '54982006', '55015008', '55217007', '55432002', '55556000', '55673009', '55745002', '55782006', '55784007', '55830003', '55867006', '55889005', '56011005', '56014002', '56032002', '56059005', '56123002', '56230001', '56234005', '56240003', '56281006', '56480005', '56549003', '56602009', '56615000', '56656002', '56844000', '56928005', '56934003', '57002000', '57066004', '57123008', '57191001', '57263002', '57376006', '57538001', '57616006', '57670008', '57752001', '57811004', '57819002', '57845006', '57853003', '57893000', '57952007', '58050004', '58098008', '58360000', '58467001', '58502006', '58760003', '58805000', '58883005', '58892008', '58905004', '58944007', '59057006', '59187003', '59240002', '59245007', '59255006', '59261009', '59270007', '59456005', '59589008', '59594008', '59751001', '59799001', '59941008', '59953007', '59999009', '60090003', '60093001', '60149003', '60169008', '60468008', '60520004', '60533005', '60541005', '60682004', '60731009', '60767002', '60881009', '60972002', '60978003', '61020000', '61093008', '61123001', '61132004', '61153008', '61181002', '61408004', '61457001', '61602008', '61621000', '61623002', '61650007', '61651006', '61862008', '61939007', '61946003', '62051009', '62063004', '62191005', '62288001', '62294009', '62353003', '62354009', '62529008', '62560008', '62782004', '63094006', '63136007', '63318000', '63338004', '63470003', '63639004', '63682003', '63758001', '63822004', '64083002', '64115004', '64127001', '64240003', '64296005', '64349004', '64462001', '64558005', '64851009', '64878006', '65020006', '65026000', '65041000', '65092008', '65265006', '65461004', '65484006', '65502005', '65505007', '65627005', '65628000', '65638005', '65695006', '65823007', '65884003', '65965000', '66065008', '66094001', '66125007', '66243004', '66261008', '66349002', '66441000', '66492008', '66493003', '66602007', '66672008', '66742008', '66854004', '66859009', '66860004', '66919007', '66971004', '67213005', '67423003', '67440007', '67477004', '67507000', '67585005', '67735003', '67891001', '67939000', '68088000', '68113000', '68206008', '68208009', '68395000', '68398003', '68402007', '68407001', '68422006', '68424007', '68444001', '68461003', '68490009', '68622003', '68702006', '68774008', '68864001', '68887009', '68892006', '69107004', '69204002', '69227005', '69236009', '69242008', '69331001', '69431002', '69509008', '69576000', '69708003', '69801001', '69879000', '69918003', '69967001', '70047000', '70216000', '70254000', '70343008', '70379000', '70447008', '70460002', '70702006', '70776005', '70841003', '70864001', '70934008', '71181003', '71289008', '71338005', '71451001', '71453003', '71455005', '71462001', '71516007', '71584004', '71634000', '71699007', '71724000', '71731001', '71759000', '71770007', '71798005', '71837009', '72312007', '72398005', '72416006', '72623000', '72824008', '72870001', '72924009', '72968006', '72996000', '73074003', '73093001', '73133000', '73170009', '73212002', '73228007', '73274006', '73277004', '73454001', '73572009', '73585007', '73627008', '73639000', '73647000', '73756003', '73763003', '73805002', '73949004', '73986003', '74022005', '74065006', '74074008', '74147005', '74213004', '74226000', '74470007', '74480006', '74575000', '74583006', '74626007', '74632002', '74674007', '74771007', '74780007', '74782004', '74798006', '74819009', '75029008', '75201000', '75203002', '75292001', '75366006', '75429004', '75501004', '75661008', '75748004', '75770001', '75927008', '75959001', '75969007', '76058001', '76155001', '76286000', '76289007', '76385003', '76390000', '76591000', '76696004', '76759004', '76962009', '77035009', '77048008', '77237006', '77331005', '77390008', '77398001', '77549006', '77657003', '77731008', '77750008', '77856005', '77885004', '77898008', '78025001', '78057000', '78174002', '78379001', '78411008', '78439009', '78449007', '78507004', '78542000', '186002', '217008', '476005', '501001', '505005', '515004', '576007', '584006', '593007', '704006', '735000', '819002', '876000', '923009', '1097007', '1160000', '1223009', '1273007', '1319003', '1371006', '1405004', '1408002', '1506001', '1517000', '1565004', '1634002', '1649005', '1676005', '1681001', '1696002', '1975007', '2038002', '2082006', '2147008', '2260005', '2329007', '2404002', '2431004', '2444009', '2500009', '2568004', '2611008', '2676007', '2706001', '2721007', '2728001', '2753003', '2765004', '2988007', '3131000', '3187008', '3555004', '3588006', '3602003', '3730007', '3807007', '3897001', '3961009', '3976001', '4115002', '4167003', '4169000', '4314009', '4393002', '4401009', '4422003', '4425001', '4555006', '4564001', '4582003', '4591004', '4761007', '4762000', '4789005', '4878009', '4933007', '5004004', '5064001', '5081005', '5094007', '5250008', '5259009', '5307001', '5340005', '5404007', '5439007', '5504009', '5533005', '5573004', '5637003', '5700002', '5757007', '5840001', '5915007', '5977008', '6056004', '6068008', '6091007', '6115000', '6135004', '6138002', '6170002', '6178009', '6197009', '6310003', '6360009', '6411000', '6422001', '6507009', '6529008', '6532006', '6592009', '6642000', '6671004', '6741004', '6755007', '6945001', '6958000', '7029006', '7120007', '7158006', '7161007', '7211005', '7337006', '7411007', '7489000', '7588005', '7616007', '7648006', '7675004', '7685003', '7738004', '7948008', '7974002', '8002004', '8025003', '8048008', '8123007', '8164002', '8268005', '8343006', '8362009', '8376005', '8452001', '8460000', '8484008', '8486005', '8491006', '8612007', '8660005', '8731008', '8740007', '8786009', '8818009', '8878003', '8908003', '8977007', '9054000', '9172009', '9253000', '9296005', '9319001', '9392009', '9398008', '9472003', '9493000', '9608008', '9672005', '9701007', '9716005', '9921004', '9930007', '9980001', '9985006', '10105003', '10158008', '10189007', '10228005', '10265007', '10393009', '10398000', '10436003', '10440007', '10473000', '10560001', '10570004', '10622000', '10889009', '10912008', '10987005', '11004008', '11022006', '11041009', '11064006', '11091008', '11123004', '11222004', '11233001', '11252007', '11267006', '11330000', '11353004', '11447000', '11474004', '11479009', '11489008', '11566003', '11594006', '11600003', '11684009', '11725001', '11744008', '11770009', '11799004', '11825009', '11863001', '11877003', '11886008', '12018003', '12103002', '12190009', '12194000', '12379005', '12498008', '12564002', '12577006', '12627001', '12642003', '12685007', '12752008', '12753003', '12899008', '12934002', '12998001', '13016007', '13083005', '13105002', '13377004', '13400000', '13435003', '13484006', '13492002', '13539006', '13571004', '13590007', '13625002', '13701000', '13717006', '13723001', '13772008', '13841004', '13872000', '14090005', '14104007', '14190008', '14226002', '14271005', '14279007', '14396005', '14444008', '14464003', '14517001', '14574003', '14604008', '14620003', '14665007', '14711003', '14726001', '14827002', '14849008', '14986005', '15011000', '15021008', '15073009', '15275007', '15286009', '15313005', '15392001', '15416001', '15469000', '15551006', '15620005', '15653000', '15683009', '15754000', '15781000', '15797005', '15798000', '15909007', '15942008', '16019008', '16025007', '16074008', '16122008', '16133006', '16138002', '16230002', '16519001', '16705004', '16734005', '16752005', '16878007', '16951006', '16996004', '17074004', '17108004', '17119001', '17152007', '17165003', '17430007', '17462005', '17595001', '17627009', '17640004', '17659002', '17701004', '17707000', '17740009', '17853004', '18030004', '18082002', '18150002', '18195009', '18359006', '18380000', '18426007', '18436004', '18468007', '18486005', '18501000', '18533009', '18611000', '18627007', '18659000', '18737007', '18761000', '18763002', '18853002', '19009001', '19011005', '19022009', '19035000', '19089003', '19136002', '19178008', '19182005', '19331004', '19395006', '19400007', '19530002', '19565002', '19677004', '19728002', '19755006', '19783008', '19830006', '19868008', '19917006', '19945000', '20009008', '20040001', '20057002', '20228006', '20304007', '20355000', '20383003', '20493009', '20576006', '20591008', '20748000', '20764008', '20777004', '20807009', '20823009', '20878003', '20898008', '20907008', '21023002', '21064007', '21102006', '21145004', '21149005', '21158003', '21166007', '21256006', '21315005', '21521008', '21642002', '21774001', '21802009', '21873000', '21876008', '21920001', '22023004', '22269007', '22290004', '22332006', '22348007', '22503007', '22568000', '22627002', '22839007', '22939008', '22971001', '23016008', '23064004', '23101007', '23103005', '23164001', '23165000', '23200004', '23240005', '23314002', '23318004', '23369004', '23380004', '23385009', '23396001', '23434000', '23603009', '23689006', '23760003', '23774005', '23775006', '23878002', '23893003', '24002009', '24008008', '24023003', '24143007', '24207006', '24248009', '24304001', '24391001', '24404002', '24479006', '24487007', '24503006', '24540003', '24574004', '24655002', '24673004', '24710003', '24821002', '24857007', '24860000', '24898000', '24926008', '24978006', '24995003', '25095009', '25176004', '25282007', '25315004', '25400004', '25426009', '25453008', '25513007', '25557006', '25717005', '25773002', '25826003', '25833003', '25867008', '25964000', '26005009', '26021004', '26066008', '26093006', '26274001', '26355006', '26441004', '26647007', '26651009', '26720006', '26740004', '26749003', '26855002', '26937007', '27024002', '27044008', '27047001', '27048006', '27076003', '27089009', '27130004', '27205008', '27273002', '27340007', '27384007', '27417007', '27425009', '27453009', '27459008', '27487004', '27489001', '27607009', '27626001', '27800009', '27862003', '27899003', '27963007', '27999002', '28145009', '28262007', '28298004', '28361003', '28408005', '28424006', '28427004', '28495003', '28564007', '28577003', '28585007', '28673005', '28679009', '28708009', '28716000', '28731009', '28779002', '28808000', '28819002', '28881009', '29244008', '29266001', '29275004', '29468003', '29502003', '29573007', '29652001', '29719004', '29735006', '29776002', '29831006', '29988009', '30030008', '30137009', '30209008', '30245006', '30357004', '30413004', '30498007', '30540002', '30594007', '30604008', '30607001', '30609003', '30621004', '30702003', '30723009', '30797003', '30954000', '30965005', '30987001', '31001006', '31008000', '31024004', '31036005', '31245001', '31317005', '31357008', '31400002', '31854008', '31897003', '31960007', '32073006', '32079005', '32089009', '32147003', '32167007', '32233008', '32235001', '32237009', '32241008', '32261002', '32277001', '32305006', '32314001', '32324009', '32329004', '32351007', '32364008', '32396000', '32403003', '32481003', '32609007', '32616008', '32699000', '32842006', '32860006', '32943000', '32974003', '32990003', '33029004', '33037007', '33053005', '33057006', '33063002', '33188008', '33210004', '33309006', '33355008', '33509005', '33550002', '33604009', '33680002', '33691009', '33825006', '33865005', '33987002', '34049004', '34161009', '34180006', '34204008', '34316000', '34355004', '34388006', '34400001', '34453005', '34465009', '34510007', '34569000', '34745001', '34750007', '34829007', '34832005', '34868000', '34900009', '34912008', '34968004', '34970008', '35012004', '35040009', '35068008', '35072007', '35092000', '35118003', '35213004', '35215006', '35310003', '35367007', '35410004', '35556005', '35614002', '35645003', '35760006', '35825008', '35841009', '35906006', '35922007', '35952004', '36005003', '36016005', '36100005', '36260004', '36396003', '36403001', '36418000', '36562006', '36613003', '36652005', '36713008', '36744004', '36757007', '36759005', '36804003', '36842009', '36853003', '36907009', '36933001', '37067002', '37100000', '37282004', '37287005', '37300006', '37583005', '37654004', '37713002', '37861002', '37902007', '37984005', '38227005', '38262000', '38269009', '38367008', '38445008', '38476002', '38499003', '38519002', '38553003', '38554009', '38558007', '38771008', '38779005', '38874005', '38908008', '39024001', '39053000', '39082004', '39118009', '39138005', '39241007', '39327001', '39337006', '39442002', '39515000', '39525005', '39650003', '39665002', '39678002', '39840002', '39988003', '39999001', '40018000', '40030006', '40044000', '40048002', '40065006', '40140007', '40154004', '40270009', '40364000', '40447004', '40456007', '40558006', '40621002', '40706003', '40856000', '40992002', '41044008', '41093003', '41096006', '41285005', '41301002', '41318003', '41403003', '41562008', '41576009', '41644009', '41667006', '41761003', '41771001', '41858009', '41886001', '41930000', '41978000', '41999002', '42038007', '42048009', '42078000', '42092006', '42107008', '42122003', '42166001', '42255003', '42333009', '42371001', '42473002', '42490008', '42664002', '42732002', '42768007', '42784008', '42799008', '42804003', '42830004', '42848008', '42888003', '42891003', '42897004', '42926001', '43042002', '43076006', '43095004', '43181000', '43241001', '43278003', '43347004', '43397000', '43417002', '43425000', '43576000', '43596008', '43632003', '43678006', '43788001', '43807002', '43827001', '43864007', '43871002', '44040003', '44045008', '44046009', '44049002', '44063008', '44093002', '44112005', '44139002', '44158006', '44212003', '44239006', '44331007', '44369002', '44439008', '44447008', '44459007', '44472008', '44675004', '44680008', '44686002', '44706009', '44719008', '44728009', '44824000', '45026006', '45044003', '45047005', '45095001', '45193006', '45246008', '45273009', '45321005', '45333000', '45388001', '45396006', '45407009', '45428000', '45441001', '45510000', '45528003', '45530001', '45601001', '45637006', '45656001', '45668005', '45672009', '45857007', '45932003', '45934002', '45969000', '45992000', '46096007', '46150001', '46158008', '46195008', '46234003', '46261003', '46331009', '46336004', '46469003', '46519008', '46539007', '46548002', '46613001', '46663006', '46730008', '46755002', '46841000', '46959001', '47019005', '47023002', '47038001', '47068005', '47104007', '47136000', '47151009', '47201006', '47215008', '47341004', '47364002', '47464003', '47469008', '47553004', '47565000', '47581005', '47601000', '47603002', '47626009', '47662005', '47674009', '47692001', '47733001', '47769009', '47784000', '47851007', '47860004', '47894002', '47974007', '48060000', '48109004', '48116003', '48131007', '48140006', '48154003', '48170001', '48217002', '48270008', '48284003', '48323009', '48366002', '48401006', '48416009', '48417000', '48444005', '48464000', '48699007', '48727007', '48751002', '48779008', '48798005', '48815002', '48821003', '48869000', '48919009', '49028001', '49106003', '49119004', '49148005', '49163008', '49212001', '49327004', '49344000', '49352002', '49377001', '49419007', '49449009', '49495002', '49568009', '49582009', '49599005', '49616005', '49653004', '49677005', '49744003', '49772005', '49837000', '49858006', '49912009', '49991001', '49997002', '50028004', '50156006', '50272007', '50383001', '50480002', '50526007', '50700004', '50752003', '50762005', '50864002', '50899003', '50988004', '51222003', '51238009', '51242007', '51262004', '51276003', '51293003', '51311004', '51372003', '51414008', '51415009', '51447004', '51468003', '51511003', '51515007', '51645003', '51718007', '51809003', '51810008', '51873003', '51941005', '51950007', '52078008', '52081003', '52160001', '52169000', '52193005', '52210003', '52227006', '52258007', '52310000', '52313003', '52419000', '52467005', '52555006', '52573009', '52680001', '52764004', '52912003', '52935000', '52991006', '53023007']}, 'type'=>'CodeableConcept', 'path'=>'Detail.product[x]', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/medication-codes'}},
          'productReference' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Medication', 'http://hl7.org/fhir/StructureDefinition/Substance'], 'type'=>'Reference', 'path'=>'Detail.product[x]', 'min'=>0, 'max'=>1},
          'dailyAmount' => {'type'=>'Quantity', 'path'=>'Detail.dailyAmount', 'min'=>0, 'max'=>1},
          'quantity' => {'type'=>'Quantity', 'path'=>'Detail.quantity', 'min'=>0, 'max'=>1},
          'description' => {'type'=>'string', 'path'=>'Detail.description', 'min'=>0, 'max'=>1}
        }

        attr_accessor :id                     # 0-1 string
        attr_accessor :extension              # 0-* [ Extension ]
        attr_accessor :modifierExtension      # 0-* [ Extension ]
        attr_accessor :kind                   # 0-1 code
        attr_accessor :instantiatesCanonical  # 0-* [ canonical ]
        attr_accessor :instantiatesUri        # 0-* [ uri ]
        attr_accessor :code                   # 0-1 CodeableConcept
        attr_accessor :reasonCode             # 0-* [ CodeableConcept ]
        attr_accessor :reasonReference        # 0-* [ Reference(Condition|Observation|DiagnosticReport|DocumentReference) ]
        attr_accessor :goal                   # 0-* [ Reference(Goal) ]
        attr_accessor :status                 # 1-1 code
        attr_accessor :statusReason           # 0-1 CodeableConcept
        attr_accessor :doNotPerform           # 0-1 boolean
        attr_accessor :scheduledTiming        # 0-1 Timing
        attr_accessor :scheduledPeriod        # 0-1 Period
        attr_accessor :scheduledString        # 0-1 string
        attr_accessor :location               # 0-1 Reference(Location)
        attr_accessor :performer              # 0-* [ Reference(Practitioner|PractitionerRole|Organization|RelatedPerson|Patient|CareTeam|HealthcareService|Device) ]
        attr_accessor :productCodeableConcept # 0-1 CodeableConcept
        attr_accessor :productReference       # 0-1 Reference(Medication|Substance)
        attr_accessor :dailyAmount            # 0-1 Quantity
        attr_accessor :quantity               # 0-1 Quantity
        attr_accessor :description            # 0-1 string
      end

      attr_accessor :id                     # 0-1 string
      attr_accessor :extension              # 0-* [ Extension ]
      attr_accessor :modifierExtension      # 0-* [ Extension ]
      attr_accessor :outcomeCodeableConcept # 0-* [ CodeableConcept ]
      attr_accessor :outcomeReference       # 0-* [ Reference(Resource) ]
      attr_accessor :progress               # 0-* [ Annotation ]
      attr_accessor :reference              # 0-1 Reference(Appointment|CommunicationRequest|DeviceRequest|MedicationRequest|NutritionOrder|Task|ServiceRequest|VisionPrescription|RequestGroup)
      attr_accessor :detail                 # 0-1 CarePlan::Activity::Detail
    end

    attr_accessor :id                    # 0-1 id
    attr_accessor :meta                  # 0-1 Meta
    attr_accessor :implicitRules         # 0-1 uri
    attr_accessor :language              # 0-1 code
    attr_accessor :text                  # 0-1 Narrative
    attr_accessor :contained             # 0-* [ Resource ]
    attr_accessor :extension             # 0-* [ Extension ]
    attr_accessor :modifierExtension     # 0-* [ Extension ]
    attr_accessor :identifier            # 0-* [ Identifier ]
    attr_accessor :instantiatesCanonical # 0-* [ canonical ]
    attr_accessor :instantiatesUri       # 0-* [ uri ]
    attr_accessor :basedOn               # 0-* [ Reference(CarePlan) ]
    attr_accessor :replaces              # 0-* [ Reference(CarePlan) ]
    attr_accessor :partOf                # 0-* [ Reference(CarePlan) ]
    attr_accessor :status                # 1-1 code
    attr_accessor :intent                # 1-1 code
    attr_accessor :category              # 0-* [ CodeableConcept ]
    attr_accessor :title                 # 0-1 string
    attr_accessor :description           # 0-1 string
    attr_accessor :subject               # 1-1 Reference(Patient|Group)
    attr_accessor :encounter             # 0-1 Reference(Encounter)
    attr_accessor :period                # 0-1 Period
    attr_accessor :created               # 0-1 dateTime
    attr_accessor :author                # 0-1 Reference(Patient|Practitioner|PractitionerRole|Device|RelatedPerson|Organization|CareTeam)
    attr_accessor :contributor           # 0-* [ Reference(Patient|Practitioner|PractitionerRole|Device|RelatedPerson|Organization|CareTeam) ]
    attr_accessor :careTeam              # 0-* [ Reference(CareTeam) ]
    attr_accessor :addresses             # 0-* [ Reference(Condition) ]
    attr_accessor :supportingInfo        # 0-* [ Reference(Resource) ]
    attr_accessor :goal                  # 0-* [ Reference(Goal) ]
    attr_accessor :activity              # 0-* [ CarePlan::Activity ]
    attr_accessor :note                  # 0-* [ Annotation ]

    def resourceType
      'CarePlan'
    end
  end
end