module FHIR
  class Encounter < FHIR::Model
    include FHIR::Hashable
    include FHIR::Json
    include FHIR::Xml

    SEARCH_PARAMS = ['date', 'identifier', 'patient', 'type', 'account', 'appointment', 'based-on', 'class', 'diagnosis', 'episode-of-care', 'length', 'location', 'location-period', 'part-of', 'participant', 'participant-type', 'practitioner', 'reason-code', 'reason-reference', 'service-provider', 'special-arrangement', 'status', 'subject']
    METADATA = {
      'id' => {'type'=>'id', 'path'=>'Encounter.id', 'min'=>0, 'max'=>1},
      'meta' => {'type'=>'Meta', 'path'=>'Encounter.meta', 'min'=>0, 'max'=>1},
      'implicitRules' => {'type'=>'uri', 'path'=>'Encounter.implicitRules', 'min'=>0, 'max'=>1},
      'language' => {'valid_codes'=>{'urn:ietf:bcp:47'=>['ar', 'bn', 'cs', 'da', 'de', 'de-AT', 'de-CH', 'de-DE', 'el', 'en', 'en-AU', 'en-CA', 'en-GB', 'en-IN', 'en-NZ', 'en-SG', 'en-US', 'es', 'es-AR', 'es-ES', 'es-UY', 'fi', 'fr', 'fr-BE', 'fr-CH', 'fr-FR', 'fy', 'fy-NL', 'hi', 'hr', 'it', 'it-CH', 'it-IT', 'ja', 'ko', 'nl', 'nl-BE', 'nl-NL', 'no', 'no-NO', 'pa', 'pl', 'pt', 'pt-BR', 'ru', 'ru-RU', 'sr', 'sr-RS', 'sv', 'sv-SE', 'te', 'zh', 'zh-CN', 'zh-HK', 'zh-SG', 'zh-TW']}, 'type'=>'code', 'path'=>'Encounter.language', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'preferred', 'uri'=>'http://hl7.org/fhir/ValueSet/languages'}},
      'text' => {'type'=>'Narrative', 'path'=>'Encounter.text', 'min'=>0, 'max'=>1},
      'contained' => {'type'=>'Resource', 'path'=>'Encounter.contained', 'min'=>0, 'max'=>Float::INFINITY},
      'extension' => {'type'=>'Extension', 'path'=>'Encounter.extension', 'min'=>0, 'max'=>Float::INFINITY},
      'modifierExtension' => {'type'=>'Extension', 'path'=>'Encounter.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
      'identifier' => {'type'=>'Identifier', 'path'=>'Encounter.identifier', 'min'=>0, 'max'=>Float::INFINITY},
      'status' => {'valid_codes'=>{'http://hl7.org/fhir/encounter-status'=>['planned', 'arrived', 'triaged', 'in-progress', 'onleave', 'finished', 'cancelled', 'entered-in-error', 'unknown']}, 'type'=>'code', 'path'=>'Encounter.status', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/encounter-status'}},
      'statusHistory' => {'type'=>'Encounter::StatusHistory', 'path'=>'Encounter.statusHistory', 'min'=>0, 'max'=>Float::INFINITY},
      'class' => {'local_name'=>'local_class', 'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/v3-ActCode'=>['AMB', 'EMER', 'FLD', 'HH', 'IMP', 'ACUTE', 'NONAC', 'OBSENC', 'PRENC', 'SS', 'VR']}, 'type'=>'Coding', 'path'=>'Encounter.class', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://terminology.hl7.org/ValueSet/v3-ActEncounterCode'}},
      'classHistory' => {'type'=>'Encounter::ClassHistory', 'path'=>'Encounter.classHistory', 'min'=>0, 'max'=>Float::INFINITY},
      'type' => {'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/encounter-type'=>['ADMS', 'BD/BM-clin', 'CCS60', 'OKI']}, 'type'=>'CodeableConcept', 'path'=>'Encounter.type', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/encounter-type'}},
      'serviceType' => {'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/service-type'=>['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25', '26', '27', '28', '29', '30', '31', '32', '33', '34', '35', '36', '37', '38', '39', '40', '41', '42', '43', '44', '45', '46', '47', '48', '49', '50', '51', '52', '53', '54', '55', '56', '57', '58', '59', '60', '61', '62', '63', '64', '65', '66', '67', '68', '69', '70', '71', '72', '73', '74', '75', '76', '77', '78', '79', '80', '81', '82', '83', '84', '85', '86', '87', '88', '89', '90', '91', '92', '93', '94', '95', '96', '97', '98', '99', '100', '101', '102', '103', '104', '105', '106', '107', '108', '109', '110', '111', '112', '113', '114', '115', '116', '117', '118', '119', '120', '121', '122', '123', '124', '125', '126', '127', '128', '129', '130', '131', '132', '133', '134', '135', '136', '137', '138', '139', '140', '141', '142', '143', '144', '145', '146', '147', '148', '149', '150', '151', '152', '153', '154', '155', '156', '157', '158', '159', '160', '161', '162', '163', '164', '165', '166', '167', '168', '169', '170', '171', '172', '173', '174', '175', '176', '177', '178', '179', '180', '181', '182', '183', '184', '185', '186', '187', '188', '189', '190', '191', '192', '193', '194', '195', '196', '197', '198', '199', '200', '201', '202', '203', '204', '205', '206', '207', '208', '209', '210', '211', '212', '213', '214', '215', '216', '217', '218', '219', '220', '221', '222', '223', '224', '225', '226', '227', '228', '229', '230', '231', '232', '233', '234', '235', '236', '237', '238', '239', '240', '241', '242', '243', '244', '245', '246', '247', '248', '249', '250', '251', '252', '253', '254', '255', '256', '257', '258', '259', '260', '261', '262', '263', '264', '265', '266', '267', '268', '269', '270', '271', '272', '273', '274', '275', '276', '277', '278', '279', '280', '281', '282', '283', '284', '285', '286', '287', '288', '289', '290', '291', '292', '293', '294', '295', '296', '297', '298', '299', '300', '301', '302', '303', '304', '305', '306', '307', '308', '309', '310', '311', '312', '313', '314', '315', '316', '317', '318', '319', '320', '321', '322', '323', '324', '325', '326', '327', '328', '330', '331', '332', '333', '334', '335', '336', '337', '338', '339', '340', '341', '342', '343', '344', '345', '346', '347', '348', '349', '350', '351', '352', '353', '354', '355', '356', '357', '358', '359', '360', '361', '362', '364', '365', '366', '367', '368', '369', '370', '371', '372', '373', '374', '375', '376', '377', '378', '379', '380', '381', '382', '383', '384', '385', '386', '387', '388', '389', '390', '391', '392', '393', '394', '395', '396', '397', '398', '399', '400', '401', '402', '403', '404', '405', '406', '407', '408', '409', '410', '411', '412', '413', '414', '415', '416', '417', '418', '419', '420', '421', '422', '423', '424', '425', '426', '427', '428', '429', '430', '431', '432', '433', '434', '435', '436', '437', '438', '439', '440', '441', '442', '443', '444', '445', '446', '447', '448', '449', '450', '451', '452', '453', '454', '455', '456', '457', '458', '459', '460', '461', '462', '463', '464', '465', '466', '467', '468', '469', '470', '471', '472', '473', '474', '475', '476', '477', '478', '479', '480', '481', '482', '483', '484', '485', '486', '488', '489', '490', '491', '492', '493', '494', '495', '496', '497', '498', '500', '501', '502', '503', '504', '505', '506', '507', '508', '509', '510', '513', '514', '530', '531', '532', '533', '534', '535', '536', '537', '538', '539', '540', '541', '542', '543', '544', '545', '546', '547', '548', '550', '551', '552', '553', '554', '555', '556', '557', '558', '559', '560', '561', '562', '563', '564', '565', '566', '567', '568', '569', '570', '571', '572', '573', '574', '575', '576', '577', '580', '581', '582', '583', '584', '585', '589', '590', '591', '593', '599', '600', '601', '602', '603', '604', '605', '606', '607', '608', '609', '610', '611', '612', '613', '614', '615', '616', '617', '618', '619', '620', '621', '622', '623', '624', '625', '626', '627', '628', '629']}, 'type'=>'CodeableConcept', 'path'=>'Encounter.serviceType', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/service-type'}},
      'priority' => {'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/v3-ActPriority'=>['A', 'CR', 'CS', 'CSP', 'CSR', 'EL', 'EM', 'P', 'PRN', 'R', 'RR', 'S', 'T', 'UD', 'UR']}, 'type'=>'CodeableConcept', 'path'=>'Encounter.priority', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://terminology.hl7.org/ValueSet/v3-ActPriority'}},
      'subject' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Patient', 'http://hl7.org/fhir/StructureDefinition/Group'], 'type'=>'Reference', 'path'=>'Encounter.subject', 'min'=>0, 'max'=>1},
      'episodeOfCare' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/EpisodeOfCare'], 'type'=>'Reference', 'path'=>'Encounter.episodeOfCare', 'min'=>0, 'max'=>Float::INFINITY},
      'basedOn' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/ServiceRequest'], 'type'=>'Reference', 'path'=>'Encounter.basedOn', 'min'=>0, 'max'=>Float::INFINITY},
      'participant' => {'type'=>'Encounter::Participant', 'path'=>'Encounter.participant', 'min'=>0, 'max'=>Float::INFINITY},
      'appointment' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Appointment'], 'type'=>'Reference', 'path'=>'Encounter.appointment', 'min'=>0, 'max'=>Float::INFINITY},
      'period' => {'type'=>'Period', 'path'=>'Encounter.period', 'min'=>0, 'max'=>1},
      'length' => {'type'=>'Duration', 'path'=>'Encounter.length', 'min'=>0, 'max'=>1},
      'reasonCode' => {'valid_codes'=>{'http://snomed.info/sct'=>['109006', '122003', '127009', '129007', '134006', '140004', '144008', '147001', '150003', '151004', '162004', '165002', '168000', '171008', '172001', '175004', '177007', '179005', '181007', '183005', '184004', '188001', '192008', '193003', '195005', '198007', '199004', '208008', '216004', '219006', '222008', '223003', '228007', '241006', '242004', '253005', '257006', '258001', '264008', '276008', '279001', '281004', '282006', '290006', '292003', '297009', '299007', '303002', '308006', '310008', '313005', '317006', '320003', '324007', '330007', '335002', '341009', '349006', '355001', '357009', '358004', '359007', '360002', '364006', '366008', '368009', '369001', '378007', '382009', '383004', '385006', '387003', '398002', '407000', '408005', '409002', '426008', '431005', '437009', '440009', '442001', '443006', '447007', '450005', '452002', '460001', '467003', '470004', '479003', '486006', '488007', '490008', '496002', '504009', '517007', '518002', '520004', '527001', '536002', '539009', '547009', '548004', '554003', '555002', '563001', '568005', '586008', '590005', '596004', '599006', '600009', '602001', '607007', '610000', '613003', '615005', '616006', '626004', '631002', '634005', '640003', '643001', '646009', '649002', '651003', '652005', '655007', '658009', '663008', '664002', '666000', '675003', '682004', '685002', '701003', '703000', '714002', '715001', '718004', '733007', '734001', '736004', '750009', '755004', '756003', '758002', '775008', '776009', '781000', '786005', '787001', '788006', '792004', '799008', '801006', '805002', '811004', '813001', '815008', '816009', '818005', '825003', '827006', '832007', '834008', '841002', '842009', '843004', '844005', '845006', '849000', '857002', '862001', '865004', '871005', '874002', '875001', '888003', '890002', '899001', '903008', '904002', '908004', '919001', '928000', '931004', '932006', '934007', '943003', '954008', '961007', '962000', '964004', '965003', '975000', '978003', '981008', '984000', '987007', '991002', '998008', '1003002', '1020003', '1023001', '1027000', '1031006', '1033009', '1034003', '1038000', '1045000', '1046004', '1051005', '1055001', '1059007', '1070000', '1073003', '1074009', '1077002', '1079004', '1085006', '1089000', '1102005', '1107004', '1108009', '1111005', '1112003', '1116000', '1124005', '1125006', '1126007', '1131009', '1134001', '1135000', '1139006', '1140008', '1141007', '1145003', '1150009', '1151008', '1152001', '1155004', '1156003', '1168007', '1184008', '1192004', '1194003', '1196001', '1197005', '1201005', '1203008', '1207009', '1208004', '1212005', '1214006', '1230003', '1232006', '1239002', '1240000', '1259003', '1261007', '1264004', '1271009', '1280009', '1282001', '1283006', '1284000', '1286003', '1287007', '1297003', '1308001', '1310004', '1317001', '1318006', '1323006', '1332008', '1335005', '1343000', '1345007', '1351002', '1356007', '1361009', '1363007', '1367008', '1370007', '1372004', '1376001', '1378000', '1380006', '1383008', '1384002', '1386000', '1387009', '1388004', '1393001', '1395008', '1402001', '1412008', '1415005', '1418007', '1419004', '1426004', '1427008', '1430001', '1447000', '1469007', '1474004', '1475003', '1478001', '1479009', '1482004', '1486001', '1488000', '1489008', '1492007', '1493002', '1499003', '1512006', '1515008', '1518005', '1519002', '1521007', '1523005', '1525003', '1531000', '1532007', '1534008', '1538006', '1539003', '1542009', '1544005', '1551001', '1556006', '1563006', '1567007', '1588003', '1592005', '1593000', '1606009', '1608005', '1639007', '1647007', '1648002', '1654001', '1657008', '1658003', '1663004', '1667003', '1670004', '1671000', '1674008', '1679003', '1682008', '1685005', '1686006', '1694004', '1698001', '1703007', '1705000', '1708003', '1714005', '1717003', '1723008', '1724002', '1734006', '1735007', '1739001', '1742007', '1744008', '1748006', '1755008', '1761006', '1763009', '1767005', '1769008', '1771008', '1776003', '1777007', '1778002', '1779005', '1794009', '1816003', '1821000', '1822007', '1824008', '1826005', '1828006', '1829003', '1833005', '1835003', '1837006', '1845001', '1847009', '1848004', '1852004', '1855002', '1856001', '1857005', '1858000', '1860003', '1865008', '1869002', '1881003', '1892002', '1896004', '1897008', '1899006', '1903004', '1908008', '1909000', '1922008', '1926006', '1938002', '1939005', '1943009', '1953005', '1954004', '1955003', '1959009', '1961000', '1963002', '1965009', '1967001', '1973000', '1977004', '1979001', '1980003', '1981004', '1988005', '1989002', '2004005', '2012002', '2024009', '2028007', '2032001', '2036003', '2040007', '2041006', '2043009', '2053005', '2055003', '2058001', '2061000', '2065009', '2066005', '2070002', '2073000', '2087000', '2089002', '2091005', '2094002', '2102007', '2103002', '2107001', '2109003', '2114004', '2116002', '2120003', '2121004', '2128005', '2129002', '2132004', '2134003', '2136001', '2138000', '2145000', '2149006', '2158004', '2167004', '2169001', '2170000', '2176006', '2177002', '2186007', '2198002', '2202000', '2204004', '2213002', '2216005', '2217001', '2219003', '2224000', '2228002', '2229005', '2231001', '2237002', '2239004', '2241003', '2243000', '2245007', '2251002', '2256007', '2261009', '2268003', '2284002', '2295008', '2296009', '2298005', '2301009', '2303007', '2304001', '2307008', '2308003', '2312009', '2314005', '2326000', '2339001', '2341000', '2351004', '2355008', '2359002', '2365002', '2366001', '2367005', '2374000', '2385003', '2388001', '2390000', '2391001', '2396006', '2398007', '2403008', '2415007', '2418009', '2419001', '2420007', '2432006', '2435008', '2437000', '2438005', '2439002', '2443003', '2452007', '2463005', '2469009', '2470005', '2471009', '2472002', '2473007', '2477008', '2492009', '2495006', '2496007', '2506003', '2513003', '2518007', '2521009', '2523007', '2526004', '2528003', '2532009', '2534005', '2538008', '2541004', '2554006', '2556008', '2560006', '2562003', '2576002', '2581006', '2582004', '2583009', '2584003', '2585002', '2589008', '2591000', '2593002', '2602008', '2606006', '2615004', '2618002', '2622007', '2624008', '2625009', '2630008', '2634004', '2638001', '2640006', '2651006', '2655002', '2657005', '2663001', '2665008', '2683000', '2689001', '2694001', '2704003', '2707005', '2713001', '2724004', '2725003', '2733002', '2736005', '2740001', '2749000', '2751001', '2761008', '2764000', '2770006', '2772003', '2775001', '2776000', '2781009', '2782002', '2783007', '2786004', '2790002', '2805007', '2806008', '2807004', '2808009', '2815001', '2816000', '2818004', '2819007', '2825006', '2828008', '2829000', '2831009', '2835000', '2836004', '2838003', '2840008', '2850009', '2853006', '2856003', '2858002', '2884008', '2893009', '2897005', '2899008', '2900003', '2901004', '2902006', '2904007', '2910007', '2912004', '2917005', '2918000', '2919008', '2929001', '2935001', '2940009', '2946003', '2951009', '2955000', '2965006', '2967003', '2972007', '2973002', '2978006', '2981001', '2989004', '2990008', '2992000', '2994004', '2999009', '3002002', '3004001', '3006004', '3009006', '3013004', '3014005', '3018008', '3019000', '3021005', '3023008', '3032005', '3033000', '3038009', '3044008', '3053001', '3059002', '3067005', '3071008', '3072001', '3073006', '3084004', '3089009', '3094009', '3095005', '3097002', '3098007', '3105002', '3109008', '3110003', '3119002', '3129009', '3135009', '3140001', '3144005', '3158007', '3160009', '3163006', '3168002', '3185000', '3199001', '3200003', '3208005', '3214003', '3217005', '3218000', '3219008', '3228009', '3229001', '3230006', '3238004', '3239007', '3253007', '3254001', '3259006', '3261002', '3263004', '3272007', '3274008', '3275009', '3276005', '3277001', '3282008', '3283003', '3286006', '3289004', '3291007', '3298001', '3303004', '3304005', '3305006', '3308008', '3310005', '3321001', '3323003', '3327002', '3331008', '3344003', '3345002', '3355003', '3358001', '3368006', '3376008', '3381004', '3387000', '3391005', '3393008', '3398004', '3401001', '3415004', '3419005', '3421000', '3424008', '3426005', '3427001', '3434004', '3439009', '3441005', '3446000', '3449007', '3456001', '3458000', '3461004', '3464007', '3468005', '3469002', '3472009', '3474005', '3480002', '3482005', '3483000', '3487004', '3500002', '3502005', '3503000', '3505007', '3506008', '3507004', '3511005', '3514002', '3519007', '3528008', '3529000', '3530005', '3531009', '3533007', '3539006', '3542000', '3544004', '3545003', '3548001', '3549009', '3558002', '3560000', '3570003', '3571004', '3577000', '3585009', '3586005', '3589003', '3590007', '3591006', '3598000', '3611003', '3633001', '3634007', '3639002', '3640000', '3641001', '3642008', '3644009', '3649004', '3650004', '3652007', '3657001', '3660008', '3662000', '3677008', '3680009', '3681008', '3696007', '3699000', '3703002', '3704008', '3705009', '3712000', '3716002', '3720003', '3723001', '3733009', '3736001', '3738000', '3744001', '3745000', '3747008', '3750006', '3751005', '3752003', '3754002', '3755001', '3756000', '3759007', '3760002', '3762005', '3763000', '3783004', '3797007', '3798002', '3815005', '3820005', '3827008', '3830001', '3841004', '3845008', '3855007', '3859001', '3873005', '3885002', '3886001', '3899003', '3900008', '3902000', '3903005', '3908001', '3909009', '3913002', '3914008', '3928002', '3939004', '3944006', '3947004', '3950001', '3951002', '3972004', '3975002', '3978000', '3987009', '3993001', '3999002', '4003003', '4004009', '4006006', '4009004', '4016003', '4017007', '4022007', '4026005', '4030008', '4038001', '4039009', '4040006', '4041005', '4046000', '4062006', '4063001', '4069002', '4070001', '4075006', '4082005', '4088009', '4089001', '4092002', '4103001', '4106009', '4107000', '4113009', '4120002', '4124006', '4127004', '4129001', '4135001', '4136000', '4142001', '4152002', '4160001', '4168008', '4170004', '4174008', '4175009', '4178006', '4181001', '4183003', '4184009', '4191007', '4195003', '4197006', '4199009', '4208000', '4210003', '4223005', '4224004', '4225003', '4229009', '4232007', '4237001', '4240001', '4241002', '4242009', '4244005', '4248008', '4249000', '4251001', '4260009', '4262001', '4264000', '4269005', '4273008', '4275001', '4278004', '4283007', '4287008', '4294006', '4300009', '4301008', '4306003', '4307007', '4308002', '4310000', '4313003', '4316006', '4320005', '4324001', '4325000', '4332009', '4338008', '4340003', '4349002', '4354006', '4356008', '4359001', '4364002', '4367009', '4373005', '4374004', '4381006', '4386001', '4390004', '4397001', '4399003', '4403007', '4406004', '4409006', '4410001', '4412009', '4414005', '4416007', '4418008', '4426000', '4434006', '4439001', '4441000', '4445009', '4448006', '4451004', '4461006', '4463009', '4464003', '4465002', '4468000', '4470009', '4473006', '4477007', '4478002', '4481007', '4483005', '104001', '115006', '119000', '121005', '128004', '133000', '135007', '142007', '146005', '153001', '160007', '166001', '170009', '174000', '176003', '189009', '197002', '230009', '243009', '245002', '262007', '267001', '285008', '294002', '295001', '306005', '316002', '334003', '342002', '346004', '348003', '351005', '352003', '353008', '374009', '388008', '389000', '401004', '406009', '417005', '435001', '445004', '456004', '459006', '463004', '468008', '474008', '489004', '493005', '494004', '497006', '503003', '531007', '533005', '535003', '540006', '543008', '545001', '549007', '550007', '559008', '570001', '574005', '603006', '617002', '618007', '625000', '628003', '629006', '633004', '637003', '642006', '645008', '647000', '657004', '665001', '670008', '671007', '673005', '674004', '676002', '680007', '687005', '695009', '697001', '710006', '712003', '721002', '722009', '726007', '730005', '741007', '746002', '753006', '754000', '759005', '762008', '764009', '767002', '789003', '791006', '807005', '814007', '817000', '831000', '851001', '853003', '867007', '870006', '879007', '881009', '893000', '897004', '910002', '911003', '913000', '926001', '935008', '941001', '945005', '948007', '951000', '956005', '967006', '969009', '971009', '1001000', '1008006', '1019009', '1021004', '1029002', '1032004', '1035002', '1036001', '1041009', '1042002', '1043007', '1044001', '1048003', '1054002', '1071001', '1084005', '1093006', '1103000', '1104006', '1115001', '1119007', '1121002', '1127003', '1133007', '1163003', '1176009', '1181000', '1186005', '1198000', '1209007', '1225002', '1227005', '1235008', '1237000', '1238005', '1251000', '1253002', '1258006', '1266002', '1267006', '1278003', '1279006', '1292009', '1299000', '1315009', '1316005', '1324000', '1327007', '1328002', '1329005', '1337002', '1339004', '1347004', '1352009', '1358008', '1366004', '1385001', '1390003', '1398005', '1399002', '1407007', '1410000', '1411001', '1413003', '1414009', '1417002', '1431002', '1440003', '1449002', '1453000', '1455007', '1457004', '1494008', '1500007', '1501006', '1505002', '1529009', '1533002', '1550000', '1555005', '1559004', '1576000', '1577009', '1578004', '1583007', '1585000', '1596008', '1597004', '1602006', '1614003', '1615002', '1616001', '1636000', '1638004', '1640009', '1645004', '1651009', '1653007', '1669000', '1677001', '1678006', '1680000', '1683003', '1689004', '1691007', '1699009', '1702002', '1704001', '1709006', '1712009', '1713004', '1730002', '1746005', '1747001', '1753001', '1757000', '1759002', '1770009', '1774000', '1775004', '1784004', '1787006', '1788001', '1801001', '1805005', '1811008', '1813006', '1820004', '1830008', '1836002', '1844002', '1854003', '1859008', '1861004', '1862006', '1866009', '1868005', '1870001', '1871002', '1872009', '1876007', '1879000', '1889001', '1906007', '1907003', '1917008', '1924009', '1950008', '1958001', '1966005', '1983001', '1995001', '1999007', '2002009', '2021001', '2051007', '2054004', '2067001', '2069003', '2078009', '2079001', '2080003', '2098004', '2115003', '2119009', '2127000', '2137005', '2153008', '2161003', '2164006', '2166008', '2171001', '2178007', '2181002', '2188008', '2193006', '2196003', '2199005', '2214008', '2220009', '2225004', '2234009', '2238007', '2242005', '2244006', '2250001', '2252009', '2266004', '2267008', '2270007', '2276001', '2278000', '2279008', '2290003', '2315006', '2318008', '2321005', '2322003', '2337004', '2344008', '2347001', '2364003', '2371008', '2373006', '2382000', '2386002', '2393003', '2406000', '2407009', '2408004', '2409007', '2425002', '2442008', '2448007', '2455009', '2457001', '2458006', '2459003', '2461007', '2474001', '2475000', '2480009', '2486003', '2488002', '2494005', '2498008', '2507007', '2508002', '2514009', '2517002', '2530001', '2531002', '2535006', '2536007', '2547000', '2552005', '2564002', '2566000', '2567009', '2580007', '2598006', '2601001', '2607002', '2613006', '2614000', '2616003', '2619005', '2629003', '2632000', '2642003', '2643008', '2644002', '2645001', '2646000', '2658000', '2659008', '2668005', '2670001', '2673004', '2677003', '2690005', '2693007', '2696004', '2697008', '2716009', '2722000', '2731000', '2732007', '2737001', '2742009', '2743004', '2745006', '2752008', '2780005', '2794006', '2802005', '2811005', '2813008', '2837008', '2842000', '2843005', '2847006', '2851008', '2854000', '2857007', '2866006', '2875008', '2876009', '2885009', '2891006', '2898000', '2903001', '2908005', '2914003', '2915002', '2933008', '2945004', '2947007', '2960001', '2968008', '2970004', '2971000', '2977001', '3001009', '3010001', '3016007', '3025001', '3026000', '3029007', '3041000', '3047001', '3060007', '3061006', '3063009', '3075004', '3078002', '3083005', '3088001', '3090000', '3112006', '3116009', '3130004', '3133002', '3137001', '3143004', '3162001', '3164000', '3165004', '3166003', '3177009', '3183007', '3186004', '3190002', '3204007', '3241008', '3249005', '3251009', '3256004', '3257008', '3258003', '3268008', '3270004', '3278006', '3287002', '3320000', '3324009', '3326006', '3328007', '3333006', '3338002', '3352000', '3357006', '3360004', '3390006', '3399007', '3407002', '3413006', '3418002', '3432000', '3443008', '3448004', '3450007', '3457005', '3479000', '3498003', '3499006', '3509001', '3512003', '3515001', '3517009', '3518004', '3527003', '3546002', '3559005', '3562008', '3564009', '3575008', '3580004', '3605001', '3607009', '3620007', '3625002', '3651000', '3654008', '3659003', '3664004', '3666002', '3669009', '3673007', '3683006', '3686003', '3688002', '3690001', '3691002', '3697003', '3700004', '3701000', '3713005', '3717006', '3734003', '3735002', '3740005', '3748003', '3749006', '3758004', '3770000', '3778007', '3780001', '3784005', '3786007', '3787003', '3794000', '3796003', '3799005', '3802001', '3819004', '3826004', '3828003', '3831002', '3843001', '3858009', '3861005', '3862003', '3864002', '3880007', '3881006', '3887005', '3889008', '3891000', '3895009', '3907006', '3911000', '3915009', '3917001', '3918006', '3926003', '3929005', '3936006', '3938007', '3942005', '3955006', '3957003', '3963007', '3967008', '3968003', '3969006', '3971006', '3980006', '3981005', '3985001', '3991004', '3998005', '4007002', '4008007', '4010009', '4027001', '4034004', '4035003', '4036002', '4037006', '4044002', '4045001', '4052004', '4064007', '4068005', '4083000', '4084006', '4090005', '4094001', '4101004', '4102006', '4114003', '4116001', '4119008', '4131005', '4134002', '4139007', '4143006', '4149005', '4154001', '4165006', '4176005', '4192000', '4213001', '4214007', '4226002', '4252008', '4263006', '4266003', '4285000', '4293000', '4304000', '4319004', '4321009', '4323007', '4331002', '4333004', '4336007', '4337003', '4339000', '4341004', '4344007', '4348005', '4350002', '4363008', '4365001', '4380007', '4387005', '4388000', '4407008', '4411002', '4420006', '4424002', '4436008', '4438009', '4443002', '4447001', '4449003', '4450003', '4455008', '4457000', '4466001', '4467005', '4475004', '4487006', '4489009', '4496006', '4503005', '4504004', '4505003', '4507006', '4511000', '4516005', '4520009', '4525004', '4533003', '4535005', '4539004', '4542005', '4544006', '4558008', '4563007', '4570007', '4579008', '4581005', '4585001', '4587009', '4589007', '4593001', '4594007', '4613005', '4625008', '4626009', '4636001', '4640005', '4642002', '4660002', '4670000', '4671001', '4672008', '4691008', '4692001', '4694000', '4699005', '4701005', '4707009', '4712005', '4713000', '4719001', '4727005', '4734007', '4737000', '4756005', '4758006', '4764004', '4765003', '4770005', '4772002', '4784000', '4804005', '4811009', '4815000', '4820000', '4827002', '4829004', '4847005', '4849008', '4862007', '4877004', '4891005', '4895001', '4902005', '4903000', '4904006', '4914002', '4929000', '4930005', '4934001', '4957007', '4966006', '4970003', '4974007', '4976009', '4987001', '4992004', '4993009', '5016005', '5019003', '5021008', '5022001', '5025004', '5032008', '5034009', '5048009', '5055006', '5057003', '5065000', '5091004', '5105000', '5110001', '5113004', '5119000', '5121005', '5123008', '5130002', '5131003', '5135007', '5147001', '5151004', '5154007', '5161006', '5162004', '5165002', '5176003', '5182000', '5184004', '5186002', '5190000', '5191001', '5212002', '5216004', '5233006', '5243009', '5245002', '5246001', '5264008', '5267001', '5270002', '5273000', '5282006', '5290006', '5298004', '5304008', '5316002', '5317006', '5326009', '5328005', '5337005', '5338000', '5342002', '5348003', '5357009', '5373003', '5384005', '5391008', '5393006', '5402006', '5407000', '5415002', '5419008', '5422005', '5429001', '5431005', '5433008', '5446003', '5447007', '5452002', '5456004', '5457008', '5460001', '5479003', '5482008', '5486006', '5489004', '5506006', '5517007', '5521000', '5536002', '5545001', '5551006', '5556001', '5570001', '5571002', '5572009', '5586008', '5608002', '5616006', '5621009', '5632009', '5636007', '5638008', '5648005', '5651003', '5663008', '5669007', '5671007', '5687005', '5690004', '5694008', '5721002', '5722009', '5726007', '5728008', '5731009', '5733007', '5738003', '5745003', '5760000', '5771004', '5777000', '5781000', '5785009', '5787001', '5789003', '5796001', '5806001', '5807005', '5809008', '5812006', '5818005', '5821007', '5823005', '5832007', '5845006', '5846007', '5857002', '5865004', '5870006', '5880005', '5892005', '5894006', '5897004', '5902003', '5925002', '5930003', '5947002', '5961007', '5966002', '5971009', '5983006', '5986003', '5992009', '5995006', '5997003', '5998008', '6005008', '6007000', '6019008', '6025007', '6026008', '6029001', '6035001', '6063004', '6069000', '6082008', '6092000', '6100001', '6108008', '6119006', '6125005', '6126006', '6127002', '6130009', '6133006', '6143009', '6146001', '6148000', '6157006', '6159009', '6161000', '6164008', '6166005', '6177004', '6187000', '6188005', '6189002', '6190006', '6195001', '6198004', '6200005', '6205000', '6213004', '6221005', '6225001', '6226000', '6227009', '6231003', '6238009', '6240004', '6255008', '6271008', '6274000', '6286002', '6289009', '6295005', '6307005', '6309008', '6319002', '6337001', '6339003', '6343004', '6353003', '6354009', '6355005', '6358007', '6361008', '6363006', '6370006', '6384001', '6385000', '6388003', '6396008', '6397004', '6399001', '6402000', '6403005', '6419003', '6429005', '6433003', '6434009', '6438007', '6439004', '6443000', '6444006', '6465000', '6466004', '6470007', '6473009', '6480006', '6486000', '6487009', '6491004', '6499002', '6502003', '6506000', '6519001', '6521006', '6527005', '6535008', '6536009', '6543003', '6547002', '6555009', '6556005', '6562000', '6563005', '6567006', '6568001', '6585004', '6589005', '6601003', '6614002', '6615001', '6622009', '6634001', '6639006', '6650009', '6656003', '6657007', '6658002', '6661001', '6665005', '6668007', '6670003', '702005', '837001', '1296007', '1807002', '2636002', '2769005', '3267003', '5462009', '5761001', '6192003', '7185004', '7335003', '7729001', '8115005', '11363007', '11981004', '13117000', '14252008', '15274006', '17397008', '17862002', '18253009', '18385005', '19853007', '20210009', '20729004', '22964006', '23125004', '24609004', '25007007', '26684009', '27139003', '28281004', '29150008', '29450001', '30459002', '31518001', '32001009', '33159007', '33543001', '33678008', '33993005', '34189007', '37012003', '38897008', '40220006', '40462002', '40893006', '41302009', '41518004', '41769001', '43000004', '44409003', '44442002', '44473003', '45145000', '45780005', '46029008', '46508005', '47354006', '47426000', '47768001', '48591001', '48994000', '50433005', '51435005', '51436006', '51738008', '52018002', '52278004', '52787007', '54267006', '54897008', '55493009', '55618006', '55726006', '55993003', '56199006', '56330003', '57177007', '57600009', '58064004', '59383005', '59738006', '60016005', '60521000', '60801006', '61236006', '61269006', '62120000', '62232005', '62696001', '62965008', '63196005', '65329004', '66325000', '66678007', '68034005', '70790008', '71101001', '71738007', '72269009', '72375002', '72604007', '73359007', '73487002', '75151002', '75538004', '75584009', '75844008', '76063002', '77291009', '77670007', '77739005', '78698008', '79622006', '81585005', '81765008', '81993002', '82120007', '82630002', '85125009', '86699002', '86894005', '86914005', '87246008', '87351004', '88500006', '88715005', '88764002', '88994001', '89777000', '90075008', '90232009', '90881001', '91436001', '91559009', '95311001', '95312008', '95313003', '95314009', '95667004', '95672008', '95721006', '95819006', '102905003', '103006007', '103709008', '105480006', '109547005', '109719008', '109723000', '111690007', '116789007', '116791004', '116794007', '116796009', '116799002', '116801004', '116804007', '116807000', '116809002', '116811006', '116814003', '116860001', '116862009', '116864005', '116866007', '117067008', '117068003', '117077005', '117079008', '117080006', '117082003', '117084002', '117088004', '117091004', '117094007', '117097000', '117098005', '117099002', '117100005', '117101009', '124743003', '124744009', '124745005', '124746006', '127377003', '129125009', '134385008', '134386009', '134390006', '134391005', '134392003', '134394002', '134396000', '134397009', '134398004', '134405005', '134420004', '134439009', '135794007', '135795008', '135796009', '135797000', '135798005', '135799002', '135800003', '135801004', '135803001', '135805008', '135806009', '135807000', '135808005', '135809002', '135811006', '135812004', '135814003', '135822005', '135823000', '135825007', '135826008', '135844000', '135866007', '135879003', '146922001', '147022006', '148176006', '148297000', '148324002', '148477008', '149129005', '150159003', '160240006', '160241005', '160242003', '160245001', '160250007', '160252004', '160253009', '160254003', '160255002', '160256001', '160257005', '160258000', '160259008', '160265008', '160266009', '160267000', '160268005', '160269002', '160270001', '160271002', '160273004', '160274005', '160279000', '160280002', '160281003', '160282005', '160288009', '160290005', '160291009', '160292002', '160297008', '160298003', '160299006', '160301004', '160302006', '160303001', '160305008', '160306009', '160308005', '160309002', '160310007', '160311006', '160312004', '160313009', '160314003', '160316001', '160318000', '160319008', '160320002', '160321003', '160324006', '160325007', '160327004', '160328009', '160329001', '160331005', '160332003', '160333008', '160336000', '160337009', '160338004', '160339007', '160340009', '160341008', '160342001', '160343006', '160344000', '160346003', '160347007', '160348002', '160350005', '160352002', '160353007', '160354001', '160357008', '160362009', '160363004', '160364005', '160377001', '160378006', '160379003', '160381001', '160386006', '160389004', '160390008', '160391007', '160392000', '160393005', '160394004', '160396002', '160397006', '160398001', '160400002', '160401003', '160402005', '160403000', '160406008', '160407004', '160408009', '160409001', '160410006', '160413008', '160414002', '160417009', '160418004', '160419007', '160421002', '160422009', '160423004', '160424005', '160425006', '160427003', '160428008', '160429000', '160430005', '160431009', '160433007', '160434001', '160435000', '160436004', '160437008', '160439006', '160440008', '160441007', '160442000', '160444004', '160445003', '160446002', '160447006', '160449009', '160450009', '160451008', '160452001', '160454000', '160455004', '160456003', '160457007', '160460000', '160461001', '160462008', '160463003', '160464009', '160465005', '160469004', '160471004', '160472006', '160473001', '160474007', '160475008', '160776008', '160806000', '160807009', '160853002', '160854008', '160855009', '160856005', '160859003', '160860008', '160861007', '160875000', '160884000', '160885004', '160886003', '160888002', '160890001', '160891002', '160947001', '160948006', '160949003', '160953001', '161062006', '161067000', '161075006', '161077003', '161078008', '161079000', '161413004', '161414005', '161415006', '161416007', '161417003', '161419000', '161420006', '161421005', '161422003', '161423008', '161424002', '161432005', '161436008', '161442007', '161443002', '161445009', '161449003', '161450003', '161451004', '161453001', '161456009', '161457000', '161458005', '161460007', '161461006', '161462004', '161464003', '161465002', '161466001', '161467005', '161468000', '161469008', '161470009', '161471008', '161472001', '161473006', '161474000', '161478002', '161479005', '161480008', '161481007', '161482000', '161483005', '161486002', '161487006', '161488001', '161489009', '161490000', '161491001', '161494009', '161496006', '161497002', '161500008', '161501007', '161502000', '161503005', '161504004', '161505003', '161508001', '161509009', '161511000', '161512007', '161513002', '161514008', '161515009', '161523006', '161524000', '161525004', '161527007', '161528002', '161532008', '161533003', '161535005', '161536006', '161538007', '161539004', '161541003', '161542005', '161546008', '161547004', '161548009', '161549001', '161550001', '161551002', '161554005', '161555006', '161556007', '161558008', '161560005', '161561009', '161562002', '161563007', '161567008', '161568003', '161570007', '161572004', '161573009', '161574003', '161575002', '161576001', '161577005', '161579008', '161580006', '161581005', '161582003', '161583008', '161584002', '161586000', '161587009', '161589007', '161611007', '161614004', '161615003', '161616002', '161617006', '161618001', '161619009', '161621004', '161622006', '161624007', '161625008', '161626009', '161627000', '161632004', '161633009', '161635002', '161636001', '161637005', '161638000', '161646004', '161647008', '161648003', '161649006', '161650006', '161651005', '161652003', '161653008', '161656000', '161659007', '161660002', '161663000', '161664006', '161665007', '161666008', '161667004', '161668009', '161669001', '161670000', '161671001', '161672008', '161674009', '161675005', '161676006', '161677002', '161678007', '161679004', '161680001', '161681002', '161682009', '161685006', '161686007', '161687003', '161689000', '161692001', '161693006', '161694000', '161696003', '161697007', '161700006', '161701005', '161743003', '161744009', '161745005', '161747002', '161748007', '161749004', '161750004', '161751000', '161752007', '161755009', '161763005', '161765003', '161767006', '161768001', '161769009', '161772002', '161773007', '161774001', '161775000', '161779006', '161780009', '161781008', '161782001', '161783006', '161786003', '161787007', '161788002', '161792009', '161794005', '161796007', '161797003', '161798008', '161800001', '161803004', '161804005', '161805006', '161806007', '161807003', '161808008', '161809000', '161810005', '161811009', '161813007', '161851007', '161869003', '161881004', '161886009', '161890006', '161915001', '161922009', '161927003', '161928008', '161938003', '161953006', '161954000', '161962008', '161966006', '161971004', '161980004', '162001003', '162005007', '162010006', '162019007', '162023004', '162037008', '162056003', '162057007', '162062008', '162069004', '162075008', '162085009', '162086005', '162104009', '162111008', '162139009', '162154003', '162157005', '162158000', '162161004', '162162006', '162185007', '162235006', '162241004', '162258009', '162260006', '162261005', '162264002', '162271007', '162275003', '162293002', '162298006', '162342008', '162350004', '162357001', '162358006', '162363005', '162364004', '162368001', '162372002', '162376004', '162379006', '162387007', '162388002', '162395006', '162406001', '162467007', '162572001', '162573006', '162591001', '162592008', '162593003', '162594009', '162596006', '162649008', '162650008', '162651007', '162653005', '162654004', '162655003', '162674006', '162675007', '162780006', '162784002', '162811006', '162838004', '162881001', '162882008', '162963000', '162971001', '162972008', '162979004', '162980001', '163045005', '163046006', '163047002', '163048007', '163068001', '163084000', '163088002', '163127007', '163128002', '163142005', '163198005', '163207001', '163213005', '163225008', '163237005', '163249006', '163253008', '163266008', '163271001', '163279004', '163310006', '163316000', '163347006', '163348001', '163354000', '163355004', '163361001', '163375008', '163423003', '163458001', '163466005', '163492003', '163536000', '163543006', '163557008', '163560001', '163581001', '163582008', '163589004', '163599009', '163628001', '163631000', '163657002', '163663006', '163731007', '163757005', '163763001', '163764007', '163772009', '163773004', '163846005', '163900009', '163904000', '163909005', '163913003', '163915005', '163918007', '164016004', '164041006', '164073000', '164140005', '164163000', '164176006', '164183004', '164212007', '164220009', '164273009', '164286000', '164321005', '164329007', '164332005', '164333000', '164336008', '164340004', '164344008', '164348006', '164355008', '164362004', '164366001', '164372001', '164376003', '164377007', '164380008', '164384004', '164390000', '164396006', '164400006', '164406000', '164415007', '164445005', '164503006', '164507007', '164525000', '164549002', '164558009', '164574004', '164588000', '164598006', '164618002', '164682005', '164689001', '164695000', '164713001', '164715008', '164719002', '164725003', '164726002', '164746007', '164747003', '164766003', '164767007', '164776000', '164777009', '164786004', '164787008', '164795007', '164796008', '164808009', '164810006', '164823004', '164824005', '164831009', '164832002', '164846002', '164853006', '164963004', '164964005', '164977001', '164978006', '164984009', '164985005', '164996002', '164997006', '165007007', '165008002', '165016006', '165017002', '165025000', '165026004', '165034005', '165035006', '165068004', '165073005', '165074004', '165080007', '165081006', '165104002', '165121006', '165122004', '165137000', '165138005', '165139002', '165146006', '165278005', '165330008', '165331007', '165332000', '165333005', '165334004', '165335003', '165336002', '165337006', '165339009', '165340006', '165342003', '165343008', '165346000', '165348004', '165349007', '165350007', '165351006', '165352004', '165353009', '165355002', '165356001', '165357005', '165358000', '165372009', '165373004', '165374005', '165375006', '165376007', '165377003', '165378008', '165393007', '165394001', '165395000', '165742001', '165761002', '165762009', '165766007', '165768008', '165790008', '165803005', '165814008', '165819003', '165824000', '165928001', '166314008', '166557002', '166660001', '166684009', '166813006', '167007008', '167056009', '167219008', '167220002', '167223000', '167253007', '167260001', '167272007', '167286006', '167296002', '167306007', '167317008', '167322008', '167331008', '167594003', '167595002', '167666002', '167701000', '167702007', '167728005', '167760002', '167822002', '167854006', '167861005', '167909009', '167946008', '167984002', '168009009', '168033003', '168085001', '168123008', '168173006', '168195005', '168196006', '168215000', '168221001', '168286009', '168287000', '168302007', '168305009', '168306005', '168307001', '168308006', '168312000', '168313005', '168314004', '168315003', '168316002', '168321004', '168330007', '168331006', '168332004', '168336001', '168337005', '168338000', '168339008', '168342002', '168345000', '168352003', '168353008', '168354002', '168359007', '168364006', '168369001', '168372008', '168373003', '168374009', '168375005', '168395004', '168396003', '168428009', '168429001', '168430006', '168431005', '168432003', '168433008', '168434002', '168435001', '168436000', '168437009', '168438004', '168441008', '168446003', '168451009', '168462009', '168465006', '891003', '1210002', '1428003', '1762004', '1912002', '2617007', '3974003', '4521008', '5062002', '5193003', '5236003', '5331006', '5866003', '5941001', '6300007', '6476001', '7420003', '7878000', '8766005', '9855000', '10588007', '10598001', '11385001', '12994004', '13234002', '13278006', '13711007', '13935005', '14035003', '14047009', '15185003', '15355001', '15654006', '16445007', '16983000', '17542004', '17766007', '17886000', '17982002', '18055005', '18870005', '18893004', '19224001', '19349004', '20757006', '20902002', '20936008', '20974000', '21902005', '22439003', '23233009', '23321002', '23361001', '23546003', '23776007', '23791009', '24454008', '24780005', '25318002', '25455001', '25692008', '26636000', '26878008', '27792001', '27935005', '28064001', '28631002', '29444006', '31868001', '32175001', '33036003', '34468006', '35149008', '35314007', '35468003', '36153001', '36882002', '37169002', '37383006', '37806009', '37933009', '38605008', '39109007', '39262008', '39379000', '39399006', '39826003', '40104005', '40358007', '40537000', '40785002', '40947009', '41358001', '41411008', '42310008', '43682008', '44174001', '44188002', '44301001', '44633000', '45216005', '45224000', '45477008', '46851004', '47044002', '47193005', '47235009', '48015001', '48071004', '48981002', '49061008', '49113003', '49215004', '49250007', '49380000', '49713007', '49905000', '50032005', '50084004', '50105002', '50109008', '50363002', '50514002', '51347003', '51709005', '52136000', '52684005', '53559009', '53846008', '54670004', '54719000', '55225009', '55554002', '55566008', '56102008', '56307009', '56962005', '57135007', '57371001', '57701003', '57741007', '58538004', '58908002', '59262002', '59283008', '59510000', '60257006', '60594001', '62475002', '63148005', '63409001', '65037004', '65819004', '66360006', '66411002', '66466001', '67223001', '67292001', '67313008', '67622000', '67786008', '67916006', '68023007', '68062003', '68274007', '69129000', '69165005', '70055007', '70167006', '70579001', '71893005', '72738009', '74105006', '74148000', '74332007', '74376000', '74509007', '74541001', '74601003', '74660000', '74683002', '75354000', '75941004', '77105004', '77588008', '77740007', '77993003', '78070009', '78078002', '78331008', '78361000', '78387000', '78427001', '78583002', '78672002', '78857004', '79573009', '79835004', '79867001', '80295006', '80580005', '81840004', '82145005', '82313006', '82612009', '82621005', '82947003', '83208000', '83468000', '84026000', '84768009', '84829006', '85261005', '86591008', '87281005', '87309006', '88051009', '88644004', '88817006', '90049009', '90097005', '90569008', '90619006', '90639005', '90757003', '90978007', '91519006', '95866005', '95871003', '95875007', '95920001', '95921002', '95922009', '102406006', '102410009', '102411008', '102412001', '102413006', '102414000', '102415004', '102416003', '102417007', '102418002', '102420004', '102421000', '102422007', '102423002', '102424008', '102425009', '102426005', '102427001', '102428006', '102429003', '102430008', '102431007', '102432000', '102433005', '102434004', '102435003', '102436002', '102437006', '102439009', '102440006', '102441005', '102442003', '102443008', '102444002', '102445001', '102446000', '105441003', '105442005', '105443000', '105444006', '105445007', '105446008', '105447004', '111056004', '111942003', '115964003', '115965002', '122866006', '129674006', '135829001', '135868008', '160956009', '160957000', '160958005', '160960007', '160961006', '160962004', '160963009', '160964003', '160965002', '160966001', '161151009', '170475009', '199607009', '199608004', '200155004', '200156003', '206258000', '206259008', '212976008', '212979001', '213004004', '213007006', '213017001', '213770003', '213771004', '213772006', '213773001', '213774007', '213775008', '213776009', '213779002', '213780004', '213781000', '213782007', '213783002', '213795002', '213796001', '213797005', '213798000', '213799008', '213802004', '213803009', '213804003', '213805002', '213806001', '213809008', '213810003', '213811004', '213812006', '213813001', '213816009', '213817000', '213818005', '213819002', '213820008', '213823005', '213824004', '213825003', '213826002', '213827006', '213831000', '213833002', '213834008', '213835009', '213859004', '213860009', '213861008', '213862001', '213863006', '213864000', '213867007', '213869005', '213870006', '213871005', '213881009', '213882002', '213883007', '213884001', '213885000', '213886004', '213889006', '213890002', '213893000', '213894006', '213897004', '213898009', '213899001', '213900006', '213901005', '213911003', '213912005', '213913000', '213914006', '213917004', '213918009', '213919001', '213920007', '213922004', '213925002', '213926001', '213927005', '213937000', '213938005', '213939002', '213940000', '213941001', '213942008', '213945005', '213946006', '213947002', '213948007', '213949004', '213952007', '213953002', '213954008', '213955009', '213956005', '213959003', '213960008', '213961007', '213962000', '213963005', '213974001', '213975000', '213976004', '213980009', '213981008', '213982001', '213983006', '213986003', '213987007', '213988002', '213989005', '213990001', '213993004', '213995006', '213996007', '213997003', '213998008', '214031005', '214032003', '214056004', '214080000', '214081001', '214082008', '214085005', '214086006', '214089004', '214090008', '214092000', '214095003', '214096002', '214098001', '214099009', '214100001', '214101002', '214102009', '214104005', '214106007', '214107003', '214108008', '214109000', '214110005', '214111009', '214112002', '214113007', '214115000', '214116004', '214118003', '214119006', '214120000', '214121001', '214123003', '214124009', '214126006', '214127002', '214128007', '214129004', '214131008', '214132001', '214134000', '214135004', '214149008', '214150008', '214151007', '214154004', '214155003', '214156002', '214160004', '214161000', '214162007', '214164008', '214165009', '214166005', '214168006', '214171003', '214172005', '214174006', '214175007', '214176008', '214177004', '214179001', '214180003', '214183001', '214184007', '214185008', '214186009', '214188005', '214189002', '214190006', '214191005', '214206004', '214207008', '214208003', '214209006', '214210001', '214211002', '214212009', '214213004', '214215006', '214218008', '214219000', '214220006', '214221005', '214222003', '214223008', '214224002', '214225001', '214227009', '214230002', '214231003', '214232005', '214233000', '214234006', '214235007', '214236008', '214237004', '214253001', '214254007', '214255008', '214256009', '214257000', '214258005', '214259002', '214260007', '214265002', '214266001', '214267005', '214269008', '214270009', '214271008', '214272001', '214273006', '214276003', '214277007', '214278002', '214279005', '214280008', '214281007', '214282000', '214284004', '214287006', '214288001', '214289009', '214291001', '214292008', '214293003', '214294009', '214295005', '214296006', '214299004', '214300007', '214301006', '214304003', '214305002', '214306001', '214307005', '214308000', '214311004', '214312006', '214313001', '214314007', '214315008', '214316009', '214317000', '214318005', '214319002', '214322000', '214323005', '214324004', '214325003', '214326002', '214327006', '214328001', '214329009', '214330004', '214344005', '214345006', '214346007', '214347003', '214348008', '214349000', '214350000', '214352008', '214353003', '214356006', '214357002', '214358007', '214359004', '214360009', '214361008', '214362001', '214363006', '214364000', '214367007', '214368002', '214369005', '214370006', '214371005', '214372003', '214373008', '214374002', '214378004', '214379007', '214380005', '214381009', '214384001', '214385000', '214386004', '214389006', '214390002', '214391003', '214392005', '214393000', '214394006', '214395007', '214396008', '214397004', '214400008', '214401007', '214402000', '214403005', '214405003', '214406002', '214407006', '214408001', '214409009', '214412007', '214413002', '214414008', '214415009', '214416005', '214417001', '214418006', '214419003', '214420009', '214435005', '214436006', '214437002', '214438007', '214439004', '214440002', '214441003', '214442005', '214443000', '214444006', '214447004', '214448009', '214449001', '214450001', '214451002', '214452009', '214453004', '214454005', '214455006', '214458008', '214459000', '214460005', '214462002', '214464001', '214465000', '214466004', '214469006', '214471006', '214472004', '214473009', '214474003', '214475002', '214476001', '214477005', '214515007', '214516008', '214517004', '214518009', '214520007', '214521006', '214523009', '214526001', '214527005', '214528000', '214529008', '214530003', '214531004', '214532006', '214533001', '214534007', '214537000', '214538005', '214539002', '214540000', '214541001', '214542008', '214543003', '214544009', '214545005', '214548007', '214549004', '214550004', '214551000', '214552007', '214553002', '214555009', '214556005', '214559003', '214560008', '214561007', '214562000', '214563005', '214564004', '214565003', '214566002', '214570005', '214571009', '214572002', '214573007', '214574001', '214575000', '214576004', '214577008', '214578003', '214581008', '214582001', '214584000', '214585004', '214586003', '214587007', '214588002', '214589005', '214592009', '214593004', '214594005', '214595006', '214596007', '214597003', '214598008', '214599000', '214601003', '214604006', '214605007', '214606008', '214607004', '214609001', '214610006', '214611005', '214613008', '214640008', '214641007', '214642000', '214643005', '214644004', '214645003', '214646002', '214647006', '214648001', '214649009', '214650009', '214653006', '214654000', '214656003', '214657007', '214658002', '214659005', '214661001', '214662008', '214665005', '214666006', '214667002', '214668007', '214669004', '214670003', '214671004', '214672006', '214673001', '214676009', '214678005', '214680004', '214681000', '214682007', '214683002', '214687001', '214688006', '214689003', '214690007', '214691006', '214692004', '214693009', '214694003', '214695002', '214698000', '214699008', '214702001', '214703006', '214704000', '214705004', '214722002', '214724001', '214725000', '214726004', '214727008', '214728003', '214729006', '214730001', '214733004', '214734005', '214735006', '214736007', '214737003', '214738008', '214740003', '214741004', '214744007', '214745008', '214746009', '214747000', '214748005', '214749002', '214750002', '214751003', '214752005', '214755007', '214756008', '214757004', '214758009', '214759001', '214760006', '214761005', '214762003', '214763008', '214766000', '214767009', '214768004', '214769007', '214770008', '214771007', '214772000', '214773005', '214774004', '214777006', '214778001', '214779009', '214780007', '214781006', '214782004', '214783009', '214784003', '214788000', '214790004', '214791000', '214792007', '214793002', '214794008', '214795009', '214796005', '214834003', '214835002', '214836001', '214837005', '214838000', '214839008', '214840005', '214841009', '214842002', '214845000', '214846004', '214847008', '214848003', '214849006', '214850006', '214851005', '214852003', '214853008', '214867004', '214868009', '214869001', '214870000', '214871001', '214872008', '214873003', '214874009', '214875005', '214878007', '214879004', '214880001', '214881002', '214882009', '214883004', '214884005', '214885006', '214886007', '214914000', '214915004', '214916003', '214917007', '214918002', '214919005', '214921000', '214922007', '214925009', '214926005', '214927001', '214928006', '214929003', '214930008', '214931007', '214933005', '214936002', '214937006', '214938001', '214939009', '214940006', '214941005', '214942003', '214943008', '214944002', '214970001', '214971002', '214972009', '214974005', '214975006', '214977003', '214978008', '214981003', '214982005', '214983000', '214984006', '214985007', '214987004', '214989001', '214992002', '214994001', '214995000', '214996004', '214997008', '215000006', '215003008', '215004002', '215005001', '215006000', '215007009', '215008004', '215009007', '215010002', '215011003', '215015007', '215016008', '215017004', '215018009', '215019001', '215020007', '215021006', '215022004', '215023009', '215026001', '215027005', '215028000', '215029008', '215030003', '215031004', '215032006', '215033001', '215034007', '215037000', '215038005', '215039002', '215040000', '215041001', '215042008', '215043003', '215044009', '215045005', '215048007', '215049004', '215050004', '215051000', '215053002', '215054008', '215055009', '215056005', '215059003', '215060008', '215061007', '215062000', '215063005', '215064004', '215066002', '215067006', '215068001', '215071009', '215072002', '215073007', '215074001', '215075000', '215076004', '215077008', '215078003', '215079006']}, 'type'=>'CodeableConcept', 'path'=>'Encounter.reasonCode', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'preferred', 'uri'=>'http://hl7.org/fhir/ValueSet/encounter-reason'}},
      'reasonReference' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Condition', 'http://hl7.org/fhir/StructureDefinition/Procedure', 'http://hl7.org/fhir/StructureDefinition/Observation', 'http://hl7.org/fhir/StructureDefinition/ImmunizationRecommendation'], 'type'=>'Reference', 'path'=>'Encounter.reasonReference', 'min'=>0, 'max'=>Float::INFINITY},
      'diagnosis' => {'type'=>'Encounter::Diagnosis', 'path'=>'Encounter.diagnosis', 'min'=>0, 'max'=>Float::INFINITY},
      'account' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Account'], 'type'=>'Reference', 'path'=>'Encounter.account', 'min'=>0, 'max'=>Float::INFINITY},
      'hospitalization' => {'type'=>'Encounter::Hospitalization', 'path'=>'Encounter.hospitalization', 'min'=>0, 'max'=>1},
      'location' => {'type'=>'Encounter::Location', 'path'=>'Encounter.location', 'min'=>0, 'max'=>Float::INFINITY},
      'serviceProvider' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Organization'], 'type'=>'Reference', 'path'=>'Encounter.serviceProvider', 'min'=>0, 'max'=>1},
      'partOf' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Encounter'], 'type'=>'Reference', 'path'=>'Encounter.partOf', 'min'=>0, 'max'=>1}
    }

    class StatusHistory < FHIR::Model
      include FHIR::Hashable
      include FHIR::Json
      include FHIR::Xml

      METADATA = {
        'id' => {'type'=>'string', 'path'=>'StatusHistory.id', 'min'=>0, 'max'=>1},
        'extension' => {'type'=>'Extension', 'path'=>'StatusHistory.extension', 'min'=>0, 'max'=>Float::INFINITY},
        'modifierExtension' => {'type'=>'Extension', 'path'=>'StatusHistory.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
        'status' => {'valid_codes'=>{'http://hl7.org/fhir/encounter-status'=>['planned', 'arrived', 'triaged', 'in-progress', 'onleave', 'finished', 'cancelled', 'entered-in-error', 'unknown']}, 'type'=>'code', 'path'=>'StatusHistory.status', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/encounter-status'}},
        'period' => {'type'=>'Period', 'path'=>'StatusHistory.period', 'min'=>1, 'max'=>1}
      }

      attr_accessor :id                # 0-1 string
      attr_accessor :extension         # 0-* [ Extension ]
      attr_accessor :modifierExtension # 0-* [ Extension ]
      attr_accessor :status            # 1-1 code
      attr_accessor :period            # 1-1 Period
    end

    class ClassHistory < FHIR::Model
      include FHIR::Hashable
      include FHIR::Json
      include FHIR::Xml

      METADATA = {
        'id' => {'type'=>'string', 'path'=>'ClassHistory.id', 'min'=>0, 'max'=>1},
        'extension' => {'type'=>'Extension', 'path'=>'ClassHistory.extension', 'min'=>0, 'max'=>Float::INFINITY},
        'modifierExtension' => {'type'=>'Extension', 'path'=>'ClassHistory.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
        'class' => {'local_name'=>'local_class', 'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/v3-ActCode'=>['AMB', 'EMER', 'FLD', 'HH', 'IMP', 'ACUTE', 'NONAC', 'OBSENC', 'PRENC', 'SS', 'VR']}, 'type'=>'Coding', 'path'=>'ClassHistory.class', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://terminology.hl7.org/ValueSet/v3-ActEncounterCode'}},
        'period' => {'type'=>'Period', 'path'=>'ClassHistory.period', 'min'=>1, 'max'=>1}
      }

      attr_accessor :id                # 0-1 string
      attr_accessor :extension         # 0-* [ Extension ]
      attr_accessor :modifierExtension # 0-* [ Extension ]
      attr_accessor :local_class       # 1-1 Coding
      attr_accessor :period            # 1-1 Period
    end

    class Participant < FHIR::Model
      include FHIR::Hashable
      include FHIR::Json
      include FHIR::Xml

      METADATA = {
        'id' => {'type'=>'string', 'path'=>'Participant.id', 'min'=>0, 'max'=>1},
        'extension' => {'type'=>'Extension', 'path'=>'Participant.extension', 'min'=>0, 'max'=>Float::INFINITY},
        'modifierExtension' => {'type'=>'Extension', 'path'=>'Participant.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
        'type' => {'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/v3-ParticipationType'=>['ADM', 'ATND', 'CALLBCK', 'CON', 'DIS', 'ESC', 'REF', 'SPRF', 'PPRF', 'PART'], 'http://terminology.hl7.org/CodeSystem/participant-type'=>['translator', 'emergency']}, 'type'=>'CodeableConcept', 'path'=>'Participant.type', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/encounter-participant-type'}},
        'period' => {'type'=>'Period', 'path'=>'Participant.period', 'min'=>0, 'max'=>1},
        'individual' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Practitioner', 'http://hl7.org/fhir/StructureDefinition/PractitionerRole', 'http://hl7.org/fhir/StructureDefinition/RelatedPerson'], 'type'=>'Reference', 'path'=>'Participant.individual', 'min'=>0, 'max'=>1}
      }

      attr_accessor :id                # 0-1 string
      attr_accessor :extension         # 0-* [ Extension ]
      attr_accessor :modifierExtension # 0-* [ Extension ]
      attr_accessor :type              # 0-* [ CodeableConcept ]
      attr_accessor :period            # 0-1 Period
      attr_accessor :individual        # 0-1 Reference(Practitioner|PractitionerRole|RelatedPerson)
    end

    class Diagnosis < FHIR::Model
      include FHIR::Hashable
      include FHIR::Json
      include FHIR::Xml

      METADATA = {
        'id' => {'type'=>'string', 'path'=>'Diagnosis.id', 'min'=>0, 'max'=>1},
        'extension' => {'type'=>'Extension', 'path'=>'Diagnosis.extension', 'min'=>0, 'max'=>Float::INFINITY},
        'modifierExtension' => {'type'=>'Extension', 'path'=>'Diagnosis.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
        'condition' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Condition', 'http://hl7.org/fhir/StructureDefinition/Procedure'], 'type'=>'Reference', 'path'=>'Diagnosis.condition', 'min'=>1, 'max'=>1},
        'use' => {'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/diagnosis-role'=>['AD', 'DD', 'CC', 'CM', 'pre-op', 'post-op', 'billing']}, 'type'=>'CodeableConcept', 'path'=>'Diagnosis.use', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'preferred', 'uri'=>'http://hl7.org/fhir/ValueSet/diagnosis-role'}},
        'rank' => {'type'=>'positiveInt', 'path'=>'Diagnosis.rank', 'min'=>0, 'max'=>1}
      }

      attr_accessor :id                # 0-1 string
      attr_accessor :extension         # 0-* [ Extension ]
      attr_accessor :modifierExtension # 0-* [ Extension ]
      attr_accessor :condition         # 1-1 Reference(Condition|Procedure)
      attr_accessor :use               # 0-1 CodeableConcept
      attr_accessor :rank              # 0-1 positiveInt
    end

    class Hospitalization < FHIR::Model
      include FHIR::Hashable
      include FHIR::Json
      include FHIR::Xml

      METADATA = {
        'id' => {'type'=>'string', 'path'=>'Hospitalization.id', 'min'=>0, 'max'=>1},
        'extension' => {'type'=>'Extension', 'path'=>'Hospitalization.extension', 'min'=>0, 'max'=>Float::INFINITY},
        'modifierExtension' => {'type'=>'Extension', 'path'=>'Hospitalization.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
        'preAdmissionIdentifier' => {'type'=>'Identifier', 'path'=>'Hospitalization.preAdmissionIdentifier', 'min'=>0, 'max'=>1},
        'origin' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Location', 'http://hl7.org/fhir/StructureDefinition/Organization'], 'type'=>'Reference', 'path'=>'Hospitalization.origin', 'min'=>0, 'max'=>1},
        'admitSource' => {'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/admit-source'=>['hosp-trans', 'emd', 'outp', 'born', 'gp', 'mp', 'nursing', 'psych', 'rehab', 'other']}, 'type'=>'CodeableConcept', 'path'=>'Hospitalization.admitSource', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'preferred', 'uri'=>'http://hl7.org/fhir/ValueSet/encounter-admit-source'}},
        'reAdmission' => {'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/v2-0092'=>['R']}, 'type'=>'CodeableConcept', 'path'=>'Hospitalization.reAdmission', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://terminology.hl7.org/ValueSet/v2-0092'}},
        'dietPreference' => {'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/diet'=>['vegetarian', 'dairy-free', 'nut-free', 'gluten-free', 'vegan', 'halal', 'kosher']}, 'type'=>'CodeableConcept', 'path'=>'Hospitalization.dietPreference', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/encounter-diet'}},
        'specialCourtesy' => {'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/v3-EncounterSpecialCourtesy'=>['EXT', 'NRM', 'PRF', 'STF', 'VIP'], 'http://terminology.hl7.org/CodeSystem/v3-NullFlavor'=>['UNK']}, 'type'=>'CodeableConcept', 'path'=>'Hospitalization.specialCourtesy', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'preferred', 'uri'=>'http://hl7.org/fhir/ValueSet/encounter-special-courtesy'}},
        'specialArrangement' => {'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/encounter-special-arrangements'=>['wheel', 'add-bed', 'int', 'att', 'dog']}, 'type'=>'CodeableConcept', 'path'=>'Hospitalization.specialArrangement', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'preferred', 'uri'=>'http://hl7.org/fhir/ValueSet/encounter-special-arrangements'}},
        'destination' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Location', 'http://hl7.org/fhir/StructureDefinition/Organization'], 'type'=>'Reference', 'path'=>'Hospitalization.destination', 'min'=>0, 'max'=>1},
        'dischargeDisposition' => {'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/discharge-disposition'=>['home', 'alt-home', 'other-hcf', 'hosp', 'long', 'aadvice', 'exp', 'psy', 'rehab', 'snf', 'oth']}, 'type'=>'CodeableConcept', 'path'=>'Hospitalization.dischargeDisposition', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/encounter-discharge-disposition'}}
      }

      attr_accessor :id                     # 0-1 string
      attr_accessor :extension              # 0-* [ Extension ]
      attr_accessor :modifierExtension      # 0-* [ Extension ]
      attr_accessor :preAdmissionIdentifier # 0-1 Identifier
      attr_accessor :origin                 # 0-1 Reference(Location|Organization)
      attr_accessor :admitSource            # 0-1 CodeableConcept
      attr_accessor :reAdmission            # 0-1 CodeableConcept
      attr_accessor :dietPreference         # 0-* [ CodeableConcept ]
      attr_accessor :specialCourtesy        # 0-* [ CodeableConcept ]
      attr_accessor :specialArrangement     # 0-* [ CodeableConcept ]
      attr_accessor :destination            # 0-1 Reference(Location|Organization)
      attr_accessor :dischargeDisposition   # 0-1 CodeableConcept
    end

    class Location < FHIR::Model
      include FHIR::Hashable
      include FHIR::Json
      include FHIR::Xml

      METADATA = {
        'id' => {'type'=>'string', 'path'=>'Location.id', 'min'=>0, 'max'=>1},
        'extension' => {'type'=>'Extension', 'path'=>'Location.extension', 'min'=>0, 'max'=>Float::INFINITY},
        'modifierExtension' => {'type'=>'Extension', 'path'=>'Location.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
        'location' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Location'], 'type'=>'Reference', 'path'=>'Location.location', 'min'=>1, 'max'=>1},
        'status' => {'valid_codes'=>{'http://hl7.org/fhir/encounter-location-status'=>['planned', 'active', 'reserved', 'completed']}, 'type'=>'code', 'path'=>'Location.status', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/encounter-location-status'}},
        'physicalType' => {'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/location-physical-type'=>['si', 'bu', 'wi', 'wa', 'lvl', 'co', 'ro', 'bd', 've', 'ho', 'ca', 'rd', 'area', 'jdn']}, 'type'=>'CodeableConcept', 'path'=>'Location.physicalType', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/location-physical-type'}},
        'period' => {'type'=>'Period', 'path'=>'Location.period', 'min'=>0, 'max'=>1}
      }

      attr_accessor :id                # 0-1 string
      attr_accessor :extension         # 0-* [ Extension ]
      attr_accessor :modifierExtension # 0-* [ Extension ]
      attr_accessor :location          # 1-1 Reference(Location)
      attr_accessor :status            # 0-1 code
      attr_accessor :physicalType      # 0-1 CodeableConcept
      attr_accessor :period            # 0-1 Period
    end

    attr_accessor :id                # 0-1 id
    attr_accessor :meta              # 0-1 Meta
    attr_accessor :implicitRules     # 0-1 uri
    attr_accessor :language          # 0-1 code
    attr_accessor :text              # 0-1 Narrative
    attr_accessor :contained         # 0-* [ Resource ]
    attr_accessor :extension         # 0-* [ Extension ]
    attr_accessor :modifierExtension # 0-* [ Extension ]
    attr_accessor :identifier        # 0-* [ Identifier ]
    attr_accessor :status            # 1-1 code
    attr_accessor :statusHistory     # 0-* [ Encounter::StatusHistory ]
    attr_accessor :local_class       # 1-1 Coding
    attr_accessor :classHistory      # 0-* [ Encounter::ClassHistory ]
    attr_accessor :type              # 0-* [ CodeableConcept ]
    attr_accessor :serviceType       # 0-1 CodeableConcept
    attr_accessor :priority          # 0-1 CodeableConcept
    attr_accessor :subject           # 0-1 Reference(Patient|Group)
    attr_accessor :episodeOfCare     # 0-* [ Reference(EpisodeOfCare) ]
    attr_accessor :basedOn           # 0-* [ Reference(ServiceRequest) ]
    attr_accessor :participant       # 0-* [ Encounter::Participant ]
    attr_accessor :appointment       # 0-* [ Reference(Appointment) ]
    attr_accessor :period            # 0-1 Period
    attr_accessor :length            # 0-1 Duration
    attr_accessor :reasonCode        # 0-* [ CodeableConcept ]
    attr_accessor :reasonReference   # 0-* [ Reference(Condition|Procedure|Observation|ImmunizationRecommendation) ]
    attr_accessor :diagnosis         # 0-* [ Encounter::Diagnosis ]
    attr_accessor :account           # 0-* [ Reference(Account) ]
    attr_accessor :hospitalization   # 0-1 Encounter::Hospitalization
    attr_accessor :location          # 0-* [ Encounter::Location ]
    attr_accessor :serviceProvider   # 0-1 Reference(Organization)
    attr_accessor :partOf            # 0-1 Reference(Encounter)

    def resourceType
      'Encounter'
    end
  end
end