module FHIR
  class MedicationAdministration < FHIR::Model
    include FHIR::Hashable
    include FHIR::Json
    include FHIR::Xml

    MULTIPLE_TYPES = {
      'medication' => ['CodeableConcept', 'Reference'],
      'effective' => ['dateTime', 'Period']
    }
    SEARCH_PARAMS = ['code', 'identifier', 'patient', 'context', 'device', 'effective-time', 'medication', 'performer', 'reason-given', 'reason-not-given', 'request', 'status', 'subject']
    METADATA = {
      'id' => {'type'=>'id', 'path'=>'MedicationAdministration.id', 'min'=>0, 'max'=>1},
      'meta' => {'type'=>'Meta', 'path'=>'MedicationAdministration.meta', 'min'=>0, 'max'=>1},
      'implicitRules' => {'type'=>'uri', 'path'=>'MedicationAdministration.implicitRules', 'min'=>0, 'max'=>1},
      'language' => {'valid_codes'=>{'urn:ietf:bcp:47'=>['ar', 'bn', 'cs', 'da', 'de', 'de-AT', 'de-CH', 'de-DE', 'el', 'en', 'en-AU', 'en-CA', 'en-GB', 'en-IN', 'en-NZ', 'en-SG', 'en-US', 'es', 'es-AR', 'es-ES', 'es-UY', 'fi', 'fr', 'fr-BE', 'fr-CH', 'fr-FR', 'fy', 'fy-NL', 'hi', 'hr', 'it', 'it-CH', 'it-IT', 'ja', 'ko', 'nl', 'nl-BE', 'nl-NL', 'no', 'no-NO', 'pa', 'pl', 'pt', 'pt-BR', 'ru', 'ru-RU', 'sr', 'sr-RS', 'sv', 'sv-SE', 'te', 'zh', 'zh-CN', 'zh-HK', 'zh-SG', 'zh-TW']}, 'type'=>'code', 'path'=>'MedicationAdministration.language', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'preferred', 'uri'=>'http://hl7.org/fhir/ValueSet/languages'}},
      'text' => {'type'=>'Narrative', 'path'=>'MedicationAdministration.text', 'min'=>0, 'max'=>1},
      'contained' => {'type'=>'Resource', 'path'=>'MedicationAdministration.contained', 'min'=>0, 'max'=>Float::INFINITY},
      'extension' => {'type'=>'Extension', 'path'=>'MedicationAdministration.extension', 'min'=>0, 'max'=>Float::INFINITY},
      'modifierExtension' => {'type'=>'Extension', 'path'=>'MedicationAdministration.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
      'identifier' => {'type'=>'Identifier', 'path'=>'MedicationAdministration.identifier', 'min'=>0, 'max'=>Float::INFINITY},
      'instantiates' => {'type'=>'uri', 'path'=>'MedicationAdministration.instantiates', 'min'=>0, 'max'=>Float::INFINITY},
      'partOf' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/MedicationAdministration', 'http://hl7.org/fhir/StructureDefinition/Procedure'], 'type'=>'Reference', 'path'=>'MedicationAdministration.partOf', 'min'=>0, 'max'=>Float::INFINITY},
      'status' => {'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/medication-admin-status'=>['in-progress', 'not-done', 'on-hold', 'completed', 'entered-in-error', 'stopped', 'unknown']}, 'type'=>'code', 'path'=>'MedicationAdministration.status', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/medication-admin-status'}},
      'statusReason' => {'valid_codes'=>{'http://snomed.info/sct'=>['182896008', '182897004', '182898009', '182899001', '182900006', '182901005', '182902003', '182903008']}, 'type'=>'CodeableConcept', 'path'=>'MedicationAdministration.statusReason', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/reason-medication-not-given-codes'}},
      'category' => {'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/medication-admin-category'=>['inpatient', 'outpatient', 'community']}, 'type'=>'CodeableConcept', 'path'=>'MedicationAdministration.category', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'preferred', 'uri'=>'http://hl7.org/fhir/ValueSet/medication-admin-category'}},
      'medicationCodeableConcept' => {'valid_codes'=>{'http://snomed.info/sct'=>['261000', '336001', '363000', '519005', '585007', '693002', '698006', '699003', '747006', '873008', '925002', '1018001', '1025008', '1057009', '1091008', '1171004', '1190007', '1244009', '1269009', '1325004', '1336006', '1355006', '1368003', '1381005', '1450002', '1476002', '1536005', '1575001', '1603001', '1668008', '1914001', '1944003', '1956002', '1971003', '2029004', '2125008', '2195004', '2197007', '2201007', '2212007', '2215009', '2249001', '2264001', '2346005', '2537003', '2660003', '2680002', '2796008', '2799001', '2869004', '2878005', '2927004', '2958003', '2964005', '2991007', '2995003', '3031003', '3066001', '3087006', '3136005', '3142009', '3145006', '3209002', '3212004', '3225007', '3342004', '3378009', '3379001', '3501003', '3592004', '3597005', '3617004', '3672002', '3693004', '3793006', '3823007', '3829006', '3874004', '3906002', '3932008', '3941003', '3945007', '3983008', '4014000', '4025009', '4043008', '4076007', '4188007', '4203009', '4334005', '4353000', '4355007', '4413004', '4423008', '4480008', '4518006', '4616002', '4681002', '4700006', '4780009', '4814001', '4844003', '5007006', '5142007', '5167005', '5172001', '5220000', '5312000', '5405008', '5477001', '5641004', '5647000', '5657004', '5681006', '5691000', '5699003', '5739006', '5767002', '5774007', '5907009', '5955009', '6054001', '6088007', '6162007', '6237004', '6260007', '6333002', '6394006', '6495008', '6513000', '6524003', '6602005', '6612003', '6710000', '6717002', '6790004', '6809003', '6826009', '6837005', '6865007', '6873003', '6881002', '6910009', '6927001', '6952004', '6992002', '7034005', '7084003', '7156005', '7179006', '7302008', '7318002', '7328006', '7348004', '7451005', '7509000', '7515000', '7549008', '7608003', '7737009', '7770004', '7774008', '7816005', '7834009', '7904003', '7975001', '8030004', '8143001', '8202008', '8203003', '8222007', '8252004', '8397006', '8450009', '8534003', '8631001', '8689007', '8701002', '8767001', '8886003', '8919000', '8987006', '9174005', '9234005', '9271007', '9396007', '9457002', '9471005', '9530002', '9532005', '9539001', '9643009', '9663002', '9676008', '9680003', '9721008', '9765000', '9797000', '9817005', '9910008', '9974009', '9992001', '10016008', '10020007', '10109009', '10133003', '10174003', '10192006', '10202007', '10240005', '10270000', '10282009', '10324005', '10329000', '10333007', '10342000', '10354000', '10377000', '10424009', '10466005', '10471003', '10500003', '10534002', '10595003', '10644005', '10660009', '10682002', '10730008', '10750007', '10751006', '10767000', '10782005', '10790005', '10843002', '10955007', '11036001', '11038000', '11115001', '11121002', '11137008', '11170003', '11202003', '11331001', '11345007', '11420005', '11473005', '11496005', '11504003', '11633008', '11644000', '11652002', '11714005', '11943009', '11984007', '11986009', '12009000', '12034000', '12177002', '12208001', '12218006', '12290003', '12315006', '12391001', '12525000', '12568004', '12578001', '12597001', '12689001', '12716009', '12801003', '12821002', '12870003', '12930006', '12970004', '13030002', '13150000', '13188003', '13235001', '13342004', '13502005', '13585009', '13668001', '13708006', '13787003', '13789000', '14013006', '14071002', '14146003', '14172007', '14193005', '14285000', '14312008', '14321009', '14340003', '14349002', '14399003', '14409006', '14438009', '14443002', '14461006', '14507006', '14638000', '14645000', '14715007', '14743003', '14767006', '14796007', '14819006', '14903000', '14905007', '15009009', '15017001', '15098005', '15129007', '15322006', '15331006', '15352003', '15505005', '15571002', '15660006', '15698006', '15730005', '15785009', '15810003', '15895007', '15901005', '16106007', '16125005', '16130009', '16214005', '16257000', '16276003', '16318005', '16355005', '16359004', '16392005', '16395007', '16462002', '16477005', '16492006', '16613008', '16624005', '16628008', '16670003', '16683002', '16717002', '16744007', '16745008', '16748005', '16808006', '16826009', '16915004', '16923002', '16946000', '17008002', '17062003', '17072000', '17117004', '17147002', '17212003', '17240008', '17243005', '17244004', '17356001', '17614005', '17731005', '17777001', '17798001', '17836006', '17916009', '17932007', '17942009', '17990002', '17991003', '18017000', '18039003', '18143001', '18220004', '18288009', '18321003', '18394004', '18414002', '18449009', '18462008', '18535002', '18550006', '18600008', '18616005', '18712002', '18815007', '18832006', '18852007', '18959002', '18970009', '19012003', '19041007', '19046002', '19114000', '19126005', '19163001', '19205004', '19421007', '19427006', '19462001', '19499001', '19510001', '19524002', '19595005', '19622008', '19839007', '19893005', '19918001', '19967004', '19978007', '20056006', '20170008', '20217007', '20229003', '20231007', '20238001', '20327004', '20340009', '20368008', '20378006', '20379003', '20413008', '20450009', '20468007', '20495002', '20686000', '20752000', '20771003', '20844009', '20847002', '20887007', '21028006', '21066009', '21075006', '21094001', '21168008', '21175009', '21235009', '21246007', '21289006', '21303006', '21373005', '21394008', '21518006', '21556007', '21559000', '21566004', '21568003', '21572004', '21611007', '21614004', '21706000', '21891005', '21903000', '21919007', '22038003', '22086005', '22165008', '22236007', '22242006', '22250002', '22362000', '22424004', '22453003', '22496008', '22606007', '22635004', '22654004', '22769006', '22779008', '22790003', '22792006', '22827004', '22840009', '22882008', '22941009', '22976006', '23053002', '23068001', '23077008', '23176001', '23295004', '23375008', '23433006', '23459009', '23564005', '23692005', '23701001', '23814005', '23816007', '23861006', '23862004', '23866001', '23883005', '23959001', '23969007', '24022008', '24202000', '24237002', '24261009', '24336008', '24357000', '24434007', '24435008', '24556008', '24570008', '24583009', '24650007', '24686008', '24721007', '24751001', '24809001', '24823004', '24838003', '24869004', '25002001', '25013003', '25027008', '25128000', '25141001', '25183006', '25204006', '25205007', '25213008', '25217009', '25254000', '25305005', '25307002', '25401000', '25500001', '25525005', '25538002', '25571003', '25607008', '25620006', '25710007', '25747007', '25796002', '25886000', '25911004', '26120001', '26191006', '26277008', '26288002', '26327007', '26346008', '26351002', '26371006', '26379008', '26437003', '26469007', '26518005', '26656004', '26817007', '26945002', '26992003', '27054007', '27079005', '27081007', '27082000', '27122000', '27184001', '27192005', '27244000', '27248002', '27345002', '27361000', '27499006', '27586005', '27594003', '27656005', '27730007', '27736001', '27766008', '27822002', '27928002', '27931001', '27989007', '28021008', '28029005', '28069006', '28121005', '28223003', '28268006', '28344001', '28421003', '28464005', '28521000', '28580002', '28588009', '28662003', '28702005', '28825003', '28829009', '28927005', '28942008', '28983006', '28999000', '29011006', '29184007', '29190006', '29301006', '29327006', '29406002', '29522004', '29527005', '29531004', '29584000', '29588002', '29666006', '29671004', '29725000', '29765001', '29783009', '29876006', '30034004', '30053009', '30094001', '30145004', '30178006', '30179003', '30203009', '30205002', '30236005', '30324001', '30325000', '30326004', '30329006', '30333004', '30424002', '30589007', '30658004', '30676006', '30745005', '30804005', '30820000', '30827002', '30848000', '30863002', '30990007', '31011004', '31055005', '31147000', '31178001', '31422009', '31522006', '31617001', '31622001', '31662002', '31706007', '31707003', '31731008', '31780003', '31787000', '31799007', '31801005', '31815007', '31818009', '31827005', '31895006', '31936008', '31990000', '32050003', '32083005', '32120008', '32133002', '32154009', '32157002', '32281001', '32370002', '32436002', '32437006', '32498003', '32505007', '32519007', '32707001', '32714004', '32757009', '32789000', '32800009', '32824001', '32836007', '32852005', '32898006', '32901007', '33280006', '33307008', '33396006', '33435008', '33440000', '33447002', '33535006', '33619005', '33635003', '33642003', '33667000', '33752008', '33837008', '33922005', '33963004', '34007009', '34070005', '34074001', '34086003', '34113002', '34120009', '34198005', '34211007', '34239008', '34274009', '34332002', '34425005', '34471003', '34654009', '34657002', '34658007', '34737006', '34915005', '34919004', '34953000', '34983009', '35060001', '35135004', '35150008', '35236008', '35257000', '35281007', '35318005', '35321007', '35343004', '35431001', '35466004', '35473009', '35605007', '35733004', '35748005', '35765001', '35864006', '35883004', '35903003', '35946000', '35954003', '35966009', '35976007', '36020009', '36021008', '36022001', '36136008', '36167005', '36173006', '36176003', '36235004', '36378007', '36380001', '36516003', '36541005', '36651003', '36661005', '36712003', '36872003', '36887008', '36953002', '37006008', '37013008', '37077000', '37078005', '37123002', '37225000', '37237003', '37262003', '37276002', '37352007', '37365003', '37411004', '37433002', '37451001', '37527009', '37648000', '37656002', '37691005', '37716005', '37751002', '37756007', '37758008', '37765000', '37951005', '37957009', '37978007', '37986007', '37994000', '38044001', '38122009', '38218009', '38245005', '38344006', '38399002', '38408002', '38543004', '38595007', '38622005', '38623000', '38648002', '38686006', '38714005', '38794009', '38909000', '38914001', '38937007', '39012008', '39044007', '39123009', '39152007', '39263003', '39292004', '39294003', '39428005', '39514001', '39546001', '39552000', '39808001', '39815009', '39933002', '39962001', '39972003', '39973008', '39979007', '40036000', '40115000', '40342009', '40404004', '40438007', '40534007', '40545005', '40601003', '40699008', '40710000', '40789008', '40924008', '40937006', '40940006', '41062004', '41067005', '41091001', '41143004', '41153003', '41199001', '41261002', '41332001', '41395001', '41410009', '41433005', '41464007', '41485007', '41492002', '41503000', '41509001', '41573001', '41592004', '41598000', '41722006', '41793006', '41834005', '41903005', '41945007', '41989007', '42033003', '42056007', '42145009', '42146005', '42159002', '42163009', '42180008', '42193003', '42212002', '42230009', '42319009', '42382009', '42464005', '42520004', '42549007', '42605004', '42671007', '42692007', '42710006', '42730005', '42761001', '42841002', '42877009', '43004008', '43032004', '43048003', '43136004', '43171004', '43239002', '43289005', '43332008', '43356007', '43440003', '43462003', '43538006', '43541002', '43585000', '43592005', '43597004', '43613009', '43621003', '43688007', '43698001', '43706004', '43784004', '43835003', '43848004', '43880002', '43897008', '43909000', '43989002', '44044007', '44068004', '44159003', '44234001', '44262008', '44293009', '44330008', '44347009', '44469001', '44508008', '44520000', '44555003', '44588005', '44603007', '44609006', '44624002', '44644008', '44681007', '44711006', '44776005', '44908000', '45084007', '45119009', '45158004', '45159007', '45207006', '45266004', '45483006', '45524001', '45555007', '45604009', '45754009', '45807004', '45940009', '45946003', '45960001', '46015007', '46021006', '46058006', '46097003', '46122001', '46134009', '46146008', '46191004', '46201000', '46225008', '46250006', '46257009', '46293006', '46492003', '46514003', '46558003', '46572007', '46654009', '46668002', '46711008', '46749007', '46861006', '46887006', '46921009', '46943001', '46950002', '47026005', '47176005', '47180000', '47192000', '47218005', '47247003', '47280005', '47336007', '47349002', '47350002', '47355007', '47383009', '47389008', '47408003', '47413004', '47414005', '47500008', '47663000', '169008', '211009', '302007', '439007', '449005', '544002', '669007', '716000', '796001', '847003', '902003', '922004', '1039008', '1148001', '1182007', '1206000', '1222004', '1389007', '1434005', '1528001', '1552008', '1594006', '1613009', '1756009', '1758005', '1842003', '1878008', '1887004', '1982006', '2016004', '2037007', '2183004', '2190009', '2497003', '2571007', '2596005', '2679000', '2944000', '2949005', '3037004', '3046005', '3127006', '3221003', '3334000', '3361000', '3526007', '3593009', '3814009', '3822002', '4126008', '4194004', '4219002', '4220008', '4382004', '4704002', '4741001', '4753002', '4865009', '4937008', '5067008', '5465006', '5478006', '5487002', '5606003', '5720001', '5737008', '5776009', '5786005', '5797005', '5924003', '5975000', '6028009', '6067003', '6071000', '6102009', '6116004', '6122008', '6232005', '6247001', '6259002', '6369005', '6425004', '6517004', '6526001', '6625006', '6652001', '6716006', '6960003', '6985007', '7092007', '7140000', '7168001', '7230005', '7235000', '7292004', '7336002', '7561000', '7577004', '7624002', '7836006', '7947003', '7959004', '7982002', '8028001', '8109005', '8163008', '8348002', '8372007', '8416000', '8571001', '8658008', '8661009', '8692006', '8696009', '9190005', '9268004', '9307009', '9500005', '9542007', '9690006', '9745007', '9778000', '9944001', '10099000', '10135005', '10243007', '10312003', '10332002', '10355004', '10356003', '10368007', '10422008', '10504007', '10515002', '10555000', '10632007', '10668002', '10712001', '10756001', '10784006', '11185009', '11260008', '11402001', '11430001', '11563006', '11719000', '11777007', '11783005', '11796006', '11841005', '11847009', '11866009', '11959009', '12096000', '12236006', '12289007', '12335007', '12369008', '12425002', '12436009', '12495006', '12512008', '12559001', '12657005', '12839006', '12968008', '13132007', '13154009', '13178004', '13252002', '13414000', '13432000', '13512003', '13525006', '13565005', '13592004', '13664004', '13790009', '13800009', '13813003', '13929005', '13936006', '13965000', '14054003', '14103001', '14170004', '14542005', '14601000', '14706000', '14728000', '14745005', '14814001', '14816004', '15117003', '15222008', '15375005', '15383004', '15389000', '15432003', '15772006', '15857002', '16031005', '16037009', '16047007', '16131008', '16403005', '16602005', '16787005', '16791000', '16832004', '16858004', '16867004', '16970001', '16977003', '17016006', '17055007', '17308007', '17386008', '17502009', '17554004', '17558001', '17600005', '17805003', '17859000', '17893001', '18002004', '18125000', '18335001', '18340009', '18381001', '18511007', '18548003', '18679008', '18811003', '18914005', '18952006', '19194001', '19225000', '19232009', '19261005', '19315007', '19403009', '19405002', '19581007', '19583005', '19630009', '19768003', '19841008', '20091003', '20201001', '20237006', '20249007', '20303001', '20320002', '20577002', '20865003', '20969008', '21069002', '21159006', '21451004', '21691008', '21701005', '21767006', '21788002', '21986005', '22091006', '22168005', '22198003', '22274004', '22474002', '22587006', '22657006', '22672005', '22696000', '22801004', '22826008', '22969001', '23079006', '23222006', '23343005', '23532003', '23822003', '23827009', '23838009', '23888001', '24036003', '24450004', '24504000', '24866006', '24891006', '25014009', '25057004', '25076002', '25085002', '25142008', '25246002', '25398003', '25419009', '25465007', '25673006', '25716001', '25849001', '25860005', '25912006', '25995007', '26122009', '26124005', '26244009', '26303005', '26370007', '26456008', '26458009', '26462003', '26503009', '26523005', '26548008', '26574002', '26580005', '26736008', '26800000', '26842003', '27035007', '27085003', '27196008', '27242001', '27479000', '27518004', '27548001', '27566006', '27638005', '27658006', '27707001', '27754002', '27867009', '28028002', '28149003', '28235004', '28240007', '28410007', '28415002', '28426008', '28506006', '28748001', '28841002', '28906000', '29051009', '29058003', '29089004', '29121001', '29129004', '29156002', '29175007', '29237004', '29439004', '29620001', '29840005', '29877002', '29883004', '29896003', '29987004', '30010009', '30125007', '30306003', '30317002', '30427009', '30466001', '30492008', '30666008', '30729008', '30761007', '30964009', '30988006', '31025003', '31087008', '31181006', '31231007', '31305008', '31306009', '31352002', '31587003', '31684002', '31690003', '31692006', '31716004', '31865003', '31872002', '31970009', '32249005', '32313007', '32460003', '32462006', '32473004', '32474005', '32583002', '32647002', '32653002', '32792001', '32823007', '32841004', '32955006', '32960005', '33124007', '33133009', '33219003', '33231001', '33234009', '33236006', '33252009', '33378002', '33484000', '33588000', '33589008', '33664007', '33675006', '33682005', '33815001', '34012005', '34217006', '34364009', '34393009', '34462007', '34598001', '34599009', '34689006', '34693000', '34696008', '34731007', '34816007', '34833000', '34929006', '35035001', '35063004', '35097006', '35282000', '35300007', '35324004', '35392005', '35476001', '35531004', '35736007', '35768004', '35792007', '35967000', '35983000', '36068003', '36113004', '36168000', '36218003', '36236003', '36391008', '36537006', '36594001', '36621009', '36642006', '36763003', '36795002', '36893000', '36909007', '36940000', '36944009', '37084008', '37146000', '37306000', '37400007', '37628007', '37643009', '37773009', '37803001', '38076006', '38131009', '38166006', '38181000', '38231004', '38268001', '38314008', '38413003', '38578004', '38828006', '38900001', '39064002', '39124003', '39128000', '39142008', '39252001', '39359008', '39432004', '39487003', '39516004', '39598004', '39608003', '39707000', '39741008', '39860005', '39939003', '40162007', '40232005', '40339003', '40429005', '40430000', '40556005', '40562000', '40589005', '40606008', '40648001', '40652001', '40820003', '40877002', '40901001', '40905005', '40974005', '40999006', '41001009', '41015006', '41147003', '41193000', '41324009', '41365009', '41367001', '41399007', '41470001', '41493007', '41549009', '41985001', '42082003', '42098005', '42271003', '42348003', '42374009', '42444000', '42514000', '42638008', '42714002', '42720001', '42863006', '43343000', '43499003', '43533002', '43594006', '43684009', '43747001', '43753001', '43879000', '43927002', '44175000', '44418001', '44658005', '44731005', '44790008', '44798001', '44938006', '44990002', '45218006', '45311002', '45313004', '45355008', '45518007', '45680002', '45844004', '45888006', '45923000', '46009007', '46063005', '46123006', '46233009', '46436003', '46479001', '46532003', '46547007', '46576005', '46709004', '46741005', '46913003', '47065008', '47120002', '47124006', '47140009', '47331002', '47527007', '47602007', '47755009', '47772002', '47898004', '48028008', '48174005', '48256008', '48279009', '48351000', '48546005', '48603004', '48614001', '48647005', '48698004', '48836000', '48875009', '48899009', '49019002', '49157004', '49192007', '49267000', '49299006', '49485009', '49577002', '49590009', '49600008', '49617001', '49663007', '49669006', '49688004', '49694007', '49705006', '49802003', '49860008', '49953001', '49992008', '50094009', '50137001', '50182002', '50244000', '50256004', '50318003', '50335004', '50520001', '50841004', '50868004', '51013009', '51073002', '51103004', '51126006', '51132001', '51326002', '51334008', '51361008', '51425004', '51555009', '51752005', '51758009', '51779009', '51908007', '51992002', '52017007', '52108005', '52215008', '52388000', '52412009', '52423008', '52451004', '52489009', '52628005', '52761007', '52883001', '52896000', '53009005', '53480001', '53584007', '53640004', '53641000', '53691001', '53793005', '53800008', '53848009', '53855006', '54142000', '54344006', '54391004', '54406003', '54541002', '54544005', '54577009', '54659006', '54705000', '54765002', '54824008', '54882005', '54887004', '54972005', '54982006', '55015008', '55217007', '55432002', '55556000', '55673009', '55745002', '55782006', '55784007', '55830003', '55867006', '55889005', '56011005', '56014002', '56032002', '56059005', '56123002', '56230001', '56234005', '56240003', '56281006', '56480005', '56549003', '56602009', '56615000', '56656002', '56844000', '56928005', '56934003', '57002000', '57066004', '57123008', '57191001', '57263002', '57376006', '57538001', '57616006', '57670008', '57752001', '57811004', '57819002', '57845006', '57853003', '57893000', '57952007', '58050004', '58098008', '58360000', '58467001', '58502006', '58760003', '58805000', '58883005', '58892008', '58905004', '58944007', '59057006', '59187003', '59240002', '59245007', '59255006', '59261009', '59270007', '59456005', '59589008', '59594008', '59751001', '59799001', '59941008', '59953007', '59999009', '60090003', '60093001', '60149003', '60169008', '60468008', '60520004', '60533005', '60541005', '60682004', '60731009', '60767002', '60881009', '60972002', '60978003', '61020000', '61093008', '61123001', '61132004', '61153008', '61181002', '61408004', '61457001', '61602008', '61621000', '61623002', '61650007', '61651006', '61862008', '61939007', '61946003', '62051009', '62063004', '62191005', '62288001', '62294009', '62353003', '62354009', '62529008', '62560008', '62782004', '63094006', '63136007', '63318000', '63338004', '63470003', '63639004', '63682003', '63758001', '63822004', '64083002', '64115004', '64127001', '64240003', '64296005', '64349004', '64462001', '64558005', '64851009', '64878006', '65020006', '65026000', '65041000', '65092008', '65265006', '65461004', '65484006', '65502005', '65505007', '65627005', '65628000', '65638005', '65695006', '65823007', '65884003', '65965000', '66065008', '66094001', '66125007', '66243004', '66261008', '66349002', '66441000', '66492008', '66493003', '66602007', '66672008', '66742008', '66854004', '66859009', '66860004', '66919007', '66971004', '67213005', '67423003', '67440007', '67477004', '67507000', '67585005', '67735003', '67891001', '67939000', '68088000', '68113000', '68206008', '68208009', '68395000', '68398003', '68402007', '68407001', '68422006', '68424007', '68444001', '68461003', '68490009', '68622003', '68702006', '68774008', '68864001', '68887009', '68892006', '69107004', '69204002', '69227005', '69236009', '69242008', '69331001', '69431002', '69509008', '69576000', '69708003', '69801001', '69879000', '69918003', '69967001', '70047000', '70216000', '70254000', '70343008', '70379000', '70447008', '70460002', '70702006', '70776005', '70841003', '70864001', '70934008', '71181003', '71289008', '71338005', '71451001', '71453003', '71455005', '71462001', '71516007', '71584004', '71634000', '71699007', '71724000', '71731001', '71759000', '71770007', '71798005', '71837009', '72312007', '72398005', '72416006', '72623000', '72824008', '72870001', '72924009', '72968006', '72996000', '73074003', '73093001', '73133000', '73170009', '73212002', '73228007', '73274006', '73277004', '73454001', '73572009', '73585007', '73627008', '73639000', '73647000', '73756003', '73763003', '73805002', '73949004', '73986003', '74022005', '74065006', '74074008', '74147005', '74213004', '74226000', '74470007', '74480006', '74575000', '74583006', '74626007', '74632002', '74674007', '74771007', '74780007', '74782004', '74798006', '74819009', '75029008', '75201000', '75203002', '75292001', '75366006', '75429004', '75501004', '75661008', '75748004', '75770001', '75927008', '75959001', '75969007', '76058001', '76155001', '76286000', '76289007', '76385003', '76390000', '76591000', '76696004', '76759004', '76962009', '77035009', '77048008', '77237006', '77331005', '77390008', '77398001', '77549006', '77657003', '77731008', '77750008', '77856005', '77885004', '77898008', '78025001', '78057000', '78174002', '78379001', '78411008', '78439009', '78449007', '78507004', '78542000', '186002', '217008', '476005', '501001', '505005', '515004', '576007', '584006', '593007', '704006', '735000', '819002', '876000', '923009', '1097007', '1160000', '1223009', '1273007', '1319003', '1371006', '1405004', '1408002', '1506001', '1517000', '1565004', '1634002', '1649005', '1676005', '1681001', '1696002', '1975007', '2038002', '2082006', '2147008', '2260005', '2329007', '2404002', '2431004', '2444009', '2500009', '2568004', '2611008', '2676007', '2706001', '2721007', '2728001', '2753003', '2765004', '2988007', '3131000', '3187008', '3555004', '3588006', '3602003', '3730007', '3807007', '3897001', '3961009', '3976001', '4115002', '4167003', '4169000', '4314009', '4393002', '4401009', '4422003', '4425001', '4555006', '4564001', '4582003', '4591004', '4761007', '4762000', '4789005', '4878009', '4933007', '5004004', '5064001', '5081005', '5094007', '5250008', '5259009', '5307001', '5340005', '5404007', '5439007', '5504009', '5533005', '5573004', '5637003', '5700002', '5757007', '5840001', '5915007', '5977008', '6056004', '6068008', '6091007', '6115000', '6135004', '6138002', '6170002', '6178009', '6197009', '6310003', '6360009', '6411000', '6422001', '6507009', '6529008', '6532006', '6592009', '6642000', '6671004', '6741004', '6755007', '6945001', '6958000', '7029006', '7120007', '7158006', '7161007', '7211005', '7337006', '7411007', '7489000', '7588005', '7616007', '7648006', '7675004', '7685003', '7738004', '7948008', '7974002', '8002004', '8025003', '8048008', '8123007', '8164002', '8268005', '8343006', '8362009', '8376005', '8452001', '8460000', '8484008', '8486005', '8491006', '8612007', '8660005', '8731008', '8740007', '8786009', '8818009', '8878003', '8908003', '8977007', '9054000', '9172009', '9253000', '9296005', '9319001', '9392009', '9398008', '9472003', '9493000', '9608008', '9672005', '9701007', '9716005', '9921004', '9930007', '9980001', '9985006', '10105003', '10158008', '10189007', '10228005', '10265007', '10393009', '10398000', '10436003', '10440007', '10473000', '10560001', '10570004', '10622000', '10889009', '10912008', '10987005', '11004008', '11022006', '11041009', '11064006', '11091008', '11123004', '11222004', '11233001', '11252007', '11267006', '11330000', '11353004', '11447000', '11474004', '11479009', '11489008', '11566003', '11594006', '11600003', '11684009', '11725001', '11744008', '11770009', '11799004', '11825009', '11863001', '11877003', '11886008', '12018003', '12103002', '12190009', '12194000', '12379005', '12498008', '12564002', '12577006', '12627001', '12642003', '12685007', '12752008', '12753003', '12899008', '12934002', '12998001', '13016007', '13083005', '13105002', '13377004', '13400000', '13435003', '13484006', '13492002', '13539006', '13571004', '13590007', '13625002', '13701000', '13717006', '13723001', '13772008', '13841004', '13872000', '14090005', '14104007', '14190008', '14226002', '14271005', '14279007', '14396005', '14444008', '14464003', '14517001', '14574003', '14604008', '14620003', '14665007', '14711003', '14726001', '14827002', '14849008', '14986005', '15011000', '15021008', '15073009', '15275007', '15286009', '15313005', '15392001', '15416001', '15469000', '15551006', '15620005', '15653000', '15683009', '15754000', '15781000', '15797005', '15798000', '15909007', '15942008', '16019008', '16025007', '16074008', '16122008', '16133006', '16138002', '16230002', '16519001', '16705004', '16734005', '16752005', '16878007', '16951006', '16996004', '17074004', '17108004', '17119001', '17152007', '17165003', '17430007', '17462005', '17595001', '17627009', '17640004', '17659002', '17701004', '17707000', '17740009', '17853004', '18030004', '18082002', '18150002', '18195009', '18359006', '18380000', '18426007', '18436004', '18468007', '18486005', '18501000', '18533009', '18611000', '18627007', '18659000', '18737007', '18761000', '18763002', '18853002', '19009001', '19011005', '19022009', '19035000', '19089003', '19136002', '19178008', '19182005', '19331004', '19395006', '19400007', '19530002', '19565002', '19677004', '19728002', '19755006', '19783008', '19830006', '19868008', '19917006', '19945000', '20009008', '20040001', '20057002', '20228006', '20304007', '20355000', '20383003', '20493009', '20576006', '20591008', '20748000', '20764008', '20777004', '20807009', '20823009', '20878003', '20898008', '20907008', '21023002', '21064007', '21102006', '21145004', '21149005', '21158003', '21166007', '21256006', '21315005', '21521008', '21642002', '21774001', '21802009', '21873000', '21876008', '21920001', '22023004', '22269007', '22290004', '22332006', '22348007', '22503007', '22568000', '22627002', '22839007', '22939008', '22971001', '23016008', '23064004', '23101007', '23103005', '23164001', '23165000', '23200004', '23240005', '23314002', '23318004', '23369004', '23380004', '23385009', '23396001', '23434000', '23603009', '23689006', '23760003', '23774005', '23775006', '23878002', '23893003', '24002009', '24008008', '24023003', '24143007', '24207006', '24248009', '24304001', '24391001', '24404002', '24479006', '24487007', '24503006', '24540003', '24574004', '24655002', '24673004', '24710003', '24821002', '24857007', '24860000', '24898000', '24926008', '24978006', '24995003', '25095009', '25176004', '25282007', '25315004', '25400004', '25426009', '25453008', '25513007', '25557006', '25717005', '25773002', '25826003', '25833003', '25867008', '25964000', '26005009', '26021004', '26066008', '26093006', '26274001', '26355006', '26441004', '26647007', '26651009', '26720006', '26740004', '26749003', '26855002', '26937007', '27024002', '27044008', '27047001', '27048006', '27076003', '27089009', '27130004', '27205008', '27273002', '27340007', '27384007', '27417007', '27425009', '27453009', '27459008', '27487004', '27489001', '27607009', '27626001', '27800009', '27862003', '27899003', '27963007', '27999002', '28145009', '28262007', '28298004', '28361003', '28408005', '28424006', '28427004', '28495003', '28564007', '28577003', '28585007', '28673005', '28679009', '28708009', '28716000', '28731009', '28779002', '28808000', '28819002', '28881009', '29244008', '29266001', '29275004', '29468003', '29502003', '29573007', '29652001', '29719004', '29735006', '29776002', '29831006', '29988009', '30030008', '30137009', '30209008', '30245006', '30357004', '30413004', '30498007', '30540002', '30594007', '30604008', '30607001', '30609003', '30621004', '30702003', '30723009', '30797003', '30954000', '30965005', '30987001', '31001006', '31008000', '31024004', '31036005', '31245001', '31317005', '31357008', '31400002', '31854008', '31897003', '31960007', '32073006', '32079005', '32089009', '32147003', '32167007', '32233008', '32235001', '32237009', '32241008', '32261002', '32277001', '32305006', '32314001', '32324009', '32329004', '32351007', '32364008', '32396000', '32403003', '32481003', '32609007', '32616008', '32699000', '32842006', '32860006', '32943000', '32974003', '32990003', '33029004', '33037007', '33053005', '33057006', '33063002', '33188008', '33210004', '33309006', '33355008', '33509005', '33550002', '33604009', '33680002', '33691009', '33825006', '33865005', '33987002', '34049004', '34161009', '34180006', '34204008', '34316000', '34355004', '34388006', '34400001', '34453005', '34465009', '34510007', '34569000', '34745001', '34750007', '34829007', '34832005', '34868000', '34900009', '34912008', '34968004', '34970008', '35012004', '35040009', '35068008', '35072007', '35092000', '35118003', '35213004', '35215006', '35310003', '35367007', '35410004', '35556005', '35614002', '35645003', '35760006', '35825008', '35841009', '35906006', '35922007', '35952004', '36005003', '36016005', '36100005', '36260004', '36396003', '36403001', '36418000', '36562006', '36613003', '36652005', '36713008', '36744004', '36757007', '36759005', '36804003', '36842009', '36853003', '36907009', '36933001', '37067002', '37100000', '37282004', '37287005', '37300006', '37583005', '37654004', '37713002', '37861002', '37902007', '37984005', '38227005', '38262000', '38269009', '38367008', '38445008', '38476002', '38499003', '38519002', '38553003', '38554009', '38558007', '38771008', '38779005', '38874005', '38908008', '39024001', '39053000', '39082004', '39118009', '39138005', '39241007', '39327001', '39337006', '39442002', '39515000', '39525005', '39650003', '39665002', '39678002', '39840002', '39988003', '39999001', '40018000', '40030006', '40044000', '40048002', '40065006', '40140007', '40154004', '40270009', '40364000', '40447004', '40456007', '40558006', '40621002', '40706003', '40856000', '40992002', '41044008', '41093003', '41096006', '41285005', '41301002', '41318003', '41403003', '41562008', '41576009', '41644009', '41667006', '41761003', '41771001', '41858009', '41886001', '41930000', '41978000', '41999002', '42038007', '42048009', '42078000', '42092006', '42107008', '42122003', '42166001', '42255003', '42333009', '42371001', '42473002', '42490008', '42664002', '42732002', '42768007', '42784008', '42799008', '42804003', '42830004', '42848008', '42888003', '42891003', '42897004', '42926001', '43042002', '43076006', '43095004', '43181000', '43241001', '43278003', '43347004', '43397000', '43417002', '43425000', '43576000', '43596008', '43632003', '43678006', '43788001', '43807002', '43827001', '43864007', '43871002', '44040003', '44045008', '44046009', '44049002', '44063008', '44093002', '44112005', '44139002', '44158006', '44212003', '44239006', '44331007', '44369002', '44439008', '44447008', '44459007', '44472008', '44675004', '44680008', '44686002', '44706009', '44719008', '44728009', '44824000', '45026006', '45044003', '45047005', '45095001', '45193006', '45246008', '45273009', '45321005', '45333000', '45388001', '45396006', '45407009', '45428000', '45441001', '45510000', '45528003', '45530001', '45601001', '45637006', '45656001', '45668005', '45672009', '45857007', '45932003', '45934002', '45969000', '45992000', '46096007', '46150001', '46158008', '46195008', '46234003', '46261003', '46331009', '46336004', '46469003', '46519008', '46539007', '46548002', '46613001', '46663006', '46730008', '46755002', '46841000', '46959001', '47019005', '47023002', '47038001', '47068005', '47104007', '47136000', '47151009', '47201006', '47215008', '47341004', '47364002', '47464003', '47469008', '47553004', '47565000', '47581005', '47601000', '47603002', '47626009', '47662005', '47674009', '47692001', '47733001', '47769009', '47784000', '47851007', '47860004', '47894002', '47974007', '48060000', '48109004', '48116003', '48131007', '48140006', '48154003', '48170001', '48217002', '48270008', '48284003', '48323009', '48366002', '48401006', '48416009', '48417000', '48444005', '48464000', '48699007', '48727007', '48751002', '48779008', '48798005', '48815002', '48821003', '48869000', '48919009', '49028001', '49106003', '49119004', '49148005', '49163008', '49212001', '49327004', '49344000', '49352002', '49377001', '49419007', '49449009', '49495002', '49568009', '49582009', '49599005', '49616005', '49653004', '49677005', '49744003', '49772005', '49837000', '49858006', '49912009', '49991001', '49997002', '50028004', '50156006', '50272007', '50383001', '50480002', '50526007', '50700004', '50752003', '50762005', '50864002', '50899003', '50988004', '51222003', '51238009', '51242007', '51262004', '51276003', '51293003', '51311004', '51372003', '51414008', '51415009', '51447004', '51468003', '51511003', '51515007', '51645003', '51718007', '51809003', '51810008', '51873003', '51941005', '51950007', '52078008', '52081003', '52160001', '52169000', '52193005', '52210003', '52227006', '52258007', '52310000', '52313003', '52419000', '52467005', '52555006', '52573009', '52680001', '52764004', '52912003', '52935000', '52991006', '53023007']}, 'type'=>'CodeableConcept', 'path'=>'MedicationAdministration.medication[x]', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/medication-codes'}},
      'medicationReference' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Medication'], 'type'=>'Reference', 'path'=>'MedicationAdministration.medication[x]', 'min'=>1, 'max'=>1},
      'subject' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Patient', 'http://hl7.org/fhir/StructureDefinition/Group'], 'type'=>'Reference', 'path'=>'MedicationAdministration.subject', 'min'=>1, 'max'=>1},
      'context' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Encounter', 'http://hl7.org/fhir/StructureDefinition/EpisodeOfCare'], 'type'=>'Reference', 'path'=>'MedicationAdministration.context', 'min'=>0, 'max'=>1},
      'supportingInformation' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Resource'], 'type'=>'Reference', 'path'=>'MedicationAdministration.supportingInformation', 'min'=>0, 'max'=>Float::INFINITY},
      'effectiveDateTime' => {'type'=>'dateTime', 'path'=>'MedicationAdministration.effective[x]', 'min'=>1, 'max'=>1},
      'effectivePeriod' => {'type'=>'Period', 'path'=>'MedicationAdministration.effective[x]', 'min'=>1, 'max'=>1},
      'performer' => {'type'=>'MedicationAdministration::Performer', 'path'=>'MedicationAdministration.performer', 'min'=>0, 'max'=>Float::INFINITY},
      'reasonCode' => {'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/reason-medication-given'=>['a', 'b', 'c']}, 'type'=>'CodeableConcept', 'path'=>'MedicationAdministration.reasonCode', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/reason-medication-given-codes'}},
      'reasonReference' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Condition', 'http://hl7.org/fhir/StructureDefinition/Observation', 'http://hl7.org/fhir/StructureDefinition/DiagnosticReport'], 'type'=>'Reference', 'path'=>'MedicationAdministration.reasonReference', 'min'=>0, 'max'=>Float::INFINITY},
      'request' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/MedicationRequest'], 'type'=>'Reference', 'path'=>'MedicationAdministration.request', 'min'=>0, 'max'=>1},
      'device' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Device'], 'type'=>'Reference', 'path'=>'MedicationAdministration.device', 'min'=>0, 'max'=>Float::INFINITY},
      'note' => {'type'=>'Annotation', 'path'=>'MedicationAdministration.note', 'min'=>0, 'max'=>Float::INFINITY},
      'dosage' => {'type'=>'MedicationAdministration::Dosage', 'path'=>'MedicationAdministration.dosage', 'min'=>0, 'max'=>1},
      'eventHistory' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Provenance'], 'type'=>'Reference', 'path'=>'MedicationAdministration.eventHistory', 'min'=>0, 'max'=>Float::INFINITY}
    }

    class Performer < FHIR::Model
      include FHIR::Hashable
      include FHIR::Json
      include FHIR::Xml

      METADATA = {
        'id' => {'type'=>'string', 'path'=>'Performer.id', 'min'=>0, 'max'=>1},
        'extension' => {'type'=>'Extension', 'path'=>'Performer.extension', 'min'=>0, 'max'=>Float::INFINITY},
        'modifierExtension' => {'type'=>'Extension', 'path'=>'Performer.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
        'function' => {'valid_codes'=>{'http://terminology.hl7.org/CodeSystem/med-admin-perform-function'=>['performer', 'verifier', 'witness']}, 'type'=>'CodeableConcept', 'path'=>'Performer.function', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/med-admin-perform-function'}},
        'actor' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Practitioner', 'http://hl7.org/fhir/StructureDefinition/PractitionerRole', 'http://hl7.org/fhir/StructureDefinition/Patient', 'http://hl7.org/fhir/StructureDefinition/RelatedPerson', 'http://hl7.org/fhir/StructureDefinition/Device'], 'type'=>'Reference', 'path'=>'Performer.actor', 'min'=>1, 'max'=>1}
      }

      attr_accessor :id                # 0-1 string
      attr_accessor :extension         # 0-* [ Extension ]
      attr_accessor :modifierExtension # 0-* [ Extension ]
      attr_accessor :function          # 0-1 CodeableConcept
      attr_accessor :actor             # 1-1 Reference(Practitioner|PractitionerRole|Patient|RelatedPerson|Device)
    end

    class Dosage < FHIR::Model
      include FHIR::Hashable
      include FHIR::Json
      include FHIR::Xml

      MULTIPLE_TYPES = {
        'rate' => ['Ratio', 'Quantity']
      }
      METADATA = {
        'id' => {'type'=>'string', 'path'=>'Dosage.id', 'min'=>0, 'max'=>1},
        'extension' => {'type'=>'Extension', 'path'=>'Dosage.extension', 'min'=>0, 'max'=>Float::INFINITY},
        'modifierExtension' => {'type'=>'Extension', 'path'=>'Dosage.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
        'text' => {'type'=>'string', 'path'=>'Dosage.text', 'min'=>0, 'max'=>1},
        'site' => {'valid_codes'=>{'http://snomed.info/sct'=>['106004', '107008', '108003', '110001', '111002', '116007', '124002', '149003', '155008', '167005', '202009', '205006', '206007', '221001', '227002', '233006', '235004', '246001', '247005', '251007', '256002', '263002', '266005', '272005', '273000', '283001', '284007', '289002', '301000', '311007', '315003', '318001', '344001', '345000', '356000', '393006', '402006', '405008', '414003', '422005', '446003', '457008', '461002', '464005', '465006', '471000', '480000', '485005', '528006', '552004', '565008', '582005', '587004', '589001', '595000', '608002', '621009', '635006', '650002', '660006', '661005', '667009', '688000', '691000', '692007', '723004', '774007', '790007', '798000', '808000', '809008', '823005', '830004', '836005', '885000', '895007', '917004', '921006', '947002', '955009', '976004', '996007', '1005009', '1012000', '1015003', '1028005', '1030007', '1063000', '1075005', '1076006', '1086007', '1087003', '1092001', '1099005', '1101003', '1106008', '1110006', '1122009', '1136004', '1159005', '1172006', '1173001', '1174007', '1193009', '1216008', '1231004', '1236009', '1243003', '1246006', '1263005', '1277008', '1307006', '1311000', '1350001', '1353004', '1403006', '1425000', '1439000', '1441004', '1456008', '1467009', '1484003', '1490004', '1502004', '1511004', '1516009', '1527006', '1537001', '1541002', '1562001', '1569005', '1580005', '1581009', '1584001', '1600003', '1605008', '1610007', '1611006', '1617005', '1620002', '1626008', '1627004', '1630006', '1631005', '1650005', '1655000', '1659006', '1684009', '1706004', '1707008', '1711002', '1716007', '1721005', '1729007', '1732005', '1765002', '1780008', '1781007', '1797002', '1818002', '1825009', '1832000', '1840006', '1849007', '1853009', '1874005', '1893007', '1895000', '1902009', '1910005', '1918003', '1927002', '1992003', '1997009', '2010005', '2020000', '2031008', '2033006', '2044003', '2048000', '2049008', '2059009', '2071003', '2076008', '2083001', '2095001', '2123001', '2150006', '2156000', '2160002', '2175005', '2182009', '2192001', '2205003', '2209009', '2236006', '2246008', '2255006', '2285001', '2292006', '2302002', '2305000', '2306004', '2327009', '2330002', '2332005', '2334006', '2349003', '2372001', '2383005', '2389009', '2395005', '2397002', '2400006', '2402003', '2421006', '2433001', '2436009', '2453002', '2454008', '2484000', '2489005', '2499000', '2502001', '2504000', '2510000', '2539000', '2543001', '2550002', '2577006', '2579009', '2592007', '2600000', '2620004', '2639009', '2653009', '2666009', '2672009', '2675006', '2681003', '2682005', '2686008', '2687004', '2695000', '2703009', '2712006', '2718005', '2726002', '2730004', '2739003', '2741002', '2746007', '2748008', '2759004', '2771005', '2789006', '2792005', '2803000', '2810006', '2812003', '2824005', '2826007', '2830005', '2839006', '2841007', '2845003', '2848001', '2855004', '2861001', '2894003', '2905008', '2909002', '2920002', '2922005', '2923000', '2954001', '2969000', '2979003', '2986006', '2998001', '3003007', '3008003', '3028004', '3039001', '3042007', '3054007', '3055008', '3056009', '3057000', '3058005', '3062004', '3068000', '3081007', '3093003', '3100007', '3113001', '3117000', '3118005', '3120008', '3134008', '3138006', '3153003', '3156006', '3159004', '3169005', '3178004', '3194006', '3198009', '3215002', '3222005', '3227004', '3236000', '3243006', '3255000', '3262009', '3279003', '3295003', '3301002', '3302009', '3315000', '3332001', '3336003', '3341006', '3350008', '3362007', '3366005', '3370002', '3374006', '3377004', '3382006', '3383001', '3394002', '3395001', '3396000', '3400000', '3409004', '3417007', '3438001', '3444002', '3447009', '3460003', '3462006', '3471002', '3478008', '3481003', '3488009', '3490005', '3524005', '3538003', '3541007', '3553006', '3556003', '3563003', '3572006', '3578005', '3582007', '3584008', '3594003', '3608004', '3609007', '3646006', '3663005', '3665003', '3670005', '3711007', '3743007', '3761003', '3766008', '3785006', '3788008', '3789000', '3810000', '3838008', '3860006', '3865001', '3867009', '3876002', '3877006', '3910004', '3916005', '3924000', '3931001', '3935005', '3937002', '3954005', '3956007', '3959000', '3960005', '3964001', '3966004', '3977005', '3984002', '3989007', '4015004', '4019005', '4029003', '4061004', '4066009', '4072009', '4081003', '4093007', '4111006', '4117005', '4121003', '4146003', '4148002', '4150005', '4158003', '4159006', '4180000', '4193005', '4205002', '4212006', '4215008', '4247003', '4258007', '4268002', '4276000', '4281009', '4295007', '4303006', '4312008', '4317002', '4328003', '4335006', '4352005', '4358009', '4360006', '4369007', '4371007', '4375003', '4377006', '4394008', '4402002', '4419000', '4421005', '4430002', '4432005', '4442007', '4486002', '4524000', '4527007', '4537002', '4548009', '4549001', '4566004', '4573009', '4578000', '4583008', '4588004', '4596009', '4603002', '4606005', '4621004', '4624007', '4647008', '4651005', '4658004', '4677002', '4703008', '4717004', '4718009', '4743003', '4755009', '4759003', '4766002', '4768001', '4774001', '4775000', '4799000', '4810005', '4812002', '4828007', '4840007', '4843009', '4861000', '4866005', '4870002', '4871003', '4881004', '4888005', '4897009', '4905007', '4906008', '4924005', '4942000', '4954000', '4956003', '4958002', '5001007', '5023006', '5026003', '5046008', '5068003', '5069006', '5076001', '5115006', '5122003', '5128004', '5140004', '5192008', '5194009', '5195005', '5204005', '5213007', '5225005', '5228007', '5229004', '5261000', '5272005', '5279001', '5296000', '5324007', '5329002', '5336001', '5347008', '5362005', '5366008', '5379004', '5382009', '5394000', '5398002', '5403001', '5421003', '5427004', '5458003', '5459006', '5491007', '5493005', '5498001', '5501001', '5520004', '5538001', '5542003', '5544002', '5560003', '5564007', '5574005', '5580002', '5597008', '5611001', '5625000', '5627008', '5633004', '5643001', '5644007', '5653000', '5665001', '5668004', '5677006', '5682004', '5696005', '5697001', '5709001', '5713008', '5717009', '5718004', '5727003', '5742000', '5751008', '5769004', '5780004', '5798000', '5802004', '5814007', '5815008', '5816009', '5825003', '5828001', '5847003', '5854009', '5868002', '5872003', '5881009', '5882002', '5889006', '5890002', '5893000', '5898009', '5923009', '5926001', '5928000', '5942008', '5943003', '5944009', '5948007', '5951000', '5953002', '5976004', '5979006', '5996007', '6001004', '6004007', '6006009', '6009002', '6013009', '6014003', '6023000', '6032003', '6046003', '6050005', '6059006', '6062009', '6073002', '6074008', '6076005', '6104005', '6105006', '6110005', '6194002', '6216007', '6217003', '6229007', '6253001', '6268000', '6269008', '6279005', '6317000', '6325003', '6326002', '6335009', '6359004', '6371005', '6375001', '6392005', '6404004', '6413002', '6417001', '6423006', '6424000', '6445007', '6448009', '6450001', '6472004', '6504002', '6511003', '6530003', '6533001', '6538005', '6541001', '6544009', '6550004', '6551000', '6553002', '6564004', '6566002', '6572002', '6598008', '6606008', '6608009', '6620001', '6623004', '6633007', '6643005', '6646002', '6649009', '6651008', '6684008', '6685009', '6711001', '6720005', '6731002', '6739000', '6742006', '6750002', '6757004', '6787005', '6789008', '6799003', '6805009', '6820003', '6828005', '6829002', '6834003', '6841009', '6844001', '6850006', '6864006', '6866008', '6871001', '6894000', '6902008', '6905005', '6912001', '6914000', '6921000', '6930008', '6944002', '6969002', '6975006', '6981003', '6987004', '6989001', '6991009', '7035006', '7050002', '7067009', '7076002', '7083009', '7090004', '7091000', '7099003', '7117004', '7121006', '7148007', '7149004', '7154008', '7160008', '7167006', '7173007', '7188002', '7192009', '7227003', '7234001', '7242000', '7275008', '7295002', '7296001', '7311008', '7344002', '7345001', '7347009', '7362006', '7376007', '7378008', '7384006', '7404008', '7435002', '7471001', '7477002', '7480001', '7494000', '7498002', '7507003', '7524009', '7532001', '7554004', '7566005', '7569003', '7591005', '7597009', '7605000', '7610001', '7629007', '7651004', '7652006', '7657000', '7658005', '7697002', '7712004', '7726008', '7736000', '7742001', '7748002', '7755000', '7756004', '7764005', '7769000', '7783003', '7820009', '7829005', '7832008', '7835005', '7840002', '7841003', '7844006', '7851002', '7854005', '7872004', '7874003', '7880006', '7884002', '7885001', '7892006', '7896009', '7911004', '7925003', '7936005', '7944005', '7954009', '7967007', '7986004', '7991003', '7999001', '8001006', '8012006', '8017000', '8024004', '8039003', '8040001', '8045006', '8057002', '8059004', '8067007', '8068002', '8079007', '8091003', '8100009', '8111001', '8112008', '8119004', '8128003', '8133004', '8157004', '8158009', '8159001', '8160006', '8161005', '8165001', '8205005', '8225009', '8242003', '8251006', '8264007', '8265008', '8266009', '8279000', '8289001', '8292002', '8314003', '8334002', '8356004', '8361002', '8369000', '8373002', '8387002', '8389004', '8412003', '8415001', '8454000', '8464009', '8482007', '8483002', '8496001', '8523001', '8546004', '8556000', '8559007', '8560002', '8568009', '8580001', '8595004', '8598002', '8600008', '8603005', '8604004', '8608001', '8617001', '8623006', '8629005', '8640002', '8668003', '8671006', '8677005', '8688004', '8695008', '8710005', '8711009', '8714001', '8752000', '8770002', '8775007', '8784007', '8810002', '8814006', '8815007', '8820007', '8821006', '8827005', '8839002', '8845005', '8850004', '8854008', '8862000', '8873007', '8887007', '8892009', '8894005', '8897003', '8907008', '8910001', '8911002', '8928004', '8931003', '8935007', '8942007', '8965002', '8966001', '8983005', '8988001', '8993003', '9000002', '9003000', '9018004', '9040008', '9055004', '9073001', '9081000', '9086005', '9089003', '9108007', '9127001', '9156001', '9181003', '9185007', '9186008', '9188009', '9208002', '9212008', '9229006', '9231002', '9240003', '9242006', '9258009', '9261005', '9262003', '9284003', '9290004', '9305001', '9317004', '9320007', '9321006', '9325002', '9332006', '9348007', '9379006', '9380009', '9384000', '9390001', '9432007', '9438006', '9454009', '9455005', '9475001', '9481009', '9490002', '9498009', '9502002', '9512009', '9535007', '9558005', '9566001', '9568000', '9596006', '9609000', '9625005', '9642004', '9646001', '9654004', '9659009', '9662007', '9668006', '9677004', '9683001', '9684007', '9708001', '9732008', '9736006', '9743000', '9758008', '9770007', '9775002', '9779008', '9783008', '9791004', '9796009', '9813009', '9825007', '9837009', '9840009', '9841008', '9846003', '9847007', '9849005', '9870004', '9875009', '9878006', '9880000', '9881001', '9891007', '9898001', '9951005', '9968009', '9970000', '9976006', '9994000', '9999005', '10013000', '10024003', '10025002', '10026001', '10036009', '10042008', '10047002', '10052007', '10056005', '10062000', '10119003', '10124000', '10134009']}, 'type'=>'CodeableConcept', 'path'=>'Dosage.site', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/approach-site-codes'}},
        'route' => {'valid_codes'=>{'http://snomed.info/sct'=>['6064005', '10547007', '12130007', '16857009', '26643006', '34206005', '37161004', '37737002', '37839007', '38239002', '45890007', '46713006', '47625008', '54471007', '54485002', '58100008', '60213007', '62226000', '72607000', '78421000', '90028008', '127490009', '127491008', '127492001', '372449004', '372450004', '372451000', '372452007', '372453002', '372454008', '372457001', '372458006', '372459003', '372460008', '372461007', '372463005', '372464004', '372465003', '372466002', '372467006', '372468001', '372469009', '372470005', '372471009', '372473007', '372474001', '372475000', '372476004', '404815008', '404818005', '404819002', '404820008', '416174007', '417070009', '417255000', '417950001', '417985001', '417989007', '418091004', '418114005', '418133000', '418136008', '418162004', '418204005', '418287000', '418321004', '418331006', '418401004', '418418000', '418441008', '418511008', '418586008', '418608002', '418664002', '418722009', '418730005', '418743005', '418813001', '418821007', '418851001', '418877009', '418887008', '418892005', '418947002', '418987007', '419021003', '419165009', '419231003', '419243002', '419320008', '419396008', '419601003', '419631009', '419684008', '419762003', '419778001', '419810008', '419874009', '419894000', '419954003', '419993007', '420047004', '420163009', '420168000', '420185003', '420201002', '420204005', '420218003', '420254004', '420287000', '420719007', '428191002', '429817007', '445752009', '445754005', '445755006', '445756007', '445767008', '445768003', '445769006', '445771006', '445913005', '445941009', '446105004', '446407004', '446435000', '446442000', '446540005', '447026006', '447052000', '447080003', '447081004', '447121004', '447122006', '447227007', '447229005', '447694001', '447964005', '448077001', '448491004', '448492006', '448598008', '697971008', '711360002', '711378007', '714743009', '718329006', '1611000175109', '180677251000087104', '461657851000087101']}, 'type'=>'CodeableConcept', 'path'=>'Dosage.route', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/route-codes'}},
        'method' => {'local_name'=>'local_method', 'valid_codes'=>{'http://snomed.info/sct'=>['417924000', '418283001', '419385000', '419582001', '419652001', '419747000', '420045007', '420246001', '420247005', '420295001', '420341009', '420360002', '420484009', '420503003', '420561004', '420604000', '420606003', '420620005', '420652005', '420771004', '420806001', '420883007', '420942008', '420974001', '421035004', '421066005', '421067001', '421134003', '421139008', '421206002', '421257003', '421286000', '421298005', '421399004', '421463005', '421484000', '421521009', '421538008', '421548005', '421612001', '421682005', '421718005', '421723005', '421769005', '421803000', '421805007', '421829000', '421832002', '421939007', '421984009', '421994004', '422033008', '422106007', '422114001', '422145002', '422152000', '422219000', '422327006']}, 'type'=>'CodeableConcept', 'path'=>'Dosage.method', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/administration-method-codes'}},
        'dose' => {'type'=>'Quantity', 'path'=>'Dosage.dose', 'min'=>0, 'max'=>1},
        'rateRatio' => {'type'=>'Ratio', 'path'=>'Dosage.rate[x]', 'min'=>0, 'max'=>1},
        'rateQuantity' => {'type'=>'Quantity', 'path'=>'Dosage.rate[x]', 'min'=>0, 'max'=>1}
      }

      attr_accessor :id                # 0-1 string
      attr_accessor :extension         # 0-* [ Extension ]
      attr_accessor :modifierExtension # 0-* [ Extension ]
      attr_accessor :text              # 0-1 string
      attr_accessor :site              # 0-1 CodeableConcept
      attr_accessor :route             # 0-1 CodeableConcept
      attr_accessor :local_method      # 0-1 CodeableConcept
      attr_accessor :dose              # 0-1 Quantity
      attr_accessor :rateRatio         # 0-1 Ratio
      attr_accessor :rateQuantity      # 0-1 Quantity
    end

    attr_accessor :id                        # 0-1 id
    attr_accessor :meta                      # 0-1 Meta
    attr_accessor :implicitRules             # 0-1 uri
    attr_accessor :language                  # 0-1 code
    attr_accessor :text                      # 0-1 Narrative
    attr_accessor :contained                 # 0-* [ Resource ]
    attr_accessor :extension                 # 0-* [ Extension ]
    attr_accessor :modifierExtension         # 0-* [ Extension ]
    attr_accessor :identifier                # 0-* [ Identifier ]
    attr_accessor :instantiates              # 0-* [ uri ]
    attr_accessor :partOf                    # 0-* [ Reference(MedicationAdministration|Procedure) ]
    attr_accessor :status                    # 1-1 code
    attr_accessor :statusReason              # 0-* [ CodeableConcept ]
    attr_accessor :category                  # 0-1 CodeableConcept
    attr_accessor :medicationCodeableConcept # 1-1 CodeableConcept
    attr_accessor :medicationReference       # 1-1 Reference(Medication)
    attr_accessor :subject                   # 1-1 Reference(Patient|Group)
    attr_accessor :context                   # 0-1 Reference(Encounter|EpisodeOfCare)
    attr_accessor :supportingInformation     # 0-* [ Reference(Resource) ]
    attr_accessor :effectiveDateTime         # 1-1 dateTime
    attr_accessor :effectivePeriod           # 1-1 Period
    attr_accessor :performer                 # 0-* [ MedicationAdministration::Performer ]
    attr_accessor :reasonCode                # 0-* [ CodeableConcept ]
    attr_accessor :reasonReference           # 0-* [ Reference(Condition|Observation|DiagnosticReport) ]
    attr_accessor :request                   # 0-1 Reference(MedicationRequest)
    attr_accessor :device                    # 0-* [ Reference(Device) ]
    attr_accessor :note                      # 0-* [ Annotation ]
    attr_accessor :dosage                    # 0-1 MedicationAdministration::Dosage
    attr_accessor :eventHistory              # 0-* [ Reference(Provenance) ]

    def resourceType
      'MedicationAdministration'
    end
  end
end